#include "td/telegram/td_api_json.h"

#include "td/telegram/td_api.h"
#include "td/telegram/td_api.hpp"

#include "td/tl/tl_json.h"

#include "td/utils/base64.h"
#include "td/utils/common.h"
#include "td/utils/Slice.h"

#include <unordered_map>

namespace td {
namespace td_api{
Result<int32> tl_constructor_from_string(td_api::BackgroundType *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"backgroundTypeWallpaper", 1972128891},
    {"backgroundTypePattern", -1091944673},
    {"backgroundTypeSolid", -31192323}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::CallProblem *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"callProblemEcho", 801116548},
    {"callProblemNoise", 1053065359},
    {"callProblemInterruptions", 1119493218},
    {"callProblemDistortedSpeech", 379960581},
    {"callProblemSilentLocal", 253652790},
    {"callProblemSilentRemote", 573634714},
    {"callProblemDropped", -1207311487}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::CallbackQueryPayload *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"callbackQueryPayloadData", -1977729946},
    {"callbackQueryPayloadGame", 1303571512}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::ChatAction *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"chatActionTyping", 380122167},
    {"chatActionRecordingVideo", 216553362},
    {"chatActionUploadingVideo", 1234185270},
    {"chatActionRecordingVoiceNote", -808850058},
    {"chatActionUploadingVoiceNote", -613643666},
    {"chatActionUploadingPhoto", 654240583},
    {"chatActionUploadingDocument", 167884362},
    {"chatActionChoosingLocation", -2017893596},
    {"chatActionChoosingContact", -1222507496},
    {"chatActionStartPlayingGame", -865884164},
    {"chatActionRecordingVideoNote", 16523393},
    {"chatActionUploadingVideoNote", 1172364918},
    {"chatActionCancel", 1160523958}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::ChatMemberStatus *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"chatMemberStatusCreator", 1756320508},
    {"chatMemberStatusAdministrator", 45106688},
    {"chatMemberStatusMember", 844723285},
    {"chatMemberStatusRestricted", 1661432998},
    {"chatMemberStatusLeft", -5815259},
    {"chatMemberStatusBanned", -1653518666}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::ChatMembersFilter *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"chatMembersFilterContacts", 1774485671},
    {"chatMembersFilterAdministrators", -1266893796},
    {"chatMembersFilterMembers", 670504342},
    {"chatMembersFilterRestricted", 1256282813},
    {"chatMembersFilterBanned", -1863102648},
    {"chatMembersFilterBots", -1422567288}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::ChatReportReason *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"chatReportReasonSpam", -510848863},
    {"chatReportReasonViolence", -1330235395},
    {"chatReportReasonPornography", 722614385},
    {"chatReportReasonChildAbuse", -1070686531},
    {"chatReportReasonCopyright", 986898080},
    {"chatReportReasonCustom", 544575454}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::DeviceToken *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"deviceTokenFirebaseCloudMessaging", -797881849},
    {"deviceTokenApplePush", 387541955},
    {"deviceTokenApplePushVoIP", 804275689},
    {"deviceTokenWindowsPush", -1410514289},
    {"deviceTokenMicrosoftPush", 1224269900},
    {"deviceTokenMicrosoftPushVoIP", -785603759},
    {"deviceTokenWebPush", -1694507273},
    {"deviceTokenSimplePush", 49584736},
    {"deviceTokenUbuntuPush", 1782320422},
    {"deviceTokenBlackBerryPush", 1559167234},
    {"deviceTokenTizenPush", -1359947213}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::FileType *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"fileTypeNone", 2003009189},
    {"fileTypeAnimation", -290816582},
    {"fileTypeAudio", -709112160},
    {"fileTypeDocument", -564722929},
    {"fileTypePhoto", -1718914651},
    {"fileTypeProfilePhoto", 1795089315},
    {"fileTypeSecret", -1871899401},
    {"fileTypeSecretThumbnail", -1401326026},
    {"fileTypeSecure", -1419133146},
    {"fileTypeSticker", 475233385},
    {"fileTypeThumbnail", -12443298},
    {"fileTypeUnknown", -2011566768},
    {"fileTypeVideo", 1430816539},
    {"fileTypeVideoNote", -518412385},
    {"fileTypeVoiceNote", -588681661},
    {"fileTypeWallpaper", 1854930076}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::InlineKeyboardButtonType *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"inlineKeyboardButtonTypeUrl", 1130741420},
    {"inlineKeyboardButtonTypeLoginUrl", 281435539},
    {"inlineKeyboardButtonTypeCallback", -1127515139},
    {"inlineKeyboardButtonTypeCallbackGame", -383429528},
    {"inlineKeyboardButtonTypeSwitchInline", -2035563307},
    {"inlineKeyboardButtonTypeBuy", 1360739440}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::InputBackground *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"inputBackgroundLocal", -1747094364},
    {"inputBackgroundRemote", -274976231}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::InputCredentials *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"inputCredentialsSaved", -2034385364},
    {"inputCredentialsNew", -829689558},
    {"inputCredentialsAndroidPay", 1979566832},
    {"inputCredentialsApplePay", -1246570799}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::InputFile *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"inputFileId", 1788906253},
    {"inputFileRemote", -107574466},
    {"inputFileLocal", 2056030919},
    {"inputFileGenerated", -1781351885}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::InputInlineQueryResult *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"inputInlineQueryResultAnimatedGif", -891474894},
    {"inputInlineQueryResultAnimatedMpeg4", -1629529888},
    {"inputInlineQueryResultArticle", 1973670156},
    {"inputInlineQueryResultAudio", 1260139988},
    {"inputInlineQueryResultContact", 1846064594},
    {"inputInlineQueryResultDocument", 578801869},
    {"inputInlineQueryResultGame", 966074327},
    {"inputInlineQueryResultLocation", -1887650218},
    {"inputInlineQueryResultPhoto", -1123338721},
    {"inputInlineQueryResultSticker", 274007129},
    {"inputInlineQueryResultVenue", 541704509},
    {"inputInlineQueryResultVideo", 1724073191},
    {"inputInlineQueryResultVoiceNote", -1790072503}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::InputMessageContent *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"inputMessageText", 247050392},
    {"inputMessageAnimation", 926542724},
    {"inputMessageAudio", -626786126},
    {"inputMessageDocument", 937970604},
    {"inputMessagePhoto", 1648801584},
    {"inputMessageSticker", 740776325},
    {"inputMessageVideo", -2108486755},
    {"inputMessageVideoNote", 279108859},
    {"inputMessageVoiceNote", 2136519657},
    {"inputMessageLocation", -1624179655},
    {"inputMessageVenue", 1447926269},
    {"inputMessageContact", -982446849},
    {"inputMessageGame", -1728000914},
    {"inputMessageInvoice", 1038812175},
    {"inputMessagePoll", -1791140518},
    {"inputMessageForwarded", 1503132333}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::InputPassportElement *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"inputPassportElementPersonalDetails", 164791359},
    {"inputPassportElementPassport", -497011356},
    {"inputPassportElementDriverLicense", 304813264},
    {"inputPassportElementIdentityCard", -9963390},
    {"inputPassportElementInternalPassport", 715360043},
    {"inputPassportElementAddress", 461630480},
    {"inputPassportElementUtilityBill", 1389203841},
    {"inputPassportElementBankStatement", -26585208},
    {"inputPassportElementRentalAgreement", 1736154155},
    {"inputPassportElementPassportRegistration", 1314562128},
    {"inputPassportElementTemporaryRegistration", -1913238047},
    {"inputPassportElementPhoneNumber", 1319357497},
    {"inputPassportElementEmailAddress", -248605659}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::InputPassportElementErrorSource *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"inputPassportElementErrorSourceUnspecified", 267230319},
    {"inputPassportElementErrorSourceDataField", -426795002},
    {"inputPassportElementErrorSourceFrontSide", 588023741},
    {"inputPassportElementErrorSourceReverseSide", 413072891},
    {"inputPassportElementErrorSourceSelfie", -773575528},
    {"inputPassportElementErrorSourceTranslationFile", 505842299},
    {"inputPassportElementErrorSourceTranslationFiles", -527254048},
    {"inputPassportElementErrorSourceFile", -298492469},
    {"inputPassportElementErrorSourceFiles", -2008541640}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::JsonValue *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"jsonValueNull", -92872499},
    {"jsonValueBoolean", -2142186576},
    {"jsonValueNumber", -1010822033},
    {"jsonValueString", 1597947313},
    {"jsonValueArray", -183913546},
    {"jsonValueObject", 520252026}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::KeyboardButtonType *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"keyboardButtonTypeText", -1773037256},
    {"keyboardButtonTypeRequestPhoneNumber", -1529235527},
    {"keyboardButtonTypeRequestLocation", -125661955}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::LanguagePackStringValue *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"languagePackStringValueOrdinary", -249256352},
    {"languagePackStringValuePluralized", 1906840261},
    {"languagePackStringValueDeleted", 1834792698}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::LogStream *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"logStreamDefault", 1390581436},
    {"logStreamFile", -1880085930},
    {"logStreamEmpty", -499912244}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::MaskPoint *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"maskPointForehead", 1027512005},
    {"maskPointEyes", 1748310861},
    {"maskPointMouth", 411773406},
    {"maskPointChin", 534995335}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::NetworkStatisticsEntry *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"networkStatisticsEntryFile", 188452706},
    {"networkStatisticsEntryCall", 737000365}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::NetworkType *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"networkTypeNone", -1971691759},
    {"networkTypeMobile", 819228239},
    {"networkTypeMobileRoaming", -1435199760},
    {"networkTypeWiFi", -633872070},
    {"networkTypeOther", 1942128539}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::NotificationSettingsScope *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"notificationSettingsScopePrivateChats", 937446759},
    {"notificationSettingsScopeGroupChats", 1212142067},
    {"notificationSettingsScopeChannelChats", 548013448}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::OptionValue *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"optionValueBoolean", 63135518},
    {"optionValueEmpty", 918955155},
    {"optionValueInteger", -1400911104},
    {"optionValueString", 756248212}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::PassportElementType *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"passportElementTypePersonalDetails", -1032136365},
    {"passportElementTypePassport", -436360376},
    {"passportElementTypeDriverLicense", 1827298379},
    {"passportElementTypeIdentityCard", -502356132},
    {"passportElementTypeInternalPassport", -793781959},
    {"passportElementTypeAddress", 496327874},
    {"passportElementTypeUtilityBill", 627084906},
    {"passportElementTypeBankStatement", 574095667},
    {"passportElementTypeRentalAgreement", -2060583280},
    {"passportElementTypePassportRegistration", -159478209},
    {"passportElementTypeTemporaryRegistration", 1092498527},
    {"passportElementTypePhoneNumber", -995361172},
    {"passportElementTypeEmailAddress", -79321405}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::ProxyType *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"proxyTypeSocks5", -890027341},
    {"proxyTypeHttp", -1547188361},
    {"proxyTypeMtproto", -1964826627}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::ReplyMarkup *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"replyMarkupRemoveKeyboard", -691252879},
    {"replyMarkupForceReply", 1039104593},
    {"replyMarkupShowKeyboard", -992627133},
    {"replyMarkupInlineKeyboard", -619317658}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::SearchMessagesFilter *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"searchMessagesFilterEmpty", -869395657},
    {"searchMessagesFilterAnimation", -155713339},
    {"searchMessagesFilterAudio", 867505275},
    {"searchMessagesFilterDocument", 1526331215},
    {"searchMessagesFilterPhoto", 925932293},
    {"searchMessagesFilterVideo", 115538222},
    {"searchMessagesFilterVoiceNote", 1841439357},
    {"searchMessagesFilterPhotoAndVideo", 1352130963},
    {"searchMessagesFilterUrl", -1828724341},
    {"searchMessagesFilterChatPhoto", -1247751329},
    {"searchMessagesFilterCall", 1305231012},
    {"searchMessagesFilterMissedCall", 970663098},
    {"searchMessagesFilterVideoNote", 564323321},
    {"searchMessagesFilterVoiceAndVideoNote", 664174819},
    {"searchMessagesFilterMention", 2001258652},
    {"searchMessagesFilterUnreadMention", -95769149}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::SupergroupMembersFilter *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"supergroupMembersFilterRecent", 1178199509},
    {"supergroupMembersFilterContacts", -1282910856},
    {"supergroupMembersFilterAdministrators", -2097380265},
    {"supergroupMembersFilterSearch", -1696358469},
    {"supergroupMembersFilterRestricted", -1107800034},
    {"supergroupMembersFilterBanned", -1210621683},
    {"supergroupMembersFilterBots", 492138918}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::TextEntityType *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"textEntityTypeMention", 934535013},
    {"textEntityTypeHashtag", -1023958307},
    {"textEntityTypeCashtag", 1222915915},
    {"textEntityTypeBotCommand", -1150997581},
    {"textEntityTypeUrl", -1312762756},
    {"textEntityTypeEmailAddress", 1425545249},
    {"textEntityTypeBold", -1128210000},
    {"textEntityTypeItalic", -118253987},
    {"textEntityTypeCode", -974534326},
    {"textEntityTypePre", 1648958606},
    {"textEntityTypePreCode", -945325397},
    {"textEntityTypeTextUrl", 445719651},
    {"textEntityTypeMentionName", -791517091},
    {"textEntityTypePhoneNumber", -1160140246}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::TextParseMode *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"textParseModeMarkdown", 969225580},
    {"textParseModeHTML", 1660208627}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::TopChatCategory *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"topChatCategoryUsers", 1026706816},
    {"topChatCategoryBots", -1577129195},
    {"topChatCategoryGroups", 1530056846},
    {"topChatCategoryChannels", -500825885},
    {"topChatCategoryInlineBots", 377023356},
    {"topChatCategoryCalls", 356208861}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::UserPrivacySetting *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"userPrivacySettingShowStatus", 1862829310},
    {"userPrivacySettingShowProfilePhoto", 1408485877},
    {"userPrivacySettingShowLinkInForwardedMessages", 592688870},
    {"userPrivacySettingAllowChatInvites", 1271668007},
    {"userPrivacySettingAllowCalls", -906967291},
    {"userPrivacySettingAllowPeerToPeerCalls", 352500032}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::UserPrivacySettingRule *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"userPrivacySettingRuleAllowAll", -1967186881},
    {"userPrivacySettingRuleAllowContacts", -1892733680},
    {"userPrivacySettingRuleAllowUsers", 427601278},
    {"userPrivacySettingRuleRestrictAll", -1406495408},
    {"userPrivacySettingRuleRestrictContacts", 1008389378},
    {"userPrivacySettingRuleRestrictUsers", 2119951802}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::Object *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"accountTtl", 1324495492},
    {"address", -2043654342},
    {"autoDownloadSettings", -1086183818},
    {"backgroundTypeWallpaper", 1972128891},
    {"backgroundTypePattern", -1091944673},
    {"backgroundTypeSolid", -31192323},
    {"callProblemEcho", 801116548},
    {"callProblemNoise", 1053065359},
    {"callProblemInterruptions", 1119493218},
    {"callProblemDistortedSpeech", 379960581},
    {"callProblemSilentLocal", 253652790},
    {"callProblemSilentRemote", 573634714},
    {"callProblemDropped", -1207311487},
    {"callProtocol", -1042830667},
    {"callbackQueryPayloadData", -1977729946},
    {"callbackQueryPayloadGame", 1303571512},
    {"chatActionTyping", 380122167},
    {"chatActionRecordingVideo", 216553362},
    {"chatActionUploadingVideo", 1234185270},
    {"chatActionRecordingVoiceNote", -808850058},
    {"chatActionUploadingVoiceNote", -613643666},
    {"chatActionUploadingPhoto", 654240583},
    {"chatActionUploadingDocument", 167884362},
    {"chatActionChoosingLocation", -2017893596},
    {"chatActionChoosingContact", -1222507496},
    {"chatActionStartPlayingGame", -865884164},
    {"chatActionRecordingVideoNote", 16523393},
    {"chatActionUploadingVideoNote", 1172364918},
    {"chatActionCancel", 1160523958},
    {"chatEventLogFilters", 941939684},
    {"chatMemberStatusCreator", 1756320508},
    {"chatMemberStatusAdministrator", 45106688},
    {"chatMemberStatusMember", 844723285},
    {"chatMemberStatusRestricted", 1661432998},
    {"chatMemberStatusLeft", -5815259},
    {"chatMemberStatusBanned", -1653518666},
    {"chatMembersFilterContacts", 1774485671},
    {"chatMembersFilterAdministrators", -1266893796},
    {"chatMembersFilterMembers", 670504342},
    {"chatMembersFilterRestricted", 1256282813},
    {"chatMembersFilterBanned", -1863102648},
    {"chatMembersFilterBots", -1422567288},
    {"chatNotificationSettings", 1503183218},
    {"chatPermissions", 1584650463},
    {"chatReportReasonSpam", -510848863},
    {"chatReportReasonViolence", -1330235395},
    {"chatReportReasonPornography", 722614385},
    {"chatReportReasonChildAbuse", -1070686531},
    {"chatReportReasonCopyright", 986898080},
    {"chatReportReasonCustom", 544575454},
    {"contact", -1483002540},
    {"date", -277956960},
    {"deviceTokenFirebaseCloudMessaging", -797881849},
    {"deviceTokenApplePush", 387541955},
    {"deviceTokenApplePushVoIP", 804275689},
    {"deviceTokenWindowsPush", -1410514289},
    {"deviceTokenMicrosoftPush", 1224269900},
    {"deviceTokenMicrosoftPushVoIP", -785603759},
    {"deviceTokenWebPush", -1694507273},
    {"deviceTokenSimplePush", 49584736},
    {"deviceTokenUbuntuPush", 1782320422},
    {"deviceTokenBlackBerryPush", 1559167234},
    {"deviceTokenTizenPush", -1359947213},
    {"draftMessage", 1902914742},
    {"error", -1679978726},
    {"fileTypeNone", 2003009189},
    {"fileTypeAnimation", -290816582},
    {"fileTypeAudio", -709112160},
    {"fileTypeDocument", -564722929},
    {"fileTypePhoto", -1718914651},
    {"fileTypeProfilePhoto", 1795089315},
    {"fileTypeSecret", -1871899401},
    {"fileTypeSecretThumbnail", -1401326026},
    {"fileTypeSecure", -1419133146},
    {"fileTypeSticker", 475233385},
    {"fileTypeThumbnail", -12443298},
    {"fileTypeUnknown", -2011566768},
    {"fileTypeVideo", 1430816539},
    {"fileTypeVideoNote", -518412385},
    {"fileTypeVoiceNote", -588681661},
    {"fileTypeWallpaper", 1854930076},
    {"formattedText", -252624564},
    {"inlineKeyboardButton", -372105704},
    {"inlineKeyboardButtonTypeUrl", 1130741420},
    {"inlineKeyboardButtonTypeLoginUrl", 281435539},
    {"inlineKeyboardButtonTypeCallback", -1127515139},
    {"inlineKeyboardButtonTypeCallbackGame", -383429528},
    {"inlineKeyboardButtonTypeSwitchInline", -2035563307},
    {"inlineKeyboardButtonTypeBuy", 1360739440},
    {"inputBackgroundLocal", -1747094364},
    {"inputBackgroundRemote", -274976231},
    {"inputCredentialsSaved", -2034385364},
    {"inputCredentialsNew", -829689558},
    {"inputCredentialsAndroidPay", 1979566832},
    {"inputCredentialsApplePay", -1246570799},
    {"inputFileId", 1788906253},
    {"inputFileRemote", -107574466},
    {"inputFileLocal", 2056030919},
    {"inputFileGenerated", -1781351885},
    {"inputIdentityDocument", -381776063},
    {"inputInlineQueryResultAnimatedGif", -891474894},
    {"inputInlineQueryResultAnimatedMpeg4", -1629529888},
    {"inputInlineQueryResultArticle", 1973670156},
    {"inputInlineQueryResultAudio", 1260139988},
    {"inputInlineQueryResultContact", 1846064594},
    {"inputInlineQueryResultDocument", 578801869},
    {"inputInlineQueryResultGame", 966074327},
    {"inputInlineQueryResultLocation", -1887650218},
    {"inputInlineQueryResultPhoto", -1123338721},
    {"inputInlineQueryResultSticker", 274007129},
    {"inputInlineQueryResultVenue", 541704509},
    {"inputInlineQueryResultVideo", 1724073191},
    {"inputInlineQueryResultVoiceNote", -1790072503},
    {"inputMessageText", 247050392},
    {"inputMessageAnimation", 926542724},
    {"inputMessageAudio", -626786126},
    {"inputMessageDocument", 937970604},
    {"inputMessagePhoto", 1648801584},
    {"inputMessageSticker", 740776325},
    {"inputMessageVideo", -2108486755},
    {"inputMessageVideoNote", 279108859},
    {"inputMessageVoiceNote", 2136519657},
    {"inputMessageLocation", -1624179655},
    {"inputMessageVenue", 1447926269},
    {"inputMessageContact", -982446849},
    {"inputMessageGame", -1728000914},
    {"inputMessageInvoice", 1038812175},
    {"inputMessagePoll", -1791140518},
    {"inputMessageForwarded", 1503132333},
    {"inputPassportElementPersonalDetails", 164791359},
    {"inputPassportElementPassport", -497011356},
    {"inputPassportElementDriverLicense", 304813264},
    {"inputPassportElementIdentityCard", -9963390},
    {"inputPassportElementInternalPassport", 715360043},
    {"inputPassportElementAddress", 461630480},
    {"inputPassportElementUtilityBill", 1389203841},
    {"inputPassportElementBankStatement", -26585208},
    {"inputPassportElementRentalAgreement", 1736154155},
    {"inputPassportElementPassportRegistration", 1314562128},
    {"inputPassportElementTemporaryRegistration", -1913238047},
    {"inputPassportElementPhoneNumber", 1319357497},
    {"inputPassportElementEmailAddress", -248605659},
    {"inputPassportElementError", 285756898},
    {"inputPassportElementErrorSourceUnspecified", 267230319},
    {"inputPassportElementErrorSourceDataField", -426795002},
    {"inputPassportElementErrorSourceFrontSide", 588023741},
    {"inputPassportElementErrorSourceReverseSide", 413072891},
    {"inputPassportElementErrorSourceSelfie", -773575528},
    {"inputPassportElementErrorSourceTranslationFile", 505842299},
    {"inputPassportElementErrorSourceTranslationFiles", -527254048},
    {"inputPassportElementErrorSourceFile", -298492469},
    {"inputPassportElementErrorSourceFiles", -2008541640},
    {"inputPersonalDocument", 1676966826},
    {"inputSticker", -1998602205},
    {"inputThumbnail", 1582387236},
    {"invoice", -368451690},
    {"jsonObjectMember", -1803309418},
    {"jsonValueNull", -92872499},
    {"jsonValueBoolean", -2142186576},
    {"jsonValueNumber", -1010822033},
    {"jsonValueString", 1597947313},
    {"jsonValueArray", -183913546},
    {"jsonValueObject", 520252026},
    {"keyboardButton", -2069836172},
    {"keyboardButtonTypeText", -1773037256},
    {"keyboardButtonTypeRequestPhoneNumber", -1529235527},
    {"keyboardButtonTypeRequestLocation", -125661955},
    {"labeledPricePart", 552789798},
    {"languagePackInfo", 542199642},
    {"languagePackString", 1307632736},
    {"languagePackStringValueOrdinary", -249256352},
    {"languagePackStringValuePluralized", 1906840261},
    {"languagePackStringValueDeleted", 1834792698},
    {"location", 749028016},
    {"logStreamDefault", 1390581436},
    {"logStreamFile", -1880085930},
    {"logStreamEmpty", -499912244},
    {"maskPointForehead", 1027512005},
    {"maskPointEyes", 1748310861},
    {"maskPointMouth", 411773406},
    {"maskPointChin", 534995335},
    {"maskPosition", -2097433026},
    {"networkStatisticsEntryFile", 188452706},
    {"networkStatisticsEntryCall", 737000365},
    {"networkTypeNone", -1971691759},
    {"networkTypeMobile", 819228239},
    {"networkTypeMobileRoaming", -1435199760},
    {"networkTypeWiFi", -633872070},
    {"networkTypeOther", 1942128539},
    {"notificationSettingsScopePrivateChats", 937446759},
    {"notificationSettingsScopeGroupChats", 1212142067},
    {"notificationSettingsScopeChannelChats", 548013448},
    {"optionValueBoolean", 63135518},
    {"optionValueEmpty", 918955155},
    {"optionValueInteger", -1400911104},
    {"optionValueString", 756248212},
    {"orderInfo", 783997294},
    {"passportElementTypePersonalDetails", -1032136365},
    {"passportElementTypePassport", -436360376},
    {"passportElementTypeDriverLicense", 1827298379},
    {"passportElementTypeIdentityCard", -502356132},
    {"passportElementTypeInternalPassport", -793781959},
    {"passportElementTypeAddress", 496327874},
    {"passportElementTypeUtilityBill", 627084906},
    {"passportElementTypeBankStatement", 574095667},
    {"passportElementTypeRentalAgreement", -2060583280},
    {"passportElementTypePassportRegistration", -159478209},
    {"passportElementTypeTemporaryRegistration", 1092498527},
    {"passportElementTypePhoneNumber", -995361172},
    {"passportElementTypeEmailAddress", -79321405},
    {"personalDetails", -1061656137},
    {"phoneNumberAuthenticationSettings", -859198743},
    {"proxyTypeSocks5", -890027341},
    {"proxyTypeHttp", -1547188361},
    {"proxyTypeMtproto", -1964826627},
    {"replyMarkupRemoveKeyboard", -691252879},
    {"replyMarkupForceReply", 1039104593},
    {"replyMarkupShowKeyboard", -992627133},
    {"replyMarkupInlineKeyboard", -619317658},
    {"scopeNotificationSettings", -426103745},
    {"searchMessagesFilterEmpty", -869395657},
    {"searchMessagesFilterAnimation", -155713339},
    {"searchMessagesFilterAudio", 867505275},
    {"searchMessagesFilterDocument", 1526331215},
    {"searchMessagesFilterPhoto", 925932293},
    {"searchMessagesFilterVideo", 115538222},
    {"searchMessagesFilterVoiceNote", 1841439357},
    {"searchMessagesFilterPhotoAndVideo", 1352130963},
    {"searchMessagesFilterUrl", -1828724341},
    {"searchMessagesFilterChatPhoto", -1247751329},
    {"searchMessagesFilterCall", 1305231012},
    {"searchMessagesFilterMissedCall", 970663098},
    {"searchMessagesFilterVideoNote", 564323321},
    {"searchMessagesFilterVoiceAndVideoNote", 664174819},
    {"searchMessagesFilterMention", 2001258652},
    {"searchMessagesFilterUnreadMention", -95769149},
    {"shippingOption", 1425690001},
    {"supergroupMembersFilterRecent", 1178199509},
    {"supergroupMembersFilterContacts", -1282910856},
    {"supergroupMembersFilterAdministrators", -2097380265},
    {"supergroupMembersFilterSearch", -1696358469},
    {"supergroupMembersFilterRestricted", -1107800034},
    {"supergroupMembersFilterBanned", -1210621683},
    {"supergroupMembersFilterBots", 492138918},
    {"tdlibParameters", -761520773},
    {"testInt", -574804983},
    {"testString", -27891572},
    {"textEntity", -1951688280},
    {"textEntityTypeMention", 934535013},
    {"textEntityTypeHashtag", -1023958307},
    {"textEntityTypeCashtag", 1222915915},
    {"textEntityTypeBotCommand", -1150997581},
    {"textEntityTypeUrl", -1312762756},
    {"textEntityTypeEmailAddress", 1425545249},
    {"textEntityTypeBold", -1128210000},
    {"textEntityTypeItalic", -118253987},
    {"textEntityTypeCode", -974534326},
    {"textEntityTypePre", 1648958606},
    {"textEntityTypePreCode", -945325397},
    {"textEntityTypeTextUrl", 445719651},
    {"textEntityTypeMentionName", -791517091},
    {"textEntityTypePhoneNumber", -1160140246},
    {"textParseModeMarkdown", 969225580},
    {"textParseModeHTML", 1660208627},
    {"topChatCategoryUsers", 1026706816},
    {"topChatCategoryBots", -1577129195},
    {"topChatCategoryGroups", 1530056846},
    {"topChatCategoryChannels", -500825885},
    {"topChatCategoryInlineBots", 377023356},
    {"topChatCategoryCalls", 356208861},
    {"userPrivacySettingShowStatus", 1862829310},
    {"userPrivacySettingShowProfilePhoto", 1408485877},
    {"userPrivacySettingShowLinkInForwardedMessages", 592688870},
    {"userPrivacySettingAllowChatInvites", 1271668007},
    {"userPrivacySettingAllowCalls", -906967291},
    {"userPrivacySettingAllowPeerToPeerCalls", 352500032},
    {"userPrivacySettingRuleAllowAll", -1967186881},
    {"userPrivacySettingRuleAllowContacts", -1892733680},
    {"userPrivacySettingRuleAllowUsers", 427601278},
    {"userPrivacySettingRuleRestrictAll", -1406495408},
    {"userPrivacySettingRuleRestrictContacts", 1008389378},
    {"userPrivacySettingRuleRestrictUsers", 2119951802},
    {"userPrivacySettingRules", 322477541},
    {"venue", 1070406393}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Result<int32> tl_constructor_from_string(td_api::Function *object, const std::string &str) {
  static const std::unordered_map<Slice, int32, SliceHash> m = {
    {"acceptCall", -646618416},
    {"acceptTermsOfService", 2130576356},
    {"addChatMember", 1182817962},
    {"addChatMembers", 1234094617},
    {"addCustomServerLanguagePack", 4492771},
    {"addFavoriteSticker", 324504799},
    {"addLocalMessage", -348943149},
    {"addLogMessage", 1597427692},
    {"addNetworkStatistics", 1264825305},
    {"addProxy", 331529432},
    {"addRecentSticker", -1478109026},
    {"addRecentlyFoundChat", -1746396787},
    {"addSavedAnimation", -1538525088},
    {"addStickerToSet", 1422402800},
    {"answerCallbackQuery", -1153028490},
    {"answerCustomQuery", -1293603521},
    {"answerInlineQuery", 485879477},
    {"answerPreCheckoutQuery", -1486789653},
    {"answerShippingQuery", -434601324},
    {"blockUser", -1239315139},
    {"cancelDownloadFile", -1954524450},
    {"cancelUploadFile", 1623539600},
    {"changeChatReportSpamState", 1768597097},
    {"changeImportedContacts", 1968207955},
    {"changePhoneNumber", -124666973},
    {"changeStickerSet", 449357293},
    {"checkAuthenticationBotToken", 639321206},
    {"checkAuthenticationCode", -302103382},
    {"checkAuthenticationPassword", -2025698400},
    {"checkChangePhoneNumberCode", -1720278429},
    {"checkChatInviteLink", -496940997},
    {"checkChatUsername", -119119344},
    {"checkDatabaseEncryptionKey", 1018769307},
    {"checkEmailAddressVerificationCode", -426386685},
    {"checkPhoneNumberConfirmationCode", -1348060966},
    {"checkPhoneNumberVerificationCode", 1497462718},
    {"checkRecoveryEmailAddressCode", -1997039589},
    {"cleanFileName", 967964667},
    {"clearAllDraftMessages", -46369573},
    {"clearImportedContacts", 869503298},
    {"clearRecentStickers", -321242684},
    {"clearRecentlyFoundChats", -285582542},
    {"close", -1187782273},
    {"closeChat", 39749353},
    {"closeSecretChat", -471006133},
    {"createBasicGroupChat", 642492777},
    {"createCall", -1742408159},
    {"createNewBasicGroupChat", 1874532069},
    {"createNewSecretChat", 1689344881},
    {"createNewStickerSet", 205093058},
    {"createNewSupergroupChat", 1284982268},
    {"createPrivateChat", -1807530364},
    {"createSecretChat", 1930285615},
    {"createSupergroupChat", 352742758},
    {"createTemporaryPassword", -1626509434},
    {"deleteAccount", -1203056508},
    {"deleteChatHistory", -1472081761},
    {"deleteChatMessagesFromUser", -1599689199},
    {"deleteChatReplyMarkup", 100637531},
    {"deleteFile", 1807653676},
    {"deleteLanguagePack", -2108761026},
    {"deleteMessages", 1130090173},
    {"deletePassportElement", -1719555468},
    {"deleteProfilePhoto", 1319794625},
    {"deleteSavedCredentials", 826300114},
    {"deleteSavedOrderInfo", 1629058164},
    {"deleteSupergroup", -1999855965},
    {"destroy", 685331274},
    {"disableProxy", -2100095102},
    {"discardCall", -923187372},
    {"disconnectAllWebsites", -1082985981},
    {"disconnectWebsite", -778767395},
    {"downloadFile", -1102026662},
    {"editCustomLanguagePackInfo", 1320751257},
    {"editInlineMessageCaption", -760985929},
    {"editInlineMessageLiveLocation", 655046316},
    {"editInlineMessageMedia", 23553921},
    {"editInlineMessageReplyMarkup", -67565858},
    {"editInlineMessageText", -855457307},
    {"editMessageCaption", 1154677038},
    {"editMessageLiveLocation", -1146772745},
    {"editMessageMedia", -1152678125},
    {"editMessageReplyMarkup", 332127881},
    {"editMessageText", 196272567},
    {"editProxy", -1605883821},
    {"enableProxy", 1494450838},
    {"finishFileGeneration", -1055060835},
    {"forwardMessages", 1948637111},
    {"generateChatInviteLink", 1945532500},
    {"getAccountTtl", -443905161},
    {"getActiveLiveLocationMessages", -1425459567},
    {"getActiveSessions", 1119710526},
    {"getAllPassportElements", -2038945045},
    {"getApplicationConfig", -1823144318},
    {"getArchivedStickerSets", 1996943238},
    {"getAttachedStickerSets", 1302172429},
    {"getAuthorizationState", 1949154877},
    {"getAutoDownloadSettingsPresets", -1721088201},
    {"getBackgroundUrl", 733769682},
    {"getBackgrounds", 249072633},
    {"getBasicGroup", 561775568},
    {"getBasicGroupFullInfo", 1770517905},
    {"getBlockedUsers", -742912777},
    {"getCallbackQueryAnswer", 116357727},
    {"getChat", 1866601536},
    {"getChatAdministrators", 508231041},
    {"getChatEventLog", 206900967},
    {"getChatHistory", -799960451},
    {"getChatMember", 677085892},
    {"getChatMessageByDate", 1062564150},
    {"getChatMessageCount", 205435308},
    {"getChatNotificationSettingsExceptions", 201199121},
    {"getChatPinnedMessage", 359865008},
    {"getChatReportSpamState", -748866856},
    {"getChatStatisticsUrl", 1114621183},
    {"getChats", -2121381601},
    {"getConnectedWebsites", -170536110},
    {"getContacts", -1417722768},
    {"getCountryCode", 1540593906},
    {"getCreatedPublicChats", 1609082914},
    {"getCurrentState", -1191417719},
    {"getDatabaseStatistics", -1942760263},
    {"getDeepLinkInfo", 680673150},
    {"getEmojiSuggestionsUrl", -1404101841},
    {"getFavoriteStickers", -338964672},
    {"getFile", 1553923406},
    {"getFileDownloadedPrefixSize", -1668864864},
    {"getFileExtension", -106055372},
    {"getFileMimeType", -2073879671},
    {"getGameHighScores", 1920923753},
    {"getGroupsInCommon", -23238689},
    {"getImportedContactCount", -656336346},
    {"getInlineGameHighScores", -1833445800},
    {"getInlineQueryResults", -1182511172},
    {"getInstalledStickerSets", 1214523749},
    {"getInviteText", 794573512},
    {"getJsonString", 663458849},
    {"getJsonValue", -1829086715},
    {"getLanguagePackInfo", 2077809320},
    {"getLanguagePackString", 150789747},
    {"getLanguagePackStrings", 1246259088},
    {"getLocalizationTargetInfo", 1849499526},
    {"getLogStream", 1167608667},
    {"getLogTagVerbosityLevel", 951004547},
    {"getLogTags", -254449190},
    {"getLogVerbosityLevel", 594057956},
    {"getMapThumbnailFile", -152660070},
    {"getMe", -191516033},
    {"getMessage", -1821196160},
    {"getMessageLink", 1362732326},
    {"getMessageLinkInfo", -700533672},
    {"getMessageLocally", -603575444},
    {"getMessages", 425299338},
    {"getNetworkStatistics", -986228706},
    {"getOption", -1572495746},
    {"getPassportAuthorizationForm", -1468394095},
    {"getPassportAuthorizationFormAvailableElements", 1738134754},
    {"getPassportElement", -1882398342},
    {"getPasswordState", -174752904},
    {"getPaymentForm", -2146950882},
    {"getPaymentReceipt", 1013758294},
    {"getPreferredCountryLanguage", -933049386},
    {"getProxies", -95026381},
    {"getProxyLink", -1285597664},
    {"getPublicMessageLink", -374642839},
    {"getPushReceiverId", -286505294},
    {"getRecentInlineBots", 1437823548},
    {"getRecentStickers", -579622241},
    {"getRecentlyVisitedTMeUrls", 806754961},
    {"getRecoveryEmailAddress", -1594770947},
    {"getRemoteFile", 2137204530},
    {"getRepliedMessage", -641918531},
    {"getSavedAnimations", 7051032},
    {"getSavedOrderInfo", -1152016675},
    {"getScopeNotificationSettings", -995613361},
    {"getSecretChat", 40599169},
    {"getStickerEmojis", -1895508665},
    {"getStickerSet", 1052318659},
    {"getStickers", -1594919556},
    {"getStorageStatistics", -853193929},
    {"getStorageStatisticsFast", 61368066},
    {"getSupergroup", -2063063706},
    {"getSupergroupFullInfo", -1150331262},
    {"getSupergroupMembers", 1427643098},
    {"getSupportUser", -1733497700},
    {"getTemporaryPasswordState", -12670830},
    {"getTextEntities", -341490693},
    {"getTopChats", -388410847},
    {"getTrendingStickerSets", -1729129957},
    {"getUser", -47586017},
    {"getUserFullInfo", -655443263},
    {"getUserPrivacySettingRules", -2077223311},
    {"getUserProfilePhotos", -2062927433},
    {"getWebPageInstantView", -1962649975},
    {"getWebPagePreview", 573441580},
    {"importContacts", -215132767},
    {"joinChat", 326769313},
    {"joinChatByInviteLink", -1049973882},
    {"leaveChat", -1825080735},
    {"logOut", -1581923301},
    {"openChat", -323371509},
    {"openMessageContent", -739088005},
    {"optimizeStorage", 980397489},
    {"parseTextEntities", -1709194593},
    {"pinChatMessage", -554712351},
    {"pingProxy", -979681103},
    {"processPushNotification", 786679952},
    {"readAllChatMentions", 1357558453},
    {"readFilePart", -407749314},
    {"recoverAuthenticationPassword", 787436412},
    {"recoverPassword", 1660185903},
    {"registerDevice", 1734127493},
    {"registerUser", -109994467},
    {"removeBackground", -1484545642},
    {"removeContacts", -615510759},
    {"removeFavoriteSticker", 1152945264},
    {"removeNotification", 862630734},
    {"removeNotificationGroup", 1713005454},
    {"removeProxy", 1369219847},
    {"removeRecentHashtag", -1013735260},
    {"removeRecentSticker", 1246577677},
    {"removeRecentlyFoundChat", 717340444},
    {"removeSavedAnimation", -495605479},
    {"removeStickerFromSet", 1642196644},
    {"removeTopChat", -1907876267},
    {"reorderInstalledStickerSets", 1114537563},
    {"reportChat", -312579772},
    {"reportSupergroupSpam", -2125451498},
    {"requestAuthenticationPasswordRecovery", 1393896118},
    {"requestPasswordRecovery", -13777582},
    {"resendAuthenticationCode", -814377191},
    {"resendChangePhoneNumberCode", -786772060},
    {"resendEmailAddressVerificationCode", -1872416732},
    {"resendMessages", -940655817},
    {"resendPhoneNumberConfirmationCode", 2069068522},
    {"resendPhoneNumberVerificationCode", 1367629820},
    {"resendRecoveryEmailAddressCode", 433483548},
    {"resetAllNotificationSettings", -174020359},
    {"resetBackgrounds", 204852088},
    {"resetNetworkStatistics", 1646452102},
    {"saveApplicationLogEvent", -811154930},
    {"searchBackground", -2130996959},
    {"searchCallMessages", -1077230820},
    {"searchChatMembers", -445823291},
    {"searchChatMessages", -1528846671},
    {"searchChatRecentLocationMessages", 950238950},
    {"searchChats", -1879787060},
    {"searchChatsOnServer", -1158402188},
    {"searchContacts", -1794690715},
    {"searchEmojis", 454272250},
    {"searchHashtags", 1043637617},
    {"searchInstalledStickerSets", 681171344},
    {"searchMessages", 1579305146},
    {"searchPublicChat", 857135533},
    {"searchPublicChats", 970385337},
    {"searchSecretMessages", -1670627915},
    {"searchStickerSet", 1157930222},
    {"searchStickerSets", -1082314629},
    {"searchStickers", 1555771203},
    {"sendBotStartMessage", 1112181339},
    {"sendCallDebugInformation", 2019243839},
    {"sendCallRating", -1402719502},
    {"sendChatAction", -841357536},
    {"sendChatScreenshotTakenNotification", 448399457},
    {"sendChatSetTtlMessage", 1432535564},
    {"sendCustomRequest", 285045153},
    {"sendEmailAddressVerificationCode", -221621379},
    {"sendInlineQueryResultMessage", 893888200},
    {"sendMessage", 1694632114},
    {"sendMessageAlbum", -291823014},
    {"sendPassportAuthorizationForm", -602402218},
    {"sendPaymentForm", 591581572},
    {"sendPhoneNumberConfirmationCode", -1901171495},
    {"sendPhoneNumberVerificationCode", 2081689035},
    {"setAccountTtl", 701389032},
    {"setAlarm", -873497067},
    {"setAuthenticationPhoneNumber", 868276259},
    {"setAutoDownloadSettings", -353671948},
    {"setBackground", -1035439225},
    {"setBio", -1619582124},
    {"setBotUpdatesStatus", -1154926191},
    {"setChatClientData", -827119811},
    {"setChatDescription", 1957213277},
    {"setChatDraftMessage", -588175579},
    {"setChatMemberStatus", -1754439241},
    {"setChatNotificationSettings", 777199614},
    {"setChatPermissions", 2138507006},
    {"setChatPhoto", 132244217},
    {"setChatTitle", 164282047},
    {"setCustomLanguagePack", -296742819},
    {"setCustomLanguagePackString", 1316365592},
    {"setDatabaseEncryptionKey", -1204599371},
    {"setFileGenerationProgress", -540459953},
    {"setGameScore", -1768307069},
    {"setInlineGameScore", 758435487},
    {"setLogStream", -1364199535},
    {"setLogTagVerbosityLevel", -2095589738},
    {"setLogVerbosityLevel", -303429678},
    {"setName", 1711693584},
    {"setNetworkType", -701635234},
    {"setOption", 2114670322},
    {"setPassportElement", 2068173212},
    {"setPassportElementErrors", 1455869875},
    {"setPassword", -1193589027},
    {"setPinnedChats", -1369665719},
    {"setPollAnswer", -1399388792},
    {"setProfilePhoto", 1594734550},
    {"setRecoveryEmailAddress", -1981836385},
    {"setScopeNotificationSettings", -2049984966},
    {"setStickerPositionInSet", 2075281185},
    {"setSupergroupStickerSet", -295782298},
    {"setSupergroupUsername", -1428333122},
    {"setTdlibParameters", -1912557997},
    {"setUserPrivacySettingRules", -473812741},
    {"setUsername", 439901214},
    {"stopPoll", 1659374253},
    {"synchronizeLanguagePack", -2065307858},
    {"terminateAllOtherSessions", 1874485523},
    {"terminateSession", -407385812},
    {"testCallBytes", -736011607},
    {"testCallEmpty", -627291626},
    {"testCallString", -1732818385},
    {"testCallVectorInt", -2137277793},
    {"testCallVectorIntObject", 1825428218},
    {"testCallVectorString", -408600900},
    {"testCallVectorStringObject", 1527666429},
    {"testGetDifference", 1747084069},
    {"testNetwork", -1343998901},
    {"testProxy", 965027595},
    {"testReturnError", 455179506},
    {"testSquareInt", -60135024},
    {"testUseUpdate", 717094686},
    {"toggleChatDefaultDisableNotification", 314794002},
    {"toggleChatIsMarkedAsUnread", -986129697},
    {"toggleChatIsPinned", -1166802621},
    {"toggleSupergroupIsAllHistoryAvailable", 1701526555},
    {"toggleSupergroupSignMessages", -558196581},
    {"unblockUser", -307286367},
    {"unpinChatMessage", 277557690},
    {"upgradeBasicGroupChatToSupergroupChat", 300488122},
    {"uploadFile", -745597786},
    {"uploadStickerFile", 1134087551},
    {"validateOrderInfo", 9480644},
    {"viewMessages", -1925784915},
    {"viewTrendingStickerSets", -952416520},
    {"writeGeneratedFilePart", -2062358189}
  };
  auto it = m.find(str);
  if (it == m.end()) {
    return Status::Error(PSLICE() << "Unknown class \"" << str << "\"");
  }
  return it->second;
}
Status from_json(td_api::accountTtl &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "days", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.days_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::address &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "country_code", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.country_code_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "state", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.state_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "city", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.city_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "street_line1", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.street_line1_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "street_line2", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.street_line2_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "postal_code", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.postal_code_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::autoDownloadSettings &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "is_auto_download_enabled", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_auto_download_enabled_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "max_photo_file_size", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.max_photo_file_size_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "max_video_file_size", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.max_video_file_size_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "max_other_file_size", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.max_other_file_size_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "preload_large_videos", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.preload_large_videos_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "preload_next_audio", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.preload_next_audio_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "use_less_data_for_calls", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.use_less_data_for_calls_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::backgroundTypeWallpaper &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "is_blurred", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_blurred_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "is_moving", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_moving_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::backgroundTypePattern &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "is_moving", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_moving_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "color", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.color_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "intensity", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.intensity_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::backgroundTypeSolid &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "color", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.color_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::callProblemEcho &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::callProblemNoise &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::callProblemInterruptions &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::callProblemDistortedSpeech &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::callProblemSilentLocal &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::callProblemSilentRemote &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::callProblemDropped &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::callProtocol &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "udp_p2p", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.udp_p2p_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "udp_reflector", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.udp_reflector_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "min_layer", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.min_layer_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "max_layer", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.max_layer_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::callbackQueryPayloadData &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "data", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json_bytes(to.data_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::callbackQueryPayloadGame &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "game_short_name", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.game_short_name_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::chatActionTyping &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::chatActionRecordingVideo &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::chatActionUploadingVideo &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "progress", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.progress_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::chatActionRecordingVoiceNote &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::chatActionUploadingVoiceNote &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "progress", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.progress_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::chatActionUploadingPhoto &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "progress", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.progress_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::chatActionUploadingDocument &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "progress", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.progress_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::chatActionChoosingLocation &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::chatActionChoosingContact &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::chatActionStartPlayingGame &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::chatActionRecordingVideoNote &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::chatActionUploadingVideoNote &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "progress", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.progress_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::chatActionCancel &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::chatEventLogFilters &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "message_edits", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_edits_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_deletions", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_deletions_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_pins", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_pins_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "member_joins", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.member_joins_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "member_leaves", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.member_leaves_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "member_invites", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.member_invites_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "member_promotions", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.member_promotions_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "member_restrictions", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.member_restrictions_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "info_changes", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.info_changes_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "setting_changes", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.setting_changes_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::chatMemberStatusCreator &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "is_member", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_member_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::chatMemberStatusAdministrator &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "can_be_edited", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.can_be_edited_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "can_change_info", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.can_change_info_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "can_post_messages", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.can_post_messages_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "can_edit_messages", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.can_edit_messages_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "can_delete_messages", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.can_delete_messages_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "can_invite_users", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.can_invite_users_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "can_restrict_members", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.can_restrict_members_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "can_pin_messages", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.can_pin_messages_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "can_promote_members", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.can_promote_members_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::chatMemberStatusMember &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::chatMemberStatusRestricted &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "is_member", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_member_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "restricted_until_date", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.restricted_until_date_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "permissions", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.permissions_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::chatMemberStatusLeft &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::chatMemberStatusBanned &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "banned_until_date", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.banned_until_date_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::chatMembersFilterContacts &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::chatMembersFilterAdministrators &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::chatMembersFilterMembers &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::chatMembersFilterRestricted &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::chatMembersFilterBanned &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::chatMembersFilterBots &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::chatNotificationSettings &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "use_default_mute_for", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.use_default_mute_for_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "mute_for", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.mute_for_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "use_default_sound", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.use_default_sound_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "sound", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.sound_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "use_default_show_preview", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.use_default_show_preview_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "show_preview", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.show_preview_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "use_default_disable_pinned_message_notifications", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.use_default_disable_pinned_message_notifications_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "disable_pinned_message_notifications", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.disable_pinned_message_notifications_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "use_default_disable_mention_notifications", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.use_default_disable_mention_notifications_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "disable_mention_notifications", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.disable_mention_notifications_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::chatPermissions &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "can_send_messages", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.can_send_messages_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "can_send_media_messages", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.can_send_media_messages_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "can_send_polls", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.can_send_polls_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "can_send_other_messages", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.can_send_other_messages_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "can_add_web_page_previews", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.can_add_web_page_previews_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "can_change_info", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.can_change_info_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "can_invite_users", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.can_invite_users_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "can_pin_messages", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.can_pin_messages_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::chatReportReasonSpam &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::chatReportReasonViolence &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::chatReportReasonPornography &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::chatReportReasonChildAbuse &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::chatReportReasonCopyright &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::chatReportReasonCustom &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "text", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.text_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::contact &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "phone_number", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.phone_number_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "first_name", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.first_name_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "last_name", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.last_name_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "vcard", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.vcard_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::date &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "day", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.day_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "month", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.month_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "year", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.year_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::deviceTokenFirebaseCloudMessaging &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "token", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.token_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "encrypt", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.encrypt_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::deviceTokenApplePush &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "device_token", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.device_token_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "is_app_sandbox", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_app_sandbox_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::deviceTokenApplePushVoIP &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "device_token", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.device_token_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "is_app_sandbox", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_app_sandbox_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "encrypt", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.encrypt_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::deviceTokenWindowsPush &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "access_token", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.access_token_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::deviceTokenMicrosoftPush &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "channel_uri", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.channel_uri_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::deviceTokenMicrosoftPushVoIP &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "channel_uri", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.channel_uri_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::deviceTokenWebPush &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "endpoint", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.endpoint_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "p256dh_base64url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.p256dh_base64url_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "auth_base64url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.auth_base64url_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::deviceTokenSimplePush &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "endpoint", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.endpoint_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::deviceTokenUbuntuPush &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "token", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.token_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::deviceTokenBlackBerryPush &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "token", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.token_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::deviceTokenTizenPush &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "reg_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reg_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::draftMessage &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_to_message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_to_message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "input_message_text", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.input_message_text_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::error &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "code", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.code_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::fileTypeNone &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::fileTypeAnimation &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::fileTypeAudio &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::fileTypeDocument &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::fileTypePhoto &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::fileTypeProfilePhoto &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::fileTypeSecret &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::fileTypeSecretThumbnail &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::fileTypeSecure &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::fileTypeSticker &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::fileTypeThumbnail &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::fileTypeUnknown &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::fileTypeVideo &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::fileTypeVideoNote &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::fileTypeVoiceNote &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::fileTypeWallpaper &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::formattedText &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "text", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.text_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "entities", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.entities_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inlineKeyboardButton &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "text", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.text_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "type", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.type_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inlineKeyboardButtonTypeUrl &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.url_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inlineKeyboardButtonTypeLoginUrl &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.url_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "forward_text", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.forward_text_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inlineKeyboardButtonTypeCallback &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "data", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json_bytes(to.data_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inlineKeyboardButtonTypeCallbackGame &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::inlineKeyboardButtonTypeSwitchInline &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "query", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.query_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "in_current_chat", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.in_current_chat_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inlineKeyboardButtonTypeBuy &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::inputBackgroundLocal &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "background", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.background_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputBackgroundRemote &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "background_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.background_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputCredentialsSaved &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "saved_credentials_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.saved_credentials_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputCredentialsNew &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "data", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.data_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "allow_save", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.allow_save_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputCredentialsAndroidPay &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "data", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.data_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputCredentialsApplePay &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "data", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.data_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputFileId &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputFileRemote &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputFileLocal &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "path", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.path_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputFileGenerated &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "original_path", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.original_path_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "conversion", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.conversion_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "expected_size", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.expected_size_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputIdentityDocument &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "number", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.number_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "expiry_date", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.expiry_date_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "front_side", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.front_side_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reverse_side", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reverse_side_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "selfie", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.selfie_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "translation", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.translation_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputInlineQueryResultAnimatedGif &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "title", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.title_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "thumbnail_url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.thumbnail_url_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "gif_url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.gif_url_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "gif_duration", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.gif_duration_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "gif_width", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.gif_width_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "gif_height", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.gif_height_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_markup", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_markup_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "input_message_content", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.input_message_content_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputInlineQueryResultAnimatedMpeg4 &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "title", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.title_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "thumbnail_url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.thumbnail_url_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "mpeg4_url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.mpeg4_url_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "mpeg4_duration", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.mpeg4_duration_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "mpeg4_width", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.mpeg4_width_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "mpeg4_height", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.mpeg4_height_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_markup", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_markup_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "input_message_content", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.input_message_content_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputInlineQueryResultArticle &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.url_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "hide_url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.hide_url_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "title", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.title_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "description", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.description_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "thumbnail_url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.thumbnail_url_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "thumbnail_width", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.thumbnail_width_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "thumbnail_height", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.thumbnail_height_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_markup", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_markup_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "input_message_content", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.input_message_content_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputInlineQueryResultAudio &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "title", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.title_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "performer", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.performer_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "audio_url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.audio_url_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "audio_duration", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.audio_duration_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_markup", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_markup_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "input_message_content", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.input_message_content_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputInlineQueryResultContact &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "contact", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.contact_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "thumbnail_url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.thumbnail_url_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "thumbnail_width", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.thumbnail_width_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "thumbnail_height", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.thumbnail_height_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_markup", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_markup_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "input_message_content", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.input_message_content_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputInlineQueryResultDocument &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "title", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.title_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "description", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.description_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "document_url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.document_url_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "mime_type", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.mime_type_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "thumbnail_url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.thumbnail_url_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "thumbnail_width", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.thumbnail_width_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "thumbnail_height", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.thumbnail_height_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_markup", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_markup_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "input_message_content", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.input_message_content_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputInlineQueryResultGame &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "game_short_name", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.game_short_name_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_markup", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_markup_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputInlineQueryResultLocation &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "location", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.location_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "live_period", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.live_period_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "title", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.title_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "thumbnail_url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.thumbnail_url_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "thumbnail_width", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.thumbnail_width_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "thumbnail_height", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.thumbnail_height_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_markup", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_markup_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "input_message_content", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.input_message_content_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputInlineQueryResultPhoto &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "title", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.title_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "description", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.description_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "thumbnail_url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.thumbnail_url_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "photo_url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.photo_url_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "photo_width", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.photo_width_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "photo_height", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.photo_height_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_markup", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_markup_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "input_message_content", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.input_message_content_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputInlineQueryResultSticker &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "thumbnail_url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.thumbnail_url_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "sticker_url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.sticker_url_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "sticker_width", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.sticker_width_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "sticker_height", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.sticker_height_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_markup", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_markup_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "input_message_content", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.input_message_content_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputInlineQueryResultVenue &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "venue", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.venue_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "thumbnail_url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.thumbnail_url_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "thumbnail_width", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.thumbnail_width_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "thumbnail_height", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.thumbnail_height_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_markup", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_markup_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "input_message_content", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.input_message_content_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputInlineQueryResultVideo &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "title", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.title_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "description", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.description_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "thumbnail_url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.thumbnail_url_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "video_url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.video_url_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "mime_type", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.mime_type_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "video_width", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.video_width_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "video_height", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.video_height_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "video_duration", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.video_duration_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_markup", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_markup_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "input_message_content", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.input_message_content_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputInlineQueryResultVoiceNote &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "title", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.title_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "voice_note_url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.voice_note_url_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "voice_note_duration", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.voice_note_duration_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_markup", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_markup_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "input_message_content", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.input_message_content_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputMessageText &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "text", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.text_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "disable_web_page_preview", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.disable_web_page_preview_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "clear_draft", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.clear_draft_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputMessageAnimation &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "animation", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.animation_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "thumbnail", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.thumbnail_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "duration", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.duration_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "width", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.width_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "height", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.height_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "caption", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.caption_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputMessageAudio &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "audio", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.audio_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "album_cover_thumbnail", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.album_cover_thumbnail_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "duration", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.duration_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "title", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.title_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "performer", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.performer_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "caption", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.caption_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputMessageDocument &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "document", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.document_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "thumbnail", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.thumbnail_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "caption", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.caption_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputMessagePhoto &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "photo", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.photo_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "thumbnail", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.thumbnail_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "added_sticker_file_ids", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.added_sticker_file_ids_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "width", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.width_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "height", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.height_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "caption", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.caption_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "ttl", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.ttl_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputMessageSticker &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "sticker", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.sticker_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "thumbnail", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.thumbnail_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "width", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.width_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "height", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.height_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputMessageVideo &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "video", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.video_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "thumbnail", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.thumbnail_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "added_sticker_file_ids", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.added_sticker_file_ids_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "duration", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.duration_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "width", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.width_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "height", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.height_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "supports_streaming", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.supports_streaming_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "caption", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.caption_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "ttl", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.ttl_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputMessageVideoNote &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "video_note", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.video_note_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "thumbnail", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.thumbnail_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "duration", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.duration_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "length", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.length_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputMessageVoiceNote &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "voice_note", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.voice_note_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "duration", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.duration_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "waveform", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json_bytes(to.waveform_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "caption", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.caption_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputMessageLocation &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "location", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.location_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "live_period", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.live_period_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputMessageVenue &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "venue", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.venue_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputMessageContact &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "contact", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.contact_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputMessageGame &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "bot_user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.bot_user_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "game_short_name", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.game_short_name_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputMessageInvoice &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "invoice", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.invoice_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "title", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.title_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "description", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.description_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "photo_url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.photo_url_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "photo_size", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.photo_size_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "photo_width", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.photo_width_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "photo_height", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.photo_height_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "payload", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json_bytes(to.payload_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "provider_token", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.provider_token_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "provider_data", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.provider_data_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "start_parameter", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.start_parameter_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputMessagePoll &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "question", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.question_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "options", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.options_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputMessageForwarded &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "from_chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.from_chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "in_game_share", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.in_game_share_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "send_copy", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.send_copy_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "remove_caption", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.remove_caption_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputPassportElementPersonalDetails &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "personal_details", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.personal_details_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputPassportElementPassport &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "passport", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.passport_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputPassportElementDriverLicense &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "driver_license", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.driver_license_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputPassportElementIdentityCard &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "identity_card", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.identity_card_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputPassportElementInternalPassport &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "internal_passport", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.internal_passport_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputPassportElementAddress &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "address", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.address_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputPassportElementUtilityBill &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "utility_bill", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.utility_bill_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputPassportElementBankStatement &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "bank_statement", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.bank_statement_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputPassportElementRentalAgreement &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "rental_agreement", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.rental_agreement_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputPassportElementPassportRegistration &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "passport_registration", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.passport_registration_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputPassportElementTemporaryRegistration &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "temporary_registration", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.temporary_registration_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputPassportElementPhoneNumber &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "phone_number", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.phone_number_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputPassportElementEmailAddress &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "email_address", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.email_address_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputPassportElementError &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "type", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.type_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "source", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.source_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputPassportElementErrorSourceUnspecified &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "element_hash", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json_bytes(to.element_hash_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputPassportElementErrorSourceDataField &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "field_name", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.field_name_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "data_hash", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json_bytes(to.data_hash_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputPassportElementErrorSourceFrontSide &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "file_hash", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json_bytes(to.file_hash_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputPassportElementErrorSourceReverseSide &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "file_hash", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json_bytes(to.file_hash_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputPassportElementErrorSourceSelfie &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "file_hash", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json_bytes(to.file_hash_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputPassportElementErrorSourceTranslationFile &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "file_hash", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json_bytes(to.file_hash_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputPassportElementErrorSourceTranslationFiles &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "file_hashes", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.file_hashes_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputPassportElementErrorSourceFile &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "file_hash", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json_bytes(to.file_hash_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputPassportElementErrorSourceFiles &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "file_hashes", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.file_hashes_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputPersonalDocument &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "files", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.files_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "translation", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.translation_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputSticker &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "png_sticker", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.png_sticker_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "emojis", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.emojis_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "mask_position", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.mask_position_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::inputThumbnail &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "thumbnail", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.thumbnail_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "width", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.width_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "height", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.height_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::invoice &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "currency", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.currency_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "price_parts", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.price_parts_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "is_test", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_test_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "need_name", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.need_name_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "need_phone_number", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.need_phone_number_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "need_email_address", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.need_email_address_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "need_shipping_address", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.need_shipping_address_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "send_phone_number_to_provider", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.send_phone_number_to_provider_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "send_email_address_to_provider", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.send_email_address_to_provider_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "is_flexible", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_flexible_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::jsonObjectMember &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "key", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.key_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "value", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.value_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::jsonValueNull &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::jsonValueBoolean &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "value", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.value_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::jsonValueNumber &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "value", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.value_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::jsonValueString &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "value", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.value_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::jsonValueArray &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "values", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.values_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::jsonValueObject &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "members", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.members_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::keyboardButton &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "text", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.text_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "type", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.type_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::keyboardButtonTypeText &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::keyboardButtonTypeRequestPhoneNumber &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::keyboardButtonTypeRequestLocation &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::labeledPricePart &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "label", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.label_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "amount", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.amount_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::languagePackInfo &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "base_language_pack_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.base_language_pack_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "name", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.name_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "native_name", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.native_name_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "plural_code", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.plural_code_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "is_official", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_official_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "is_rtl", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_rtl_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "is_beta", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_beta_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "is_installed", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_installed_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "total_string_count", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.total_string_count_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "translated_string_count", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.translated_string_count_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "local_string_count", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.local_string_count_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "translation_url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.translation_url_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::languagePackString &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "key", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.key_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "value", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.value_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::languagePackStringValueOrdinary &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "value", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.value_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::languagePackStringValuePluralized &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "zero_value", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.zero_value_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "one_value", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.one_value_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "two_value", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.two_value_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "few_value", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.few_value_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "many_value", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.many_value_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "other_value", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.other_value_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::languagePackStringValueDeleted &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::location &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "latitude", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.latitude_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "longitude", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.longitude_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::logStreamDefault &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::logStreamFile &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "path", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.path_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "max_file_size", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.max_file_size_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::logStreamEmpty &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::maskPointForehead &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::maskPointEyes &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::maskPointMouth &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::maskPointChin &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::maskPosition &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "point", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.point_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "x_shift", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.x_shift_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "y_shift", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.y_shift_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "scale", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.scale_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::networkStatisticsEntryFile &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "file_type", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.file_type_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "network_type", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.network_type_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "sent_bytes", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.sent_bytes_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "received_bytes", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.received_bytes_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::networkStatisticsEntryCall &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "network_type", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.network_type_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "sent_bytes", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.sent_bytes_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "received_bytes", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.received_bytes_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "duration", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.duration_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::networkTypeNone &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::networkTypeMobile &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::networkTypeMobileRoaming &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::networkTypeWiFi &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::networkTypeOther &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::notificationSettingsScopePrivateChats &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::notificationSettingsScopeGroupChats &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::notificationSettingsScopeChannelChats &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::optionValueBoolean &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "value", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.value_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::optionValueEmpty &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::optionValueInteger &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "value", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.value_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::optionValueString &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "value", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.value_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::orderInfo &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "name", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.name_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "phone_number", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.phone_number_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "email_address", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.email_address_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "shipping_address", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.shipping_address_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::passportElementTypePersonalDetails &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::passportElementTypePassport &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::passportElementTypeDriverLicense &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::passportElementTypeIdentityCard &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::passportElementTypeInternalPassport &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::passportElementTypeAddress &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::passportElementTypeUtilityBill &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::passportElementTypeBankStatement &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::passportElementTypeRentalAgreement &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::passportElementTypePassportRegistration &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::passportElementTypeTemporaryRegistration &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::passportElementTypePhoneNumber &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::passportElementTypeEmailAddress &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::personalDetails &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "first_name", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.first_name_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "middle_name", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.middle_name_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "last_name", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.last_name_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "native_first_name", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.native_first_name_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "native_middle_name", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.native_middle_name_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "native_last_name", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.native_last_name_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "birthdate", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.birthdate_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "gender", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.gender_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "country_code", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.country_code_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "residence_country_code", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.residence_country_code_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::phoneNumberAuthenticationSettings &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "allow_flash_call", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.allow_flash_call_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "is_current_phone_number", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_current_phone_number_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "allow_sms_retriever_api", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.allow_sms_retriever_api_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::proxyTypeSocks5 &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "username", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.username_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "password", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.password_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::proxyTypeHttp &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "username", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.username_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "password", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.password_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "http_only", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.http_only_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::proxyTypeMtproto &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "secret", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.secret_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::replyMarkupRemoveKeyboard &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "is_personal", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_personal_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::replyMarkupForceReply &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "is_personal", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_personal_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::replyMarkupShowKeyboard &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "rows", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.rows_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "resize_keyboard", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.resize_keyboard_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "one_time", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.one_time_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "is_personal", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_personal_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::replyMarkupInlineKeyboard &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "rows", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.rows_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::scopeNotificationSettings &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "mute_for", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.mute_for_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "sound", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.sound_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "show_preview", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.show_preview_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "disable_pinned_message_notifications", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.disable_pinned_message_notifications_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "disable_mention_notifications", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.disable_mention_notifications_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::searchMessagesFilterEmpty &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::searchMessagesFilterAnimation &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::searchMessagesFilterAudio &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::searchMessagesFilterDocument &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::searchMessagesFilterPhoto &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::searchMessagesFilterVideo &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::searchMessagesFilterVoiceNote &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::searchMessagesFilterPhotoAndVideo &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::searchMessagesFilterUrl &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::searchMessagesFilterChatPhoto &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::searchMessagesFilterCall &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::searchMessagesFilterMissedCall &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::searchMessagesFilterVideoNote &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::searchMessagesFilterVoiceAndVideoNote &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::searchMessagesFilterMention &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::searchMessagesFilterUnreadMention &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::shippingOption &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "title", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.title_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "price_parts", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.price_parts_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::supergroupMembersFilterRecent &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::supergroupMembersFilterContacts &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "query", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.query_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::supergroupMembersFilterAdministrators &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::supergroupMembersFilterSearch &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "query", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.query_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::supergroupMembersFilterRestricted &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "query", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.query_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::supergroupMembersFilterBanned &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "query", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.query_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::supergroupMembersFilterBots &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::tdlibParameters &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "use_test_dc", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.use_test_dc_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "database_directory", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.database_directory_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "files_directory", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.files_directory_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "use_file_database", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.use_file_database_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "use_chat_info_database", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.use_chat_info_database_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "use_message_database", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.use_message_database_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "use_secret_chats", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.use_secret_chats_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "api_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.api_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "api_hash", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.api_hash_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "system_language_code", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.system_language_code_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "device_model", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.device_model_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "system_version", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.system_version_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "application_version", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.application_version_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "enable_storage_optimizer", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.enable_storage_optimizer_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "ignore_file_names", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.ignore_file_names_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::testInt &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "value", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.value_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::testString &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "value", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.value_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::textEntity &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "offset", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.offset_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "length", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.length_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "type", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.type_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::textEntityTypeMention &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::textEntityTypeHashtag &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::textEntityTypeCashtag &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::textEntityTypeBotCommand &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::textEntityTypeUrl &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::textEntityTypeEmailAddress &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::textEntityTypeBold &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::textEntityTypeItalic &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::textEntityTypeCode &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::textEntityTypePre &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::textEntityTypePreCode &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "language", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.language_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::textEntityTypeTextUrl &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.url_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::textEntityTypeMentionName &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::textEntityTypePhoneNumber &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::textParseModeMarkdown &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::textParseModeHTML &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::topChatCategoryUsers &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::topChatCategoryBots &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::topChatCategoryGroups &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::topChatCategoryChannels &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::topChatCategoryInlineBots &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::topChatCategoryCalls &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::userPrivacySettingShowStatus &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::userPrivacySettingShowProfilePhoto &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::userPrivacySettingShowLinkInForwardedMessages &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::userPrivacySettingAllowChatInvites &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::userPrivacySettingAllowCalls &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::userPrivacySettingAllowPeerToPeerCalls &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::userPrivacySettingRuleAllowAll &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::userPrivacySettingRuleAllowContacts &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::userPrivacySettingRuleAllowUsers &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "user_ids", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_ids_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::userPrivacySettingRuleRestrictAll &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::userPrivacySettingRuleRestrictContacts &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::userPrivacySettingRuleRestrictUsers &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "user_ids", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_ids_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::userPrivacySettingRules &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "rules", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.rules_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::venue &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "location", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.location_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "title", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.title_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "address", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.address_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "provider", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.provider_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "type", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.type_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::acceptCall &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "call_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.call_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "protocol", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.protocol_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::acceptTermsOfService &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "terms_of_service_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.terms_of_service_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::addChatMember &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "forward_limit", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.forward_limit_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::addChatMembers &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "user_ids", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_ids_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::addCustomServerLanguagePack &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "language_pack_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.language_pack_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::addFavoriteSticker &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "sticker", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.sticker_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::addLocalMessage &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "sender_user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.sender_user_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_to_message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_to_message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "disable_notification", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.disable_notification_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "input_message_content", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.input_message_content_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::addLogMessage &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "verbosity_level", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.verbosity_level_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "text", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.text_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::addNetworkStatistics &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "entry", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.entry_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::addProxy &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "server", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.server_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "port", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.port_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "enable", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.enable_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "type", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.type_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::addRecentSticker &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "is_attached", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_attached_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "sticker", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.sticker_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::addRecentlyFoundChat &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::addSavedAnimation &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "animation", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.animation_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::addStickerToSet &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "name", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.name_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "sticker", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.sticker_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::answerCallbackQuery &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "callback_query_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.callback_query_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "text", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.text_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "show_alert", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.show_alert_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.url_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "cache_time", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.cache_time_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::answerCustomQuery &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "custom_query_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.custom_query_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "data", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.data_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::answerInlineQuery &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "inline_query_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.inline_query_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "is_personal", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_personal_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "results", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.results_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "cache_time", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.cache_time_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "next_offset", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.next_offset_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "switch_pm_text", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.switch_pm_text_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "switch_pm_parameter", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.switch_pm_parameter_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::answerPreCheckoutQuery &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "pre_checkout_query_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.pre_checkout_query_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "error_message", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.error_message_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::answerShippingQuery &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "shipping_query_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.shipping_query_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "shipping_options", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.shipping_options_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "error_message", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.error_message_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::blockUser &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::cancelDownloadFile &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "file_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.file_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "only_if_pending", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.only_if_pending_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::cancelUploadFile &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "file_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.file_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::changeChatReportSpamState &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "is_spam_chat", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_spam_chat_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::changeImportedContacts &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "contacts", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.contacts_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::changePhoneNumber &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "phone_number", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.phone_number_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "settings", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.settings_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::changeStickerSet &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "set_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.set_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "is_installed", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_installed_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "is_archived", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_archived_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::checkAuthenticationBotToken &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "token", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.token_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::checkAuthenticationCode &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "code", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.code_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::checkAuthenticationPassword &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "password", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.password_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::checkChangePhoneNumberCode &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "code", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.code_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::checkChatInviteLink &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "invite_link", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.invite_link_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::checkChatUsername &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "username", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.username_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::checkDatabaseEncryptionKey &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "encryption_key", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json_bytes(to.encryption_key_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::checkEmailAddressVerificationCode &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "code", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.code_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::checkPhoneNumberConfirmationCode &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "code", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.code_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::checkPhoneNumberVerificationCode &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "code", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.code_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::checkRecoveryEmailAddressCode &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "code", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.code_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::cleanFileName &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "file_name", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.file_name_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::clearAllDraftMessages &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "exclude_secret_chats", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.exclude_secret_chats_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::clearImportedContacts &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::clearRecentStickers &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "is_attached", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_attached_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::clearRecentlyFoundChats &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::close &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::closeChat &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::closeSecretChat &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "secret_chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.secret_chat_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::createBasicGroupChat &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "basic_group_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.basic_group_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "force", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.force_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::createCall &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "protocol", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.protocol_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::createNewBasicGroupChat &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "user_ids", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_ids_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "title", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.title_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::createNewSecretChat &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::createNewStickerSet &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "title", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.title_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "name", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.name_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "is_masks", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_masks_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "stickers", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.stickers_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::createNewSupergroupChat &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "title", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.title_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "is_channel", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_channel_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "description", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.description_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::createPrivateChat &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "force", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.force_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::createSecretChat &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "secret_chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.secret_chat_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::createSupergroupChat &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "supergroup_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.supergroup_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "force", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.force_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::createTemporaryPassword &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "password", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.password_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "valid_for", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.valid_for_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::deleteAccount &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "reason", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reason_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::deleteChatHistory &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "remove_from_chat_list", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.remove_from_chat_list_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "revoke", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.revoke_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::deleteChatMessagesFromUser &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::deleteChatReplyMarkup &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::deleteFile &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "file_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.file_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::deleteLanguagePack &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "language_pack_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.language_pack_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::deleteMessages &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_ids", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_ids_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "revoke", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.revoke_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::deletePassportElement &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "type", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.type_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::deleteProfilePhoto &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "profile_photo_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.profile_photo_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::deleteSavedCredentials &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::deleteSavedOrderInfo &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::deleteSupergroup &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "supergroup_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.supergroup_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::destroy &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::disableProxy &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::discardCall &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "call_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.call_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "is_disconnected", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_disconnected_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "duration", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.duration_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "connection_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.connection_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::disconnectAllWebsites &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::disconnectWebsite &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "website_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.website_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::downloadFile &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "file_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.file_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "priority", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.priority_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "offset", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.offset_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "limit", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.limit_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "synchronous", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.synchronous_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::editCustomLanguagePackInfo &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "info", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.info_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::editInlineMessageCaption &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "inline_message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.inline_message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_markup", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_markup_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "caption", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.caption_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::editInlineMessageLiveLocation &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "inline_message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.inline_message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_markup", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_markup_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "location", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.location_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::editInlineMessageMedia &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "inline_message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.inline_message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_markup", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_markup_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "input_message_content", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.input_message_content_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::editInlineMessageReplyMarkup &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "inline_message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.inline_message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_markup", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_markup_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::editInlineMessageText &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "inline_message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.inline_message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_markup", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_markup_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "input_message_content", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.input_message_content_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::editMessageCaption &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_markup", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_markup_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "caption", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.caption_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::editMessageLiveLocation &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_markup", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_markup_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "location", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.location_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::editMessageMedia &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_markup", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_markup_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "input_message_content", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.input_message_content_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::editMessageReplyMarkup &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_markup", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_markup_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::editMessageText &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_markup", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_markup_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "input_message_content", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.input_message_content_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::editProxy &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "proxy_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.proxy_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "server", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.server_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "port", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.port_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "enable", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.enable_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "type", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.type_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::enableProxy &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "proxy_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.proxy_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::finishFileGeneration &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "generation_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.generation_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "error", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.error_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::forwardMessages &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "from_chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.from_chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_ids", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_ids_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "disable_notification", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.disable_notification_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "from_background", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.from_background_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "as_album", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.as_album_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "send_copy", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.send_copy_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "remove_caption", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.remove_caption_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::generateChatInviteLink &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getAccountTtl &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::getActiveLiveLocationMessages &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::getActiveSessions &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::getAllPassportElements &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "password", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.password_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getApplicationConfig &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::getArchivedStickerSets &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "is_masks", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_masks_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "offset_sticker_set_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.offset_sticker_set_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "limit", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.limit_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getAttachedStickerSets &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "file_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.file_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getAuthorizationState &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::getAutoDownloadSettingsPresets &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::getBackgroundUrl &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "name", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.name_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "type", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.type_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getBackgrounds &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "for_dark_theme", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.for_dark_theme_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getBasicGroup &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "basic_group_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.basic_group_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getBasicGroupFullInfo &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "basic_group_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.basic_group_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getBlockedUsers &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "offset", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.offset_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "limit", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.limit_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getCallbackQueryAnswer &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "payload", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.payload_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getChat &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getChatAdministrators &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getChatEventLog &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "query", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.query_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "from_event_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.from_event_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "limit", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.limit_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "filters", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.filters_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "user_ids", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_ids_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getChatHistory &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "from_message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.from_message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "offset", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.offset_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "limit", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.limit_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "only_local", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.only_local_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getChatMember &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getChatMessageByDate &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "date", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.date_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getChatMessageCount &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "filter", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.filter_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "return_local", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.return_local_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getChatNotificationSettingsExceptions &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "scope", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.scope_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "compare_sound", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.compare_sound_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getChatPinnedMessage &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getChatReportSpamState &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getChatStatisticsUrl &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "parameters", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.parameters_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "is_dark", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_dark_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getChats &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "offset_order", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.offset_order_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "offset_chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.offset_chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "limit", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.limit_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getConnectedWebsites &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::getContacts &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::getCountryCode &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::getCreatedPublicChats &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::getCurrentState &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::getDatabaseStatistics &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::getDeepLinkInfo &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "link", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.link_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getEmojiSuggestionsUrl &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "language_code", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.language_code_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getFavoriteStickers &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::getFile &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "file_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.file_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getFileDownloadedPrefixSize &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "file_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.file_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "offset", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.offset_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getFileExtension &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "mime_type", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.mime_type_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getFileMimeType &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "file_name", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.file_name_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getGameHighScores &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getGroupsInCommon &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "offset_chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.offset_chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "limit", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.limit_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getImportedContactCount &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::getInlineGameHighScores &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "inline_message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.inline_message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getInlineQueryResults &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "bot_user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.bot_user_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "user_location", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_location_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "query", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.query_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "offset", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.offset_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getInstalledStickerSets &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "is_masks", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_masks_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getInviteText &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::getJsonString &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "json_value", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.json_value_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getJsonValue &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "json", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.json_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getLanguagePackInfo &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "language_pack_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.language_pack_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getLanguagePackString &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "language_pack_database_path", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.language_pack_database_path_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "localization_target", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.localization_target_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "language_pack_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.language_pack_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "key", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.key_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getLanguagePackStrings &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "language_pack_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.language_pack_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "keys", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.keys_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getLocalizationTargetInfo &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "only_local", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.only_local_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getLogStream &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::getLogTagVerbosityLevel &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "tag", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.tag_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getLogTags &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::getLogVerbosityLevel &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::getMapThumbnailFile &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "location", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.location_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "zoom", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.zoom_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "width", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.width_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "height", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.height_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "scale", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.scale_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getMe &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::getMessage &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getMessageLink &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getMessageLinkInfo &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.url_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getMessageLocally &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getMessages &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_ids", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_ids_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getNetworkStatistics &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "only_current", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.only_current_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getOption &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "name", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.name_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getPassportAuthorizationForm &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "bot_user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.bot_user_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "scope", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.scope_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "public_key", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.public_key_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "nonce", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.nonce_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getPassportAuthorizationFormAvailableElements &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "autorization_form_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.autorization_form_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "password", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.password_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getPassportElement &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "type", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.type_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "password", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.password_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getPasswordState &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::getPaymentForm &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getPaymentReceipt &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getPreferredCountryLanguage &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "country_code", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.country_code_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getProxies &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::getProxyLink &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "proxy_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.proxy_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getPublicMessageLink &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "for_album", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.for_album_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getPushReceiverId &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "payload", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.payload_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getRecentInlineBots &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::getRecentStickers &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "is_attached", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_attached_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getRecentlyVisitedTMeUrls &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "referrer", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.referrer_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getRecoveryEmailAddress &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "password", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.password_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getRemoteFile &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "remote_file_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.remote_file_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "file_type", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.file_type_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getRepliedMessage &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getSavedAnimations &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::getSavedOrderInfo &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::getScopeNotificationSettings &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "scope", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.scope_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getSecretChat &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "secret_chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.secret_chat_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getStickerEmojis &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "sticker", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.sticker_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getStickerSet &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "set_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.set_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getStickers &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "emoji", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.emoji_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "limit", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.limit_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getStorageStatistics &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_limit", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_limit_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getStorageStatisticsFast &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::getSupergroup &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "supergroup_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.supergroup_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getSupergroupFullInfo &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "supergroup_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.supergroup_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getSupergroupMembers &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "supergroup_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.supergroup_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "filter", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.filter_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "offset", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.offset_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "limit", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.limit_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getSupportUser &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::getTemporaryPasswordState &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::getTextEntities &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "text", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.text_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getTopChats &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "category", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.category_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "limit", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.limit_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getTrendingStickerSets &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::getUser &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getUserFullInfo &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getUserPrivacySettingRules &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "setting", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.setting_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getUserProfilePhotos &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "offset", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.offset_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "limit", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.limit_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getWebPageInstantView &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "url", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.url_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "force_full", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.force_full_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::getWebPagePreview &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "text", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.text_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::importContacts &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "contacts", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.contacts_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::joinChat &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::joinChatByInviteLink &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "invite_link", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.invite_link_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::leaveChat &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::logOut &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::openChat &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::openMessageContent &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::optimizeStorage &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "size", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.size_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "ttl", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.ttl_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "count", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.count_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "immunity_delay", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.immunity_delay_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "file_types", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.file_types_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_ids", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_ids_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "exclude_chat_ids", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.exclude_chat_ids_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_limit", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_limit_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::parseTextEntities &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "text", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.text_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "parse_mode", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.parse_mode_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::pinChatMessage &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "disable_notification", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.disable_notification_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::pingProxy &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "proxy_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.proxy_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::processPushNotification &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "payload", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.payload_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::readAllChatMentions &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::readFilePart &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "file_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.file_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "offset", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.offset_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "count", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.count_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::recoverAuthenticationPassword &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "recovery_code", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.recovery_code_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::recoverPassword &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "recovery_code", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.recovery_code_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::registerDevice &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "device_token", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.device_token_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "other_user_ids", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.other_user_ids_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::registerUser &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "first_name", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.first_name_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "last_name", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.last_name_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::removeBackground &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "background_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.background_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::removeContacts &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "user_ids", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_ids_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::removeFavoriteSticker &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "sticker", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.sticker_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::removeNotification &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "notification_group_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.notification_group_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "notification_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.notification_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::removeNotificationGroup &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "notification_group_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.notification_group_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "max_notification_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.max_notification_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::removeProxy &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "proxy_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.proxy_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::removeRecentHashtag &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "hashtag", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.hashtag_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::removeRecentSticker &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "is_attached", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_attached_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "sticker", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.sticker_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::removeRecentlyFoundChat &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::removeSavedAnimation &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "animation", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.animation_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::removeStickerFromSet &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "sticker", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.sticker_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::removeTopChat &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "category", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.category_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::reorderInstalledStickerSets &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "is_masks", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_masks_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "sticker_set_ids", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.sticker_set_ids_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::reportChat &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reason", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reason_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_ids", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_ids_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::reportSupergroupSpam &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "supergroup_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.supergroup_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_ids", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_ids_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::requestAuthenticationPasswordRecovery &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::requestPasswordRecovery &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::resendAuthenticationCode &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::resendChangePhoneNumberCode &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::resendEmailAddressVerificationCode &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::resendMessages &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_ids", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_ids_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::resendPhoneNumberConfirmationCode &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::resendPhoneNumberVerificationCode &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::resendRecoveryEmailAddressCode &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::resetAllNotificationSettings &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::resetBackgrounds &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::resetNetworkStatistics &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::saveApplicationLogEvent &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "type", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.type_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "data", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.data_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::searchBackground &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "name", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.name_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::searchCallMessages &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "from_message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.from_message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "limit", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.limit_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "only_missed", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.only_missed_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::searchChatMembers &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "query", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.query_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "limit", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.limit_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "filter", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.filter_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::searchChatMessages &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "query", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.query_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "sender_user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.sender_user_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "from_message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.from_message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "offset", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.offset_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "limit", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.limit_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "filter", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.filter_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::searchChatRecentLocationMessages &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "limit", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.limit_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::searchChats &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "query", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.query_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "limit", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.limit_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::searchChatsOnServer &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "query", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.query_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "limit", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.limit_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::searchContacts &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "query", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.query_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "limit", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.limit_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::searchEmojis &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "text", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.text_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "exact_match", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.exact_match_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::searchHashtags &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "prefix", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.prefix_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "limit", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.limit_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::searchInstalledStickerSets &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "is_masks", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_masks_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "query", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.query_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "limit", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.limit_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::searchMessages &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "query", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.query_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "offset_date", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.offset_date_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "offset_chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.offset_chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "offset_message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.offset_message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "limit", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.limit_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::searchPublicChat &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "username", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.username_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::searchPublicChats &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "query", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.query_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::searchSecretMessages &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "query", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.query_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "from_search_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.from_search_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "limit", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.limit_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "filter", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.filter_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::searchStickerSet &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "name", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.name_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::searchStickerSets &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "query", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.query_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::searchStickers &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "emoji", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.emoji_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "limit", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.limit_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::sendBotStartMessage &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "bot_user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.bot_user_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "parameter", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.parameter_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::sendCallDebugInformation &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "call_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.call_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "debug_information", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.debug_information_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::sendCallRating &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "call_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.call_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "rating", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.rating_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "comment", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.comment_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "problems", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.problems_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::sendChatAction &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "action", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.action_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::sendChatScreenshotTakenNotification &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::sendChatSetTtlMessage &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "ttl", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.ttl_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::sendCustomRequest &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "method", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.method_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "parameters", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.parameters_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::sendEmailAddressVerificationCode &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "email_address", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.email_address_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::sendInlineQueryResultMessage &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_to_message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_to_message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "disable_notification", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.disable_notification_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "from_background", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.from_background_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "query_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.query_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "result_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.result_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "hide_via_bot", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.hide_via_bot_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::sendMessage &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_to_message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_to_message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "disable_notification", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.disable_notification_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "from_background", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.from_background_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_markup", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_markup_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "input_message_content", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.input_message_content_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::sendMessageAlbum &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_to_message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_to_message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "disable_notification", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.disable_notification_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "from_background", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.from_background_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "input_message_contents", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.input_message_contents_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::sendPassportAuthorizationForm &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "autorization_form_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.autorization_form_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "types", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.types_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::sendPaymentForm &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "order_info_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.order_info_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "shipping_option_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.shipping_option_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "credentials", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.credentials_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::sendPhoneNumberConfirmationCode &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "hash", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.hash_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "phone_number", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.phone_number_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "settings", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.settings_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::sendPhoneNumberVerificationCode &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "phone_number", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.phone_number_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "settings", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.settings_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setAccountTtl &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "ttl", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.ttl_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setAlarm &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "seconds", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.seconds_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setAuthenticationPhoneNumber &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "phone_number", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.phone_number_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "settings", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.settings_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setAutoDownloadSettings &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "settings", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.settings_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "type", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.type_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setBackground &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "background", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.background_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "type", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.type_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "for_dark_theme", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.for_dark_theme_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setBio &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "bio", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.bio_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setBotUpdatesStatus &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "pending_update_count", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.pending_update_count_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "error_message", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.error_message_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setChatClientData &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "client_data", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.client_data_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setChatDescription &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "description", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.description_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setChatDraftMessage &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "draft_message", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.draft_message_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setChatMemberStatus &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "status", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.status_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setChatNotificationSettings &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "notification_settings", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.notification_settings_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setChatPermissions &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "permissions", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.permissions_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setChatPhoto &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "photo", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.photo_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setChatTitle &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "title", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.title_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setCustomLanguagePack &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "info", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.info_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "strings", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.strings_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setCustomLanguagePackString &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "language_pack_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.language_pack_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "new_string", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.new_string_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setDatabaseEncryptionKey &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "new_encryption_key", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json_bytes(to.new_encryption_key_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setFileGenerationProgress &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "generation_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.generation_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "expected_size", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.expected_size_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "local_prefix_size", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.local_prefix_size_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setGameScore &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "edit_message", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.edit_message_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "score", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.score_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "force", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.force_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setInlineGameScore &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "inline_message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.inline_message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "edit_message", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.edit_message_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "score", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.score_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "force", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.force_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setLogStream &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "log_stream", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.log_stream_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setLogTagVerbosityLevel &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "tag", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.tag_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "new_verbosity_level", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.new_verbosity_level_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setLogVerbosityLevel &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "new_verbosity_level", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.new_verbosity_level_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setName &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "first_name", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.first_name_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "last_name", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.last_name_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setNetworkType &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "type", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.type_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setOption &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "name", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.name_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "value", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.value_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setPassportElement &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "element", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.element_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "password", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.password_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setPassportElementErrors &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "errors", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.errors_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setPassword &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "old_password", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.old_password_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "new_password", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.new_password_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "new_hint", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.new_hint_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "set_recovery_email_address", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.set_recovery_email_address_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "new_recovery_email_address", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.new_recovery_email_address_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setPinnedChats &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_ids", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_ids_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setPollAnswer &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "option_ids", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.option_ids_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setProfilePhoto &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "photo", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.photo_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setRecoveryEmailAddress &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "password", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.password_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "new_recovery_email_address", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.new_recovery_email_address_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setScopeNotificationSettings &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "scope", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.scope_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "notification_settings", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.notification_settings_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setStickerPositionInSet &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "sticker", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.sticker_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "position", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.position_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setSupergroupStickerSet &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "supergroup_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.supergroup_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "sticker_set_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.sticker_set_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setSupergroupUsername &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "supergroup_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.supergroup_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "username", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.username_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setTdlibParameters &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "parameters", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.parameters_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setUserPrivacySettingRules &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "setting", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.setting_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "rules", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.rules_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::setUsername &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "username", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.username_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::stopPoll &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "reply_markup", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.reply_markup_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::synchronizeLanguagePack &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "language_pack_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.language_pack_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::terminateAllOtherSessions &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::terminateSession &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "session_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.session_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::testCallBytes &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "x", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json_bytes(to.x_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::testCallEmpty &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::testCallString &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "x", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.x_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::testCallVectorInt &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "x", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.x_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::testCallVectorIntObject &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "x", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.x_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::testCallVectorString &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "x", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.x_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::testCallVectorStringObject &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "x", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.x_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::testGetDifference &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::testNetwork &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::testProxy &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "server", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.server_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "port", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.port_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "type", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.type_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::testReturnError &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "error", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.error_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::testSquareInt &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "x", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.x_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::testUseUpdate &to, JsonObject &from) {
  return Status::OK();
}
Status from_json(td_api::toggleChatDefaultDisableNotification &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "default_disable_notification", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.default_disable_notification_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::toggleChatIsMarkedAsUnread &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "is_marked_as_unread", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_marked_as_unread_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::toggleChatIsPinned &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "is_pinned", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_pinned_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::toggleSupergroupIsAllHistoryAvailable &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "supergroup_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.supergroup_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "is_all_history_available", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.is_all_history_available_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::toggleSupergroupSignMessages &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "supergroup_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.supergroup_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "sign_messages", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.sign_messages_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::unblockUser &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::unpinChatMessage &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::upgradeBasicGroupChatToSupergroupChat &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::uploadFile &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "file", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.file_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "file_type", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.file_type_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "priority", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.priority_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::uploadStickerFile &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "user_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.user_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "png_sticker", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.png_sticker_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::validateOrderInfo &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "order_info", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.order_info_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "allow_save", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.allow_save_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::viewMessages &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "chat_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.chat_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "message_ids", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.message_ids_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "force_read", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.force_read_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::viewTrendingStickerSets &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "sticker_set_ids", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.sticker_set_ids_, value));
    }
  }
  return Status::OK();
}
Status from_json(td_api::writeGeneratedFilePart &to, JsonObject &from) {
  {
    TRY_RESULT(value, get_json_object_field(from, "generation_id", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.generation_id_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "offset", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json(to.offset_, value));
    }
  }
  {
    TRY_RESULT(value, get_json_object_field(from, "data", td::JsonValue::Type::Null, true));
    if (value.type() != td::JsonValue::Type::Null) {
      TRY_STATUS(from_json_bytes(to.data_, value));
    }
  }
  return Status::OK();
}
void to_json(JsonValueScope &jv, const td_api::accountTtl &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "accountTtl");
  jo << ctie("days", ToJson(object.days_));
}
void to_json(JsonValueScope &jv, const td_api::address &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "address");
  jo << ctie("country_code", ToJson(object.country_code_));
  jo << ctie("state", ToJson(object.state_));
  jo << ctie("city", ToJson(object.city_));
  jo << ctie("street_line1", ToJson(object.street_line1_));
  jo << ctie("street_line2", ToJson(object.street_line2_));
  jo << ctie("postal_code", ToJson(object.postal_code_));
}
void to_json(JsonValueScope &jv, const td_api::animation &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "animation");
  jo << ctie("duration", ToJson(object.duration_));
  jo << ctie("width", ToJson(object.width_));
  jo << ctie("height", ToJson(object.height_));
  jo << ctie("file_name", ToJson(object.file_name_));
  jo << ctie("mime_type", ToJson(object.mime_type_));
  if (object.minithumbnail_) {
    jo << ctie("minithumbnail", ToJson(object.minithumbnail_));
  }
  if (object.thumbnail_) {
    jo << ctie("thumbnail", ToJson(object.thumbnail_));
  }
  if (object.animation_) {
    jo << ctie("animation", ToJson(object.animation_));
  }
}
void to_json(JsonValueScope &jv, const td_api::animations &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "animations");
  jo << ctie("animations", ToJson(object.animations_));
}
void to_json(JsonValueScope &jv, const td_api::audio &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "audio");
  jo << ctie("duration", ToJson(object.duration_));
  jo << ctie("title", ToJson(object.title_));
  jo << ctie("performer", ToJson(object.performer_));
  jo << ctie("file_name", ToJson(object.file_name_));
  jo << ctie("mime_type", ToJson(object.mime_type_));
  if (object.album_cover_minithumbnail_) {
    jo << ctie("album_cover_minithumbnail", ToJson(object.album_cover_minithumbnail_));
  }
  if (object.album_cover_thumbnail_) {
    jo << ctie("album_cover_thumbnail", ToJson(object.album_cover_thumbnail_));
  }
  if (object.audio_) {
    jo << ctie("audio", ToJson(object.audio_));
  }
}
void to_json(JsonValueScope &jv, const td_api::authenticationCodeInfo &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "authenticationCodeInfo");
  jo << ctie("phone_number", ToJson(object.phone_number_));
  if (object.type_) {
    jo << ctie("type", ToJson(object.type_));
  }
  if (object.next_type_) {
    jo << ctie("next_type", ToJson(object.next_type_));
  }
  jo << ctie("timeout", ToJson(object.timeout_));
}
void to_json(JsonValueScope &jv, const td_api::AuthenticationCodeType &object) {
  td_api::downcast_call(const_cast<td_api::AuthenticationCodeType &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::authenticationCodeTypeTelegramMessage &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "authenticationCodeTypeTelegramMessage");
  jo << ctie("length", ToJson(object.length_));
}
void to_json(JsonValueScope &jv, const td_api::authenticationCodeTypeSms &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "authenticationCodeTypeSms");
  jo << ctie("length", ToJson(object.length_));
}
void to_json(JsonValueScope &jv, const td_api::authenticationCodeTypeCall &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "authenticationCodeTypeCall");
  jo << ctie("length", ToJson(object.length_));
}
void to_json(JsonValueScope &jv, const td_api::authenticationCodeTypeFlashCall &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "authenticationCodeTypeFlashCall");
  jo << ctie("pattern", ToJson(object.pattern_));
}
void to_json(JsonValueScope &jv, const td_api::AuthorizationState &object) {
  td_api::downcast_call(const_cast<td_api::AuthorizationState &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::authorizationStateWaitTdlibParameters &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "authorizationStateWaitTdlibParameters");
}
void to_json(JsonValueScope &jv, const td_api::authorizationStateWaitEncryptionKey &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "authorizationStateWaitEncryptionKey");
  jo << ctie("is_encrypted", ToJson(object.is_encrypted_));
}
void to_json(JsonValueScope &jv, const td_api::authorizationStateWaitPhoneNumber &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "authorizationStateWaitPhoneNumber");
}
void to_json(JsonValueScope &jv, const td_api::authorizationStateWaitCode &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "authorizationStateWaitCode");
  if (object.code_info_) {
    jo << ctie("code_info", ToJson(object.code_info_));
  }
}
void to_json(JsonValueScope &jv, const td_api::authorizationStateWaitRegistration &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "authorizationStateWaitRegistration");
  if (object.terms_of_service_) {
    jo << ctie("terms_of_service", ToJson(object.terms_of_service_));
  }
}
void to_json(JsonValueScope &jv, const td_api::authorizationStateWaitPassword &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "authorizationStateWaitPassword");
  jo << ctie("password_hint", ToJson(object.password_hint_));
  jo << ctie("has_recovery_email_address", ToJson(object.has_recovery_email_address_));
  jo << ctie("recovery_email_address_pattern", ToJson(object.recovery_email_address_pattern_));
}
void to_json(JsonValueScope &jv, const td_api::authorizationStateReady &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "authorizationStateReady");
}
void to_json(JsonValueScope &jv, const td_api::authorizationStateLoggingOut &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "authorizationStateLoggingOut");
}
void to_json(JsonValueScope &jv, const td_api::authorizationStateClosing &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "authorizationStateClosing");
}
void to_json(JsonValueScope &jv, const td_api::authorizationStateClosed &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "authorizationStateClosed");
}
void to_json(JsonValueScope &jv, const td_api::autoDownloadSettings &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "autoDownloadSettings");
  jo << ctie("is_auto_download_enabled", ToJson(object.is_auto_download_enabled_));
  jo << ctie("max_photo_file_size", ToJson(object.max_photo_file_size_));
  jo << ctie("max_video_file_size", ToJson(object.max_video_file_size_));
  jo << ctie("max_other_file_size", ToJson(object.max_other_file_size_));
  jo << ctie("preload_large_videos", ToJson(object.preload_large_videos_));
  jo << ctie("preload_next_audio", ToJson(object.preload_next_audio_));
  jo << ctie("use_less_data_for_calls", ToJson(object.use_less_data_for_calls_));
}
void to_json(JsonValueScope &jv, const td_api::autoDownloadSettingsPresets &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "autoDownloadSettingsPresets");
  if (object.low_) {
    jo << ctie("low", ToJson(object.low_));
  }
  if (object.medium_) {
    jo << ctie("medium", ToJson(object.medium_));
  }
  if (object.high_) {
    jo << ctie("high", ToJson(object.high_));
  }
}
void to_json(JsonValueScope &jv, const td_api::background &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "background");
  jo << ctie("id", ToJson(JsonInt64{object.id_}));
  jo << ctie("is_default", ToJson(object.is_default_));
  jo << ctie("is_dark", ToJson(object.is_dark_));
  jo << ctie("name", ToJson(object.name_));
  if (object.document_) {
    jo << ctie("document", ToJson(object.document_));
  }
  if (object.type_) {
    jo << ctie("type", ToJson(object.type_));
  }
}
void to_json(JsonValueScope &jv, const td_api::BackgroundType &object) {
  td_api::downcast_call(const_cast<td_api::BackgroundType &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::backgroundTypeWallpaper &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "backgroundTypeWallpaper");
  jo << ctie("is_blurred", ToJson(object.is_blurred_));
  jo << ctie("is_moving", ToJson(object.is_moving_));
}
void to_json(JsonValueScope &jv, const td_api::backgroundTypePattern &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "backgroundTypePattern");
  jo << ctie("is_moving", ToJson(object.is_moving_));
  jo << ctie("color", ToJson(object.color_));
  jo << ctie("intensity", ToJson(object.intensity_));
}
void to_json(JsonValueScope &jv, const td_api::backgroundTypeSolid &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "backgroundTypeSolid");
  jo << ctie("color", ToJson(object.color_));
}
void to_json(JsonValueScope &jv, const td_api::backgrounds &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "backgrounds");
  jo << ctie("backgrounds", ToJson(object.backgrounds_));
}
void to_json(JsonValueScope &jv, const td_api::basicGroup &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "basicGroup");
  jo << ctie("id", ToJson(object.id_));
  jo << ctie("member_count", ToJson(object.member_count_));
  if (object.status_) {
    jo << ctie("status", ToJson(object.status_));
  }
  jo << ctie("is_active", ToJson(object.is_active_));
  jo << ctie("upgraded_to_supergroup_id", ToJson(object.upgraded_to_supergroup_id_));
}
void to_json(JsonValueScope &jv, const td_api::basicGroupFullInfo &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "basicGroupFullInfo");
  jo << ctie("description", ToJson(object.description_));
  jo << ctie("creator_user_id", ToJson(object.creator_user_id_));
  jo << ctie("members", ToJson(object.members_));
  jo << ctie("invite_link", ToJson(object.invite_link_));
}
void to_json(JsonValueScope &jv, const td_api::botCommand &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "botCommand");
  jo << ctie("command", ToJson(object.command_));
  jo << ctie("description", ToJson(object.description_));
}
void to_json(JsonValueScope &jv, const td_api::botInfo &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "botInfo");
  jo << ctie("description", ToJson(object.description_));
  jo << ctie("commands", ToJson(object.commands_));
}
void to_json(JsonValueScope &jv, const td_api::call &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "call");
  jo << ctie("id", ToJson(object.id_));
  jo << ctie("user_id", ToJson(object.user_id_));
  jo << ctie("is_outgoing", ToJson(object.is_outgoing_));
  if (object.state_) {
    jo << ctie("state", ToJson(object.state_));
  }
}
void to_json(JsonValueScope &jv, const td_api::callConnection &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "callConnection");
  jo << ctie("id", ToJson(JsonInt64{object.id_}));
  jo << ctie("ip", ToJson(object.ip_));
  jo << ctie("ipv6", ToJson(object.ipv6_));
  jo << ctie("port", ToJson(object.port_));
  jo << ctie("peer_tag", ToJson(base64_encode(object.peer_tag_)));
}
void to_json(JsonValueScope &jv, const td_api::CallDiscardReason &object) {
  td_api::downcast_call(const_cast<td_api::CallDiscardReason &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::callDiscardReasonEmpty &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "callDiscardReasonEmpty");
}
void to_json(JsonValueScope &jv, const td_api::callDiscardReasonMissed &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "callDiscardReasonMissed");
}
void to_json(JsonValueScope &jv, const td_api::callDiscardReasonDeclined &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "callDiscardReasonDeclined");
}
void to_json(JsonValueScope &jv, const td_api::callDiscardReasonDisconnected &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "callDiscardReasonDisconnected");
}
void to_json(JsonValueScope &jv, const td_api::callDiscardReasonHungUp &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "callDiscardReasonHungUp");
}
void to_json(JsonValueScope &jv, const td_api::callId &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "callId");
  jo << ctie("id", ToJson(object.id_));
}
void to_json(JsonValueScope &jv, const td_api::callProtocol &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "callProtocol");
  jo << ctie("udp_p2p", ToJson(object.udp_p2p_));
  jo << ctie("udp_reflector", ToJson(object.udp_reflector_));
  jo << ctie("min_layer", ToJson(object.min_layer_));
  jo << ctie("max_layer", ToJson(object.max_layer_));
}
void to_json(JsonValueScope &jv, const td_api::CallState &object) {
  td_api::downcast_call(const_cast<td_api::CallState &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::callStatePending &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "callStatePending");
  jo << ctie("is_created", ToJson(object.is_created_));
  jo << ctie("is_received", ToJson(object.is_received_));
}
void to_json(JsonValueScope &jv, const td_api::callStateExchangingKeys &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "callStateExchangingKeys");
}
void to_json(JsonValueScope &jv, const td_api::callStateReady &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "callStateReady");
  if (object.protocol_) {
    jo << ctie("protocol", ToJson(object.protocol_));
  }
  jo << ctie("connections", ToJson(object.connections_));
  jo << ctie("config", ToJson(object.config_));
  jo << ctie("encryption_key", ToJson(base64_encode(object.encryption_key_)));
  jo << ctie("emojis", ToJson(object.emojis_));
  jo << ctie("allow_p2p", ToJson(object.allow_p2p_));
}
void to_json(JsonValueScope &jv, const td_api::callStateHangingUp &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "callStateHangingUp");
}
void to_json(JsonValueScope &jv, const td_api::callStateDiscarded &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "callStateDiscarded");
  if (object.reason_) {
    jo << ctie("reason", ToJson(object.reason_));
  }
  jo << ctie("need_rating", ToJson(object.need_rating_));
  jo << ctie("need_debug_information", ToJson(object.need_debug_information_));
}
void to_json(JsonValueScope &jv, const td_api::callStateError &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "callStateError");
  if (object.error_) {
    jo << ctie("error", ToJson(object.error_));
  }
}
void to_json(JsonValueScope &jv, const td_api::callbackQueryAnswer &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "callbackQueryAnswer");
  jo << ctie("text", ToJson(object.text_));
  jo << ctie("show_alert", ToJson(object.show_alert_));
  jo << ctie("url", ToJson(object.url_));
}
void to_json(JsonValueScope &jv, const td_api::CallbackQueryPayload &object) {
  td_api::downcast_call(const_cast<td_api::CallbackQueryPayload &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::callbackQueryPayloadData &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "callbackQueryPayloadData");
  jo << ctie("data", ToJson(base64_encode(object.data_)));
}
void to_json(JsonValueScope &jv, const td_api::callbackQueryPayloadGame &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "callbackQueryPayloadGame");
  jo << ctie("game_short_name", ToJson(object.game_short_name_));
}
void to_json(JsonValueScope &jv, const td_api::chat &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chat");
  jo << ctie("id", ToJson(object.id_));
  if (object.type_) {
    jo << ctie("type", ToJson(object.type_));
  }
  jo << ctie("title", ToJson(object.title_));
  if (object.photo_) {
    jo << ctie("photo", ToJson(object.photo_));
  }
  if (object.permissions_) {
    jo << ctie("permissions", ToJson(object.permissions_));
  }
  if (object.last_message_) {
    jo << ctie("last_message", ToJson(object.last_message_));
  }
  jo << ctie("order", ToJson(JsonInt64{object.order_}));
  jo << ctie("is_pinned", ToJson(object.is_pinned_));
  jo << ctie("is_marked_as_unread", ToJson(object.is_marked_as_unread_));
  jo << ctie("is_sponsored", ToJson(object.is_sponsored_));
  jo << ctie("can_be_deleted_only_for_self", ToJson(object.can_be_deleted_only_for_self_));
  jo << ctie("can_be_deleted_for_all_users", ToJson(object.can_be_deleted_for_all_users_));
  jo << ctie("can_be_reported", ToJson(object.can_be_reported_));
  jo << ctie("default_disable_notification", ToJson(object.default_disable_notification_));
  jo << ctie("unread_count", ToJson(object.unread_count_));
  jo << ctie("last_read_inbox_message_id", ToJson(object.last_read_inbox_message_id_));
  jo << ctie("last_read_outbox_message_id", ToJson(object.last_read_outbox_message_id_));
  jo << ctie("unread_mention_count", ToJson(object.unread_mention_count_));
  if (object.notification_settings_) {
    jo << ctie("notification_settings", ToJson(object.notification_settings_));
  }
  jo << ctie("pinned_message_id", ToJson(object.pinned_message_id_));
  jo << ctie("reply_markup_message_id", ToJson(object.reply_markup_message_id_));
  if (object.draft_message_) {
    jo << ctie("draft_message", ToJson(object.draft_message_));
  }
  jo << ctie("client_data", ToJson(object.client_data_));
}
void to_json(JsonValueScope &jv, const td_api::ChatAction &object) {
  td_api::downcast_call(const_cast<td_api::ChatAction &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::chatActionTyping &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatActionTyping");
}
void to_json(JsonValueScope &jv, const td_api::chatActionRecordingVideo &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatActionRecordingVideo");
}
void to_json(JsonValueScope &jv, const td_api::chatActionUploadingVideo &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatActionUploadingVideo");
  jo << ctie("progress", ToJson(object.progress_));
}
void to_json(JsonValueScope &jv, const td_api::chatActionRecordingVoiceNote &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatActionRecordingVoiceNote");
}
void to_json(JsonValueScope &jv, const td_api::chatActionUploadingVoiceNote &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatActionUploadingVoiceNote");
  jo << ctie("progress", ToJson(object.progress_));
}
void to_json(JsonValueScope &jv, const td_api::chatActionUploadingPhoto &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatActionUploadingPhoto");
  jo << ctie("progress", ToJson(object.progress_));
}
void to_json(JsonValueScope &jv, const td_api::chatActionUploadingDocument &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatActionUploadingDocument");
  jo << ctie("progress", ToJson(object.progress_));
}
void to_json(JsonValueScope &jv, const td_api::chatActionChoosingLocation &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatActionChoosingLocation");
}
void to_json(JsonValueScope &jv, const td_api::chatActionChoosingContact &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatActionChoosingContact");
}
void to_json(JsonValueScope &jv, const td_api::chatActionStartPlayingGame &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatActionStartPlayingGame");
}
void to_json(JsonValueScope &jv, const td_api::chatActionRecordingVideoNote &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatActionRecordingVideoNote");
}
void to_json(JsonValueScope &jv, const td_api::chatActionUploadingVideoNote &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatActionUploadingVideoNote");
  jo << ctie("progress", ToJson(object.progress_));
}
void to_json(JsonValueScope &jv, const td_api::chatActionCancel &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatActionCancel");
}
void to_json(JsonValueScope &jv, const td_api::chatEvent &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatEvent");
  jo << ctie("id", ToJson(JsonInt64{object.id_}));
  jo << ctie("date", ToJson(object.date_));
  jo << ctie("user_id", ToJson(object.user_id_));
  if (object.action_) {
    jo << ctie("action", ToJson(object.action_));
  }
}
void to_json(JsonValueScope &jv, const td_api::ChatEventAction &object) {
  td_api::downcast_call(const_cast<td_api::ChatEventAction &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::chatEventMessageEdited &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatEventMessageEdited");
  if (object.old_message_) {
    jo << ctie("old_message", ToJson(object.old_message_));
  }
  if (object.new_message_) {
    jo << ctie("new_message", ToJson(object.new_message_));
  }
}
void to_json(JsonValueScope &jv, const td_api::chatEventMessageDeleted &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatEventMessageDeleted");
  if (object.message_) {
    jo << ctie("message", ToJson(object.message_));
  }
}
void to_json(JsonValueScope &jv, const td_api::chatEventPollStopped &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatEventPollStopped");
  if (object.message_) {
    jo << ctie("message", ToJson(object.message_));
  }
}
void to_json(JsonValueScope &jv, const td_api::chatEventMessagePinned &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatEventMessagePinned");
  if (object.message_) {
    jo << ctie("message", ToJson(object.message_));
  }
}
void to_json(JsonValueScope &jv, const td_api::chatEventMessageUnpinned &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatEventMessageUnpinned");
}
void to_json(JsonValueScope &jv, const td_api::chatEventMemberJoined &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatEventMemberJoined");
}
void to_json(JsonValueScope &jv, const td_api::chatEventMemberLeft &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatEventMemberLeft");
}
void to_json(JsonValueScope &jv, const td_api::chatEventMemberInvited &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatEventMemberInvited");
  jo << ctie("user_id", ToJson(object.user_id_));
  if (object.status_) {
    jo << ctie("status", ToJson(object.status_));
  }
}
void to_json(JsonValueScope &jv, const td_api::chatEventMemberPromoted &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatEventMemberPromoted");
  jo << ctie("user_id", ToJson(object.user_id_));
  if (object.old_status_) {
    jo << ctie("old_status", ToJson(object.old_status_));
  }
  if (object.new_status_) {
    jo << ctie("new_status", ToJson(object.new_status_));
  }
}
void to_json(JsonValueScope &jv, const td_api::chatEventMemberRestricted &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatEventMemberRestricted");
  jo << ctie("user_id", ToJson(object.user_id_));
  if (object.old_status_) {
    jo << ctie("old_status", ToJson(object.old_status_));
  }
  if (object.new_status_) {
    jo << ctie("new_status", ToJson(object.new_status_));
  }
}
void to_json(JsonValueScope &jv, const td_api::chatEventTitleChanged &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatEventTitleChanged");
  jo << ctie("old_title", ToJson(object.old_title_));
  jo << ctie("new_title", ToJson(object.new_title_));
}
void to_json(JsonValueScope &jv, const td_api::chatEventPermissionsChanged &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatEventPermissionsChanged");
  if (object.old_permissions_) {
    jo << ctie("old_permissions", ToJson(object.old_permissions_));
  }
  if (object.new_permissions_) {
    jo << ctie("new_permissions", ToJson(object.new_permissions_));
  }
}
void to_json(JsonValueScope &jv, const td_api::chatEventDescriptionChanged &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatEventDescriptionChanged");
  jo << ctie("old_description", ToJson(object.old_description_));
  jo << ctie("new_description", ToJson(object.new_description_));
}
void to_json(JsonValueScope &jv, const td_api::chatEventUsernameChanged &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatEventUsernameChanged");
  jo << ctie("old_username", ToJson(object.old_username_));
  jo << ctie("new_username", ToJson(object.new_username_));
}
void to_json(JsonValueScope &jv, const td_api::chatEventPhotoChanged &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatEventPhotoChanged");
  if (object.old_photo_) {
    jo << ctie("old_photo", ToJson(object.old_photo_));
  }
  if (object.new_photo_) {
    jo << ctie("new_photo", ToJson(object.new_photo_));
  }
}
void to_json(JsonValueScope &jv, const td_api::chatEventInvitesToggled &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatEventInvitesToggled");
  jo << ctie("can_invite_users", ToJson(object.can_invite_users_));
}
void to_json(JsonValueScope &jv, const td_api::chatEventSignMessagesToggled &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatEventSignMessagesToggled");
  jo << ctie("sign_messages", ToJson(object.sign_messages_));
}
void to_json(JsonValueScope &jv, const td_api::chatEventStickerSetChanged &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatEventStickerSetChanged");
  jo << ctie("old_sticker_set_id", ToJson(JsonInt64{object.old_sticker_set_id_}));
  jo << ctie("new_sticker_set_id", ToJson(JsonInt64{object.new_sticker_set_id_}));
}
void to_json(JsonValueScope &jv, const td_api::chatEventIsAllHistoryAvailableToggled &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatEventIsAllHistoryAvailableToggled");
  jo << ctie("is_all_history_available", ToJson(object.is_all_history_available_));
}
void to_json(JsonValueScope &jv, const td_api::chatEvents &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatEvents");
  jo << ctie("events", ToJson(object.events_));
}
void to_json(JsonValueScope &jv, const td_api::chatInviteLink &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatInviteLink");
  jo << ctie("invite_link", ToJson(object.invite_link_));
}
void to_json(JsonValueScope &jv, const td_api::chatInviteLinkInfo &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatInviteLinkInfo");
  jo << ctie("chat_id", ToJson(object.chat_id_));
  if (object.type_) {
    jo << ctie("type", ToJson(object.type_));
  }
  jo << ctie("title", ToJson(object.title_));
  if (object.photo_) {
    jo << ctie("photo", ToJson(object.photo_));
  }
  jo << ctie("member_count", ToJson(object.member_count_));
  jo << ctie("member_user_ids", ToJson(object.member_user_ids_));
  jo << ctie("is_public", ToJson(object.is_public_));
}
void to_json(JsonValueScope &jv, const td_api::chatMember &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatMember");
  jo << ctie("user_id", ToJson(object.user_id_));
  jo << ctie("inviter_user_id", ToJson(object.inviter_user_id_));
  jo << ctie("joined_chat_date", ToJson(object.joined_chat_date_));
  if (object.status_) {
    jo << ctie("status", ToJson(object.status_));
  }
  if (object.bot_info_) {
    jo << ctie("bot_info", ToJson(object.bot_info_));
  }
}
void to_json(JsonValueScope &jv, const td_api::ChatMemberStatus &object) {
  td_api::downcast_call(const_cast<td_api::ChatMemberStatus &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::chatMemberStatusCreator &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatMemberStatusCreator");
  jo << ctie("is_member", ToJson(object.is_member_));
}
void to_json(JsonValueScope &jv, const td_api::chatMemberStatusAdministrator &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatMemberStatusAdministrator");
  jo << ctie("can_be_edited", ToJson(object.can_be_edited_));
  jo << ctie("can_change_info", ToJson(object.can_change_info_));
  jo << ctie("can_post_messages", ToJson(object.can_post_messages_));
  jo << ctie("can_edit_messages", ToJson(object.can_edit_messages_));
  jo << ctie("can_delete_messages", ToJson(object.can_delete_messages_));
  jo << ctie("can_invite_users", ToJson(object.can_invite_users_));
  jo << ctie("can_restrict_members", ToJson(object.can_restrict_members_));
  jo << ctie("can_pin_messages", ToJson(object.can_pin_messages_));
  jo << ctie("can_promote_members", ToJson(object.can_promote_members_));
}
void to_json(JsonValueScope &jv, const td_api::chatMemberStatusMember &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatMemberStatusMember");
}
void to_json(JsonValueScope &jv, const td_api::chatMemberStatusRestricted &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatMemberStatusRestricted");
  jo << ctie("is_member", ToJson(object.is_member_));
  jo << ctie("restricted_until_date", ToJson(object.restricted_until_date_));
  if (object.permissions_) {
    jo << ctie("permissions", ToJson(object.permissions_));
  }
}
void to_json(JsonValueScope &jv, const td_api::chatMemberStatusLeft &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatMemberStatusLeft");
}
void to_json(JsonValueScope &jv, const td_api::chatMemberStatusBanned &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatMemberStatusBanned");
  jo << ctie("banned_until_date", ToJson(object.banned_until_date_));
}
void to_json(JsonValueScope &jv, const td_api::chatMembers &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatMembers");
  jo << ctie("total_count", ToJson(object.total_count_));
  jo << ctie("members", ToJson(object.members_));
}
void to_json(JsonValueScope &jv, const td_api::chatNotificationSettings &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatNotificationSettings");
  jo << ctie("use_default_mute_for", ToJson(object.use_default_mute_for_));
  jo << ctie("mute_for", ToJson(object.mute_for_));
  jo << ctie("use_default_sound", ToJson(object.use_default_sound_));
  jo << ctie("sound", ToJson(object.sound_));
  jo << ctie("use_default_show_preview", ToJson(object.use_default_show_preview_));
  jo << ctie("show_preview", ToJson(object.show_preview_));
  jo << ctie("use_default_disable_pinned_message_notifications", ToJson(object.use_default_disable_pinned_message_notifications_));
  jo << ctie("disable_pinned_message_notifications", ToJson(object.disable_pinned_message_notifications_));
  jo << ctie("use_default_disable_mention_notifications", ToJson(object.use_default_disable_mention_notifications_));
  jo << ctie("disable_mention_notifications", ToJson(object.disable_mention_notifications_));
}
void to_json(JsonValueScope &jv, const td_api::chatPermissions &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatPermissions");
  jo << ctie("can_send_messages", ToJson(object.can_send_messages_));
  jo << ctie("can_send_media_messages", ToJson(object.can_send_media_messages_));
  jo << ctie("can_send_polls", ToJson(object.can_send_polls_));
  jo << ctie("can_send_other_messages", ToJson(object.can_send_other_messages_));
  jo << ctie("can_add_web_page_previews", ToJson(object.can_add_web_page_previews_));
  jo << ctie("can_change_info", ToJson(object.can_change_info_));
  jo << ctie("can_invite_users", ToJson(object.can_invite_users_));
  jo << ctie("can_pin_messages", ToJson(object.can_pin_messages_));
}
void to_json(JsonValueScope &jv, const td_api::chatPhoto &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatPhoto");
  if (object.small_) {
    jo << ctie("small", ToJson(object.small_));
  }
  if (object.big_) {
    jo << ctie("big", ToJson(object.big_));
  }
}
void to_json(JsonValueScope &jv, const td_api::chatReportSpamState &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatReportSpamState");
  jo << ctie("can_report_spam", ToJson(object.can_report_spam_));
}
void to_json(JsonValueScope &jv, const td_api::ChatType &object) {
  td_api::downcast_call(const_cast<td_api::ChatType &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::chatTypePrivate &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatTypePrivate");
  jo << ctie("user_id", ToJson(object.user_id_));
}
void to_json(JsonValueScope &jv, const td_api::chatTypeBasicGroup &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatTypeBasicGroup");
  jo << ctie("basic_group_id", ToJson(object.basic_group_id_));
}
void to_json(JsonValueScope &jv, const td_api::chatTypeSupergroup &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatTypeSupergroup");
  jo << ctie("supergroup_id", ToJson(object.supergroup_id_));
  jo << ctie("is_channel", ToJson(object.is_channel_));
}
void to_json(JsonValueScope &jv, const td_api::chatTypeSecret &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chatTypeSecret");
  jo << ctie("secret_chat_id", ToJson(object.secret_chat_id_));
  jo << ctie("user_id", ToJson(object.user_id_));
}
void to_json(JsonValueScope &jv, const td_api::chats &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "chats");
  jo << ctie("chat_ids", ToJson(object.chat_ids_));
}
void to_json(JsonValueScope &jv, const td_api::CheckChatUsernameResult &object) {
  td_api::downcast_call(const_cast<td_api::CheckChatUsernameResult &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::checkChatUsernameResultOk &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "checkChatUsernameResultOk");
}
void to_json(JsonValueScope &jv, const td_api::checkChatUsernameResultUsernameInvalid &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "checkChatUsernameResultUsernameInvalid");
}
void to_json(JsonValueScope &jv, const td_api::checkChatUsernameResultUsernameOccupied &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "checkChatUsernameResultUsernameOccupied");
}
void to_json(JsonValueScope &jv, const td_api::checkChatUsernameResultPublicChatsTooMuch &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "checkChatUsernameResultPublicChatsTooMuch");
}
void to_json(JsonValueScope &jv, const td_api::checkChatUsernameResultPublicGroupsUnavailable &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "checkChatUsernameResultPublicGroupsUnavailable");
}
void to_json(JsonValueScope &jv, const td_api::connectedWebsite &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "connectedWebsite");
  jo << ctie("id", ToJson(JsonInt64{object.id_}));
  jo << ctie("domain_name", ToJson(object.domain_name_));
  jo << ctie("bot_user_id", ToJson(object.bot_user_id_));
  jo << ctie("browser", ToJson(object.browser_));
  jo << ctie("platform", ToJson(object.platform_));
  jo << ctie("log_in_date", ToJson(object.log_in_date_));
  jo << ctie("last_active_date", ToJson(object.last_active_date_));
  jo << ctie("ip", ToJson(object.ip_));
  jo << ctie("location", ToJson(object.location_));
}
void to_json(JsonValueScope &jv, const td_api::connectedWebsites &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "connectedWebsites");
  jo << ctie("websites", ToJson(object.websites_));
}
void to_json(JsonValueScope &jv, const td_api::ConnectionState &object) {
  td_api::downcast_call(const_cast<td_api::ConnectionState &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::connectionStateWaitingForNetwork &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "connectionStateWaitingForNetwork");
}
void to_json(JsonValueScope &jv, const td_api::connectionStateConnectingToProxy &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "connectionStateConnectingToProxy");
}
void to_json(JsonValueScope &jv, const td_api::connectionStateConnecting &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "connectionStateConnecting");
}
void to_json(JsonValueScope &jv, const td_api::connectionStateUpdating &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "connectionStateUpdating");
}
void to_json(JsonValueScope &jv, const td_api::connectionStateReady &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "connectionStateReady");
}
void to_json(JsonValueScope &jv, const td_api::contact &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "contact");
  jo << ctie("phone_number", ToJson(object.phone_number_));
  jo << ctie("first_name", ToJson(object.first_name_));
  jo << ctie("last_name", ToJson(object.last_name_));
  jo << ctie("vcard", ToJson(object.vcard_));
  jo << ctie("user_id", ToJson(object.user_id_));
}
void to_json(JsonValueScope &jv, const td_api::count &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "count");
  jo << ctie("count", ToJson(object.count_));
}
void to_json(JsonValueScope &jv, const td_api::customRequestResult &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "customRequestResult");
  jo << ctie("result", ToJson(object.result_));
}
void to_json(JsonValueScope &jv, const td_api::databaseStatistics &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "databaseStatistics");
  jo << ctie("statistics", ToJson(object.statistics_));
}
void to_json(JsonValueScope &jv, const td_api::date &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "date");
  jo << ctie("day", ToJson(object.day_));
  jo << ctie("month", ToJson(object.month_));
  jo << ctie("year", ToJson(object.year_));
}
void to_json(JsonValueScope &jv, const td_api::datedFile &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "datedFile");
  if (object.file_) {
    jo << ctie("file", ToJson(object.file_));
  }
  jo << ctie("date", ToJson(object.date_));
}
void to_json(JsonValueScope &jv, const td_api::deepLinkInfo &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "deepLinkInfo");
  if (object.text_) {
    jo << ctie("text", ToJson(object.text_));
  }
  jo << ctie("need_update_application", ToJson(object.need_update_application_));
}
void to_json(JsonValueScope &jv, const td_api::document &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "document");
  jo << ctie("file_name", ToJson(object.file_name_));
  jo << ctie("mime_type", ToJson(object.mime_type_));
  if (object.minithumbnail_) {
    jo << ctie("minithumbnail", ToJson(object.minithumbnail_));
  }
  if (object.thumbnail_) {
    jo << ctie("thumbnail", ToJson(object.thumbnail_));
  }
  if (object.document_) {
    jo << ctie("document", ToJson(object.document_));
  }
}
void to_json(JsonValueScope &jv, const td_api::draftMessage &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "draftMessage");
  jo << ctie("reply_to_message_id", ToJson(object.reply_to_message_id_));
  if (object.input_message_text_) {
    jo << ctie("input_message_text", ToJson(object.input_message_text_));
  }
}
void to_json(JsonValueScope &jv, const td_api::emailAddressAuthenticationCodeInfo &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "emailAddressAuthenticationCodeInfo");
  jo << ctie("email_address_pattern", ToJson(object.email_address_pattern_));
  jo << ctie("length", ToJson(object.length_));
}
void to_json(JsonValueScope &jv, const td_api::emojis &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "emojis");
  jo << ctie("emojis", ToJson(object.emojis_));
}
void to_json(JsonValueScope &jv, const td_api::encryptedCredentials &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "encryptedCredentials");
  jo << ctie("data", ToJson(base64_encode(object.data_)));
  jo << ctie("hash", ToJson(base64_encode(object.hash_)));
  jo << ctie("secret", ToJson(base64_encode(object.secret_)));
}
void to_json(JsonValueScope &jv, const td_api::encryptedPassportElement &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "encryptedPassportElement");
  if (object.type_) {
    jo << ctie("type", ToJson(object.type_));
  }
  jo << ctie("data", ToJson(base64_encode(object.data_)));
  if (object.front_side_) {
    jo << ctie("front_side", ToJson(object.front_side_));
  }
  if (object.reverse_side_) {
    jo << ctie("reverse_side", ToJson(object.reverse_side_));
  }
  if (object.selfie_) {
    jo << ctie("selfie", ToJson(object.selfie_));
  }
  jo << ctie("translation", ToJson(object.translation_));
  jo << ctie("files", ToJson(object.files_));
  jo << ctie("value", ToJson(object.value_));
  jo << ctie("hash", ToJson(object.hash_));
}
void to_json(JsonValueScope &jv, const td_api::error &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "error");
  jo << ctie("code", ToJson(object.code_));
  jo << ctie("message", ToJson(object.message_));
}
void to_json(JsonValueScope &jv, const td_api::file &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "file");
  jo << ctie("id", ToJson(object.id_));
  jo << ctie("size", ToJson(object.size_));
  jo << ctie("expected_size", ToJson(object.expected_size_));
  if (object.local_) {
    jo << ctie("local", ToJson(object.local_));
  }
  if (object.remote_) {
    jo << ctie("remote", ToJson(object.remote_));
  }
}
void to_json(JsonValueScope &jv, const td_api::filePart &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "filePart");
  jo << ctie("data", ToJson(base64_encode(object.data_)));
}
void to_json(JsonValueScope &jv, const td_api::FileType &object) {
  td_api::downcast_call(const_cast<td_api::FileType &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::fileTypeNone &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "fileTypeNone");
}
void to_json(JsonValueScope &jv, const td_api::fileTypeAnimation &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "fileTypeAnimation");
}
void to_json(JsonValueScope &jv, const td_api::fileTypeAudio &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "fileTypeAudio");
}
void to_json(JsonValueScope &jv, const td_api::fileTypeDocument &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "fileTypeDocument");
}
void to_json(JsonValueScope &jv, const td_api::fileTypePhoto &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "fileTypePhoto");
}
void to_json(JsonValueScope &jv, const td_api::fileTypeProfilePhoto &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "fileTypeProfilePhoto");
}
void to_json(JsonValueScope &jv, const td_api::fileTypeSecret &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "fileTypeSecret");
}
void to_json(JsonValueScope &jv, const td_api::fileTypeSecretThumbnail &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "fileTypeSecretThumbnail");
}
void to_json(JsonValueScope &jv, const td_api::fileTypeSecure &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "fileTypeSecure");
}
void to_json(JsonValueScope &jv, const td_api::fileTypeSticker &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "fileTypeSticker");
}
void to_json(JsonValueScope &jv, const td_api::fileTypeThumbnail &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "fileTypeThumbnail");
}
void to_json(JsonValueScope &jv, const td_api::fileTypeUnknown &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "fileTypeUnknown");
}
void to_json(JsonValueScope &jv, const td_api::fileTypeVideo &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "fileTypeVideo");
}
void to_json(JsonValueScope &jv, const td_api::fileTypeVideoNote &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "fileTypeVideoNote");
}
void to_json(JsonValueScope &jv, const td_api::fileTypeVoiceNote &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "fileTypeVoiceNote");
}
void to_json(JsonValueScope &jv, const td_api::fileTypeWallpaper &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "fileTypeWallpaper");
}
void to_json(JsonValueScope &jv, const td_api::formattedText &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "formattedText");
  jo << ctie("text", ToJson(object.text_));
  jo << ctie("entities", ToJson(object.entities_));
}
void to_json(JsonValueScope &jv, const td_api::foundMessages &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "foundMessages");
  jo << ctie("messages", ToJson(object.messages_));
  jo << ctie("next_from_search_id", ToJson(JsonInt64{object.next_from_search_id_}));
}
void to_json(JsonValueScope &jv, const td_api::game &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "game");
  jo << ctie("id", ToJson(JsonInt64{object.id_}));
  jo << ctie("short_name", ToJson(object.short_name_));
  jo << ctie("title", ToJson(object.title_));
  if (object.text_) {
    jo << ctie("text", ToJson(object.text_));
  }
  jo << ctie("description", ToJson(object.description_));
  if (object.photo_) {
    jo << ctie("photo", ToJson(object.photo_));
  }
  if (object.animation_) {
    jo << ctie("animation", ToJson(object.animation_));
  }
}
void to_json(JsonValueScope &jv, const td_api::gameHighScore &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "gameHighScore");
  jo << ctie("position", ToJson(object.position_));
  jo << ctie("user_id", ToJson(object.user_id_));
  jo << ctie("score", ToJson(object.score_));
}
void to_json(JsonValueScope &jv, const td_api::gameHighScores &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "gameHighScores");
  jo << ctie("scores", ToJson(object.scores_));
}
void to_json(JsonValueScope &jv, const td_api::hashtags &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "hashtags");
  jo << ctie("hashtags", ToJson(object.hashtags_));
}
void to_json(JsonValueScope &jv, const td_api::httpUrl &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "httpUrl");
  jo << ctie("url", ToJson(object.url_));
}
void to_json(JsonValueScope &jv, const td_api::identityDocument &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "identityDocument");
  jo << ctie("number", ToJson(object.number_));
  if (object.expiry_date_) {
    jo << ctie("expiry_date", ToJson(object.expiry_date_));
  }
  if (object.front_side_) {
    jo << ctie("front_side", ToJson(object.front_side_));
  }
  if (object.reverse_side_) {
    jo << ctie("reverse_side", ToJson(object.reverse_side_));
  }
  if (object.selfie_) {
    jo << ctie("selfie", ToJson(object.selfie_));
  }
  jo << ctie("translation", ToJson(object.translation_));
}
void to_json(JsonValueScope &jv, const td_api::importedContacts &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "importedContacts");
  jo << ctie("user_ids", ToJson(object.user_ids_));
  jo << ctie("importer_count", ToJson(object.importer_count_));
}
void to_json(JsonValueScope &jv, const td_api::inlineKeyboardButton &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inlineKeyboardButton");
  jo << ctie("text", ToJson(object.text_));
  if (object.type_) {
    jo << ctie("type", ToJson(object.type_));
  }
}
void to_json(JsonValueScope &jv, const td_api::InlineKeyboardButtonType &object) {
  td_api::downcast_call(const_cast<td_api::InlineKeyboardButtonType &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::inlineKeyboardButtonTypeUrl &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inlineKeyboardButtonTypeUrl");
  jo << ctie("url", ToJson(object.url_));
}
void to_json(JsonValueScope &jv, const td_api::inlineKeyboardButtonTypeLoginUrl &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inlineKeyboardButtonTypeLoginUrl");
  jo << ctie("url", ToJson(object.url_));
  jo << ctie("id", ToJson(object.id_));
  jo << ctie("forward_text", ToJson(object.forward_text_));
}
void to_json(JsonValueScope &jv, const td_api::inlineKeyboardButtonTypeCallback &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inlineKeyboardButtonTypeCallback");
  jo << ctie("data", ToJson(base64_encode(object.data_)));
}
void to_json(JsonValueScope &jv, const td_api::inlineKeyboardButtonTypeCallbackGame &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inlineKeyboardButtonTypeCallbackGame");
}
void to_json(JsonValueScope &jv, const td_api::inlineKeyboardButtonTypeSwitchInline &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inlineKeyboardButtonTypeSwitchInline");
  jo << ctie("query", ToJson(object.query_));
  jo << ctie("in_current_chat", ToJson(object.in_current_chat_));
}
void to_json(JsonValueScope &jv, const td_api::inlineKeyboardButtonTypeBuy &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inlineKeyboardButtonTypeBuy");
}
void to_json(JsonValueScope &jv, const td_api::InlineQueryResult &object) {
  td_api::downcast_call(const_cast<td_api::InlineQueryResult &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::inlineQueryResultArticle &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inlineQueryResultArticle");
  jo << ctie("id", ToJson(object.id_));
  jo << ctie("url", ToJson(object.url_));
  jo << ctie("hide_url", ToJson(object.hide_url_));
  jo << ctie("title", ToJson(object.title_));
  jo << ctie("description", ToJson(object.description_));
  if (object.thumbnail_) {
    jo << ctie("thumbnail", ToJson(object.thumbnail_));
  }
}
void to_json(JsonValueScope &jv, const td_api::inlineQueryResultContact &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inlineQueryResultContact");
  jo << ctie("id", ToJson(object.id_));
  if (object.contact_) {
    jo << ctie("contact", ToJson(object.contact_));
  }
  if (object.thumbnail_) {
    jo << ctie("thumbnail", ToJson(object.thumbnail_));
  }
}
void to_json(JsonValueScope &jv, const td_api::inlineQueryResultLocation &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inlineQueryResultLocation");
  jo << ctie("id", ToJson(object.id_));
  if (object.location_) {
    jo << ctie("location", ToJson(object.location_));
  }
  jo << ctie("title", ToJson(object.title_));
  if (object.thumbnail_) {
    jo << ctie("thumbnail", ToJson(object.thumbnail_));
  }
}
void to_json(JsonValueScope &jv, const td_api::inlineQueryResultVenue &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inlineQueryResultVenue");
  jo << ctie("id", ToJson(object.id_));
  if (object.venue_) {
    jo << ctie("venue", ToJson(object.venue_));
  }
  if (object.thumbnail_) {
    jo << ctie("thumbnail", ToJson(object.thumbnail_));
  }
}
void to_json(JsonValueScope &jv, const td_api::inlineQueryResultGame &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inlineQueryResultGame");
  jo << ctie("id", ToJson(object.id_));
  if (object.game_) {
    jo << ctie("game", ToJson(object.game_));
  }
}
void to_json(JsonValueScope &jv, const td_api::inlineQueryResultAnimation &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inlineQueryResultAnimation");
  jo << ctie("id", ToJson(object.id_));
  if (object.animation_) {
    jo << ctie("animation", ToJson(object.animation_));
  }
  jo << ctie("title", ToJson(object.title_));
}
void to_json(JsonValueScope &jv, const td_api::inlineQueryResultAudio &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inlineQueryResultAudio");
  jo << ctie("id", ToJson(object.id_));
  if (object.audio_) {
    jo << ctie("audio", ToJson(object.audio_));
  }
}
void to_json(JsonValueScope &jv, const td_api::inlineQueryResultDocument &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inlineQueryResultDocument");
  jo << ctie("id", ToJson(object.id_));
  if (object.document_) {
    jo << ctie("document", ToJson(object.document_));
  }
  jo << ctie("title", ToJson(object.title_));
  jo << ctie("description", ToJson(object.description_));
}
void to_json(JsonValueScope &jv, const td_api::inlineQueryResultPhoto &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inlineQueryResultPhoto");
  jo << ctie("id", ToJson(object.id_));
  if (object.photo_) {
    jo << ctie("photo", ToJson(object.photo_));
  }
  jo << ctie("title", ToJson(object.title_));
  jo << ctie("description", ToJson(object.description_));
}
void to_json(JsonValueScope &jv, const td_api::inlineQueryResultSticker &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inlineQueryResultSticker");
  jo << ctie("id", ToJson(object.id_));
  if (object.sticker_) {
    jo << ctie("sticker", ToJson(object.sticker_));
  }
}
void to_json(JsonValueScope &jv, const td_api::inlineQueryResultVideo &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inlineQueryResultVideo");
  jo << ctie("id", ToJson(object.id_));
  if (object.video_) {
    jo << ctie("video", ToJson(object.video_));
  }
  jo << ctie("title", ToJson(object.title_));
  jo << ctie("description", ToJson(object.description_));
}
void to_json(JsonValueScope &jv, const td_api::inlineQueryResultVoiceNote &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inlineQueryResultVoiceNote");
  jo << ctie("id", ToJson(object.id_));
  if (object.voice_note_) {
    jo << ctie("voice_note", ToJson(object.voice_note_));
  }
  jo << ctie("title", ToJson(object.title_));
}
void to_json(JsonValueScope &jv, const td_api::inlineQueryResults &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inlineQueryResults");
  jo << ctie("inline_query_id", ToJson(JsonInt64{object.inline_query_id_}));
  jo << ctie("next_offset", ToJson(object.next_offset_));
  jo << ctie("results", ToJson(object.results_));
  jo << ctie("switch_pm_text", ToJson(object.switch_pm_text_));
  jo << ctie("switch_pm_parameter", ToJson(object.switch_pm_parameter_));
}
void to_json(JsonValueScope &jv, const td_api::InputFile &object) {
  td_api::downcast_call(const_cast<td_api::InputFile &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::inputFileId &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inputFileId");
  jo << ctie("id", ToJson(object.id_));
}
void to_json(JsonValueScope &jv, const td_api::inputFileRemote &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inputFileRemote");
  jo << ctie("id", ToJson(object.id_));
}
void to_json(JsonValueScope &jv, const td_api::inputFileLocal &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inputFileLocal");
  jo << ctie("path", ToJson(object.path_));
}
void to_json(JsonValueScope &jv, const td_api::inputFileGenerated &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inputFileGenerated");
  jo << ctie("original_path", ToJson(object.original_path_));
  jo << ctie("conversion", ToJson(object.conversion_));
  jo << ctie("expected_size", ToJson(object.expected_size_));
}
void to_json(JsonValueScope &jv, const td_api::InputMessageContent &object) {
  td_api::downcast_call(const_cast<td_api::InputMessageContent &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::inputMessageText &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inputMessageText");
  if (object.text_) {
    jo << ctie("text", ToJson(object.text_));
  }
  jo << ctie("disable_web_page_preview", ToJson(object.disable_web_page_preview_));
  jo << ctie("clear_draft", ToJson(object.clear_draft_));
}
void to_json(JsonValueScope &jv, const td_api::inputMessageAnimation &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inputMessageAnimation");
  if (object.animation_) {
    jo << ctie("animation", ToJson(object.animation_));
  }
  if (object.thumbnail_) {
    jo << ctie("thumbnail", ToJson(object.thumbnail_));
  }
  jo << ctie("duration", ToJson(object.duration_));
  jo << ctie("width", ToJson(object.width_));
  jo << ctie("height", ToJson(object.height_));
  if (object.caption_) {
    jo << ctie("caption", ToJson(object.caption_));
  }
}
void to_json(JsonValueScope &jv, const td_api::inputMessageAudio &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inputMessageAudio");
  if (object.audio_) {
    jo << ctie("audio", ToJson(object.audio_));
  }
  if (object.album_cover_thumbnail_) {
    jo << ctie("album_cover_thumbnail", ToJson(object.album_cover_thumbnail_));
  }
  jo << ctie("duration", ToJson(object.duration_));
  jo << ctie("title", ToJson(object.title_));
  jo << ctie("performer", ToJson(object.performer_));
  if (object.caption_) {
    jo << ctie("caption", ToJson(object.caption_));
  }
}
void to_json(JsonValueScope &jv, const td_api::inputMessageDocument &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inputMessageDocument");
  if (object.document_) {
    jo << ctie("document", ToJson(object.document_));
  }
  if (object.thumbnail_) {
    jo << ctie("thumbnail", ToJson(object.thumbnail_));
  }
  if (object.caption_) {
    jo << ctie("caption", ToJson(object.caption_));
  }
}
void to_json(JsonValueScope &jv, const td_api::inputMessagePhoto &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inputMessagePhoto");
  if (object.photo_) {
    jo << ctie("photo", ToJson(object.photo_));
  }
  if (object.thumbnail_) {
    jo << ctie("thumbnail", ToJson(object.thumbnail_));
  }
  jo << ctie("added_sticker_file_ids", ToJson(object.added_sticker_file_ids_));
  jo << ctie("width", ToJson(object.width_));
  jo << ctie("height", ToJson(object.height_));
  if (object.caption_) {
    jo << ctie("caption", ToJson(object.caption_));
  }
  jo << ctie("ttl", ToJson(object.ttl_));
}
void to_json(JsonValueScope &jv, const td_api::inputMessageSticker &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inputMessageSticker");
  if (object.sticker_) {
    jo << ctie("sticker", ToJson(object.sticker_));
  }
  if (object.thumbnail_) {
    jo << ctie("thumbnail", ToJson(object.thumbnail_));
  }
  jo << ctie("width", ToJson(object.width_));
  jo << ctie("height", ToJson(object.height_));
}
void to_json(JsonValueScope &jv, const td_api::inputMessageVideo &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inputMessageVideo");
  if (object.video_) {
    jo << ctie("video", ToJson(object.video_));
  }
  if (object.thumbnail_) {
    jo << ctie("thumbnail", ToJson(object.thumbnail_));
  }
  jo << ctie("added_sticker_file_ids", ToJson(object.added_sticker_file_ids_));
  jo << ctie("duration", ToJson(object.duration_));
  jo << ctie("width", ToJson(object.width_));
  jo << ctie("height", ToJson(object.height_));
  jo << ctie("supports_streaming", ToJson(object.supports_streaming_));
  if (object.caption_) {
    jo << ctie("caption", ToJson(object.caption_));
  }
  jo << ctie("ttl", ToJson(object.ttl_));
}
void to_json(JsonValueScope &jv, const td_api::inputMessageVideoNote &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inputMessageVideoNote");
  if (object.video_note_) {
    jo << ctie("video_note", ToJson(object.video_note_));
  }
  if (object.thumbnail_) {
    jo << ctie("thumbnail", ToJson(object.thumbnail_));
  }
  jo << ctie("duration", ToJson(object.duration_));
  jo << ctie("length", ToJson(object.length_));
}
void to_json(JsonValueScope &jv, const td_api::inputMessageVoiceNote &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inputMessageVoiceNote");
  if (object.voice_note_) {
    jo << ctie("voice_note", ToJson(object.voice_note_));
  }
  jo << ctie("duration", ToJson(object.duration_));
  jo << ctie("waveform", ToJson(base64_encode(object.waveform_)));
  if (object.caption_) {
    jo << ctie("caption", ToJson(object.caption_));
  }
}
void to_json(JsonValueScope &jv, const td_api::inputMessageLocation &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inputMessageLocation");
  if (object.location_) {
    jo << ctie("location", ToJson(object.location_));
  }
  jo << ctie("live_period", ToJson(object.live_period_));
}
void to_json(JsonValueScope &jv, const td_api::inputMessageVenue &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inputMessageVenue");
  if (object.venue_) {
    jo << ctie("venue", ToJson(object.venue_));
  }
}
void to_json(JsonValueScope &jv, const td_api::inputMessageContact &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inputMessageContact");
  if (object.contact_) {
    jo << ctie("contact", ToJson(object.contact_));
  }
}
void to_json(JsonValueScope &jv, const td_api::inputMessageGame &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inputMessageGame");
  jo << ctie("bot_user_id", ToJson(object.bot_user_id_));
  jo << ctie("game_short_name", ToJson(object.game_short_name_));
}
void to_json(JsonValueScope &jv, const td_api::inputMessageInvoice &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inputMessageInvoice");
  if (object.invoice_) {
    jo << ctie("invoice", ToJson(object.invoice_));
  }
  jo << ctie("title", ToJson(object.title_));
  jo << ctie("description", ToJson(object.description_));
  jo << ctie("photo_url", ToJson(object.photo_url_));
  jo << ctie("photo_size", ToJson(object.photo_size_));
  jo << ctie("photo_width", ToJson(object.photo_width_));
  jo << ctie("photo_height", ToJson(object.photo_height_));
  jo << ctie("payload", ToJson(base64_encode(object.payload_)));
  jo << ctie("provider_token", ToJson(object.provider_token_));
  jo << ctie("provider_data", ToJson(object.provider_data_));
  jo << ctie("start_parameter", ToJson(object.start_parameter_));
}
void to_json(JsonValueScope &jv, const td_api::inputMessagePoll &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inputMessagePoll");
  jo << ctie("question", ToJson(object.question_));
  jo << ctie("options", ToJson(object.options_));
}
void to_json(JsonValueScope &jv, const td_api::inputMessageForwarded &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inputMessageForwarded");
  jo << ctie("from_chat_id", ToJson(object.from_chat_id_));
  jo << ctie("message_id", ToJson(object.message_id_));
  jo << ctie("in_game_share", ToJson(object.in_game_share_));
  jo << ctie("send_copy", ToJson(object.send_copy_));
  jo << ctie("remove_caption", ToJson(object.remove_caption_));
}
void to_json(JsonValueScope &jv, const td_api::inputThumbnail &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "inputThumbnail");
  if (object.thumbnail_) {
    jo << ctie("thumbnail", ToJson(object.thumbnail_));
  }
  jo << ctie("width", ToJson(object.width_));
  jo << ctie("height", ToJson(object.height_));
}
void to_json(JsonValueScope &jv, const td_api::invoice &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "invoice");
  jo << ctie("currency", ToJson(object.currency_));
  jo << ctie("price_parts", ToJson(object.price_parts_));
  jo << ctie("is_test", ToJson(object.is_test_));
  jo << ctie("need_name", ToJson(object.need_name_));
  jo << ctie("need_phone_number", ToJson(object.need_phone_number_));
  jo << ctie("need_email_address", ToJson(object.need_email_address_));
  jo << ctie("need_shipping_address", ToJson(object.need_shipping_address_));
  jo << ctie("send_phone_number_to_provider", ToJson(object.send_phone_number_to_provider_));
  jo << ctie("send_email_address_to_provider", ToJson(object.send_email_address_to_provider_));
  jo << ctie("is_flexible", ToJson(object.is_flexible_));
}
void to_json(JsonValueScope &jv, const td_api::jsonObjectMember &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "jsonObjectMember");
  jo << ctie("key", ToJson(object.key_));
  if (object.value_) {
    jo << ctie("value", ToJson(object.value_));
  }
}
void to_json(JsonValueScope &jv, const td_api::JsonValue &object) {
  td_api::downcast_call(const_cast<td_api::JsonValue &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::jsonValueNull &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "jsonValueNull");
}
void to_json(JsonValueScope &jv, const td_api::jsonValueBoolean &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "jsonValueBoolean");
  jo << ctie("value", ToJson(object.value_));
}
void to_json(JsonValueScope &jv, const td_api::jsonValueNumber &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "jsonValueNumber");
  jo << ctie("value", ToJson(object.value_));
}
void to_json(JsonValueScope &jv, const td_api::jsonValueString &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "jsonValueString");
  jo << ctie("value", ToJson(object.value_));
}
void to_json(JsonValueScope &jv, const td_api::jsonValueArray &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "jsonValueArray");
  jo << ctie("values", ToJson(object.values_));
}
void to_json(JsonValueScope &jv, const td_api::jsonValueObject &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "jsonValueObject");
  jo << ctie("members", ToJson(object.members_));
}
void to_json(JsonValueScope &jv, const td_api::keyboardButton &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "keyboardButton");
  jo << ctie("text", ToJson(object.text_));
  if (object.type_) {
    jo << ctie("type", ToJson(object.type_));
  }
}
void to_json(JsonValueScope &jv, const td_api::KeyboardButtonType &object) {
  td_api::downcast_call(const_cast<td_api::KeyboardButtonType &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::keyboardButtonTypeText &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "keyboardButtonTypeText");
}
void to_json(JsonValueScope &jv, const td_api::keyboardButtonTypeRequestPhoneNumber &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "keyboardButtonTypeRequestPhoneNumber");
}
void to_json(JsonValueScope &jv, const td_api::keyboardButtonTypeRequestLocation &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "keyboardButtonTypeRequestLocation");
}
void to_json(JsonValueScope &jv, const td_api::labeledPricePart &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "labeledPricePart");
  jo << ctie("label", ToJson(object.label_));
  jo << ctie("amount", ToJson(object.amount_));
}
void to_json(JsonValueScope &jv, const td_api::languagePackInfo &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "languagePackInfo");
  jo << ctie("id", ToJson(object.id_));
  jo << ctie("base_language_pack_id", ToJson(object.base_language_pack_id_));
  jo << ctie("name", ToJson(object.name_));
  jo << ctie("native_name", ToJson(object.native_name_));
  jo << ctie("plural_code", ToJson(object.plural_code_));
  jo << ctie("is_official", ToJson(object.is_official_));
  jo << ctie("is_rtl", ToJson(object.is_rtl_));
  jo << ctie("is_beta", ToJson(object.is_beta_));
  jo << ctie("is_installed", ToJson(object.is_installed_));
  jo << ctie("total_string_count", ToJson(object.total_string_count_));
  jo << ctie("translated_string_count", ToJson(object.translated_string_count_));
  jo << ctie("local_string_count", ToJson(object.local_string_count_));
  jo << ctie("translation_url", ToJson(object.translation_url_));
}
void to_json(JsonValueScope &jv, const td_api::languagePackString &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "languagePackString");
  jo << ctie("key", ToJson(object.key_));
  if (object.value_) {
    jo << ctie("value", ToJson(object.value_));
  }
}
void to_json(JsonValueScope &jv, const td_api::LanguagePackStringValue &object) {
  td_api::downcast_call(const_cast<td_api::LanguagePackStringValue &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::languagePackStringValueOrdinary &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "languagePackStringValueOrdinary");
  jo << ctie("value", ToJson(object.value_));
}
void to_json(JsonValueScope &jv, const td_api::languagePackStringValuePluralized &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "languagePackStringValuePluralized");
  jo << ctie("zero_value", ToJson(object.zero_value_));
  jo << ctie("one_value", ToJson(object.one_value_));
  jo << ctie("two_value", ToJson(object.two_value_));
  jo << ctie("few_value", ToJson(object.few_value_));
  jo << ctie("many_value", ToJson(object.many_value_));
  jo << ctie("other_value", ToJson(object.other_value_));
}
void to_json(JsonValueScope &jv, const td_api::languagePackStringValueDeleted &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "languagePackStringValueDeleted");
}
void to_json(JsonValueScope &jv, const td_api::languagePackStrings &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "languagePackStrings");
  jo << ctie("strings", ToJson(object.strings_));
}
void to_json(JsonValueScope &jv, const td_api::LinkState &object) {
  td_api::downcast_call(const_cast<td_api::LinkState &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::linkStateNone &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "linkStateNone");
}
void to_json(JsonValueScope &jv, const td_api::linkStateKnowsPhoneNumber &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "linkStateKnowsPhoneNumber");
}
void to_json(JsonValueScope &jv, const td_api::linkStateIsContact &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "linkStateIsContact");
}
void to_json(JsonValueScope &jv, const td_api::localFile &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "localFile");
  jo << ctie("path", ToJson(object.path_));
  jo << ctie("can_be_downloaded", ToJson(object.can_be_downloaded_));
  jo << ctie("can_be_deleted", ToJson(object.can_be_deleted_));
  jo << ctie("is_downloading_active", ToJson(object.is_downloading_active_));
  jo << ctie("is_downloading_completed", ToJson(object.is_downloading_completed_));
  jo << ctie("download_offset", ToJson(object.download_offset_));
  jo << ctie("downloaded_prefix_size", ToJson(object.downloaded_prefix_size_));
  jo << ctie("downloaded_size", ToJson(object.downloaded_size_));
}
void to_json(JsonValueScope &jv, const td_api::localizationTargetInfo &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "localizationTargetInfo");
  jo << ctie("language_packs", ToJson(object.language_packs_));
}
void to_json(JsonValueScope &jv, const td_api::location &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "location");
  jo << ctie("latitude", ToJson(object.latitude_));
  jo << ctie("longitude", ToJson(object.longitude_));
}
void to_json(JsonValueScope &jv, const td_api::LogStream &object) {
  td_api::downcast_call(const_cast<td_api::LogStream &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::logStreamDefault &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "logStreamDefault");
}
void to_json(JsonValueScope &jv, const td_api::logStreamFile &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "logStreamFile");
  jo << ctie("path", ToJson(object.path_));
  jo << ctie("max_file_size", ToJson(object.max_file_size_));
}
void to_json(JsonValueScope &jv, const td_api::logStreamEmpty &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "logStreamEmpty");
}
void to_json(JsonValueScope &jv, const td_api::logTags &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "logTags");
  jo << ctie("tags", ToJson(object.tags_));
}
void to_json(JsonValueScope &jv, const td_api::logVerbosityLevel &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "logVerbosityLevel");
  jo << ctie("verbosity_level", ToJson(object.verbosity_level_));
}
void to_json(JsonValueScope &jv, const td_api::MaskPoint &object) {
  td_api::downcast_call(const_cast<td_api::MaskPoint &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::maskPointForehead &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "maskPointForehead");
}
void to_json(JsonValueScope &jv, const td_api::maskPointEyes &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "maskPointEyes");
}
void to_json(JsonValueScope &jv, const td_api::maskPointMouth &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "maskPointMouth");
}
void to_json(JsonValueScope &jv, const td_api::maskPointChin &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "maskPointChin");
}
void to_json(JsonValueScope &jv, const td_api::maskPosition &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "maskPosition");
  if (object.point_) {
    jo << ctie("point", ToJson(object.point_));
  }
  jo << ctie("x_shift", ToJson(object.x_shift_));
  jo << ctie("y_shift", ToJson(object.y_shift_));
  jo << ctie("scale", ToJson(object.scale_));
}
void to_json(JsonValueScope &jv, const td_api::message &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "message");
  jo << ctie("id", ToJson(object.id_));
  jo << ctie("sender_user_id", ToJson(object.sender_user_id_));
  jo << ctie("chat_id", ToJson(object.chat_id_));
  if (object.sending_state_) {
    jo << ctie("sending_state", ToJson(object.sending_state_));
  }
  jo << ctie("is_outgoing", ToJson(object.is_outgoing_));
  jo << ctie("can_be_edited", ToJson(object.can_be_edited_));
  jo << ctie("can_be_forwarded", ToJson(object.can_be_forwarded_));
  jo << ctie("can_be_deleted_only_for_self", ToJson(object.can_be_deleted_only_for_self_));
  jo << ctie("can_be_deleted_for_all_users", ToJson(object.can_be_deleted_for_all_users_));
  jo << ctie("is_channel_post", ToJson(object.is_channel_post_));
  jo << ctie("contains_unread_mention", ToJson(object.contains_unread_mention_));
  jo << ctie("date", ToJson(object.date_));
  jo << ctie("edit_date", ToJson(object.edit_date_));
  if (object.forward_info_) {
    jo << ctie("forward_info", ToJson(object.forward_info_));
  }
  jo << ctie("reply_to_message_id", ToJson(object.reply_to_message_id_));
  jo << ctie("ttl", ToJson(object.ttl_));
  jo << ctie("ttl_expires_in", ToJson(object.ttl_expires_in_));
  jo << ctie("via_bot_user_id", ToJson(object.via_bot_user_id_));
  jo << ctie("author_signature", ToJson(object.author_signature_));
  jo << ctie("views", ToJson(object.views_));
  jo << ctie("media_album_id", ToJson(JsonInt64{object.media_album_id_}));
  if (object.content_) {
    jo << ctie("content", ToJson(object.content_));
  }
  if (object.reply_markup_) {
    jo << ctie("reply_markup", ToJson(object.reply_markup_));
  }
}
void to_json(JsonValueScope &jv, const td_api::MessageContent &object) {
  td_api::downcast_call(const_cast<td_api::MessageContent &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::messageText &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageText");
  if (object.text_) {
    jo << ctie("text", ToJson(object.text_));
  }
  if (object.web_page_) {
    jo << ctie("web_page", ToJson(object.web_page_));
  }
}
void to_json(JsonValueScope &jv, const td_api::messageAnimation &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageAnimation");
  if (object.animation_) {
    jo << ctie("animation", ToJson(object.animation_));
  }
  if (object.caption_) {
    jo << ctie("caption", ToJson(object.caption_));
  }
  jo << ctie("is_secret", ToJson(object.is_secret_));
}
void to_json(JsonValueScope &jv, const td_api::messageAudio &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageAudio");
  if (object.audio_) {
    jo << ctie("audio", ToJson(object.audio_));
  }
  if (object.caption_) {
    jo << ctie("caption", ToJson(object.caption_));
  }
}
void to_json(JsonValueScope &jv, const td_api::messageDocument &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageDocument");
  if (object.document_) {
    jo << ctie("document", ToJson(object.document_));
  }
  if (object.caption_) {
    jo << ctie("caption", ToJson(object.caption_));
  }
}
void to_json(JsonValueScope &jv, const td_api::messagePhoto &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messagePhoto");
  if (object.photo_) {
    jo << ctie("photo", ToJson(object.photo_));
  }
  if (object.caption_) {
    jo << ctie("caption", ToJson(object.caption_));
  }
  jo << ctie("is_secret", ToJson(object.is_secret_));
}
void to_json(JsonValueScope &jv, const td_api::messageExpiredPhoto &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageExpiredPhoto");
}
void to_json(JsonValueScope &jv, const td_api::messageSticker &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageSticker");
  if (object.sticker_) {
    jo << ctie("sticker", ToJson(object.sticker_));
  }
}
void to_json(JsonValueScope &jv, const td_api::messageVideo &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageVideo");
  if (object.video_) {
    jo << ctie("video", ToJson(object.video_));
  }
  if (object.caption_) {
    jo << ctie("caption", ToJson(object.caption_));
  }
  jo << ctie("is_secret", ToJson(object.is_secret_));
}
void to_json(JsonValueScope &jv, const td_api::messageExpiredVideo &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageExpiredVideo");
}
void to_json(JsonValueScope &jv, const td_api::messageVideoNote &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageVideoNote");
  if (object.video_note_) {
    jo << ctie("video_note", ToJson(object.video_note_));
  }
  jo << ctie("is_viewed", ToJson(object.is_viewed_));
  jo << ctie("is_secret", ToJson(object.is_secret_));
}
void to_json(JsonValueScope &jv, const td_api::messageVoiceNote &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageVoiceNote");
  if (object.voice_note_) {
    jo << ctie("voice_note", ToJson(object.voice_note_));
  }
  if (object.caption_) {
    jo << ctie("caption", ToJson(object.caption_));
  }
  jo << ctie("is_listened", ToJson(object.is_listened_));
}
void to_json(JsonValueScope &jv, const td_api::messageLocation &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageLocation");
  if (object.location_) {
    jo << ctie("location", ToJson(object.location_));
  }
  jo << ctie("live_period", ToJson(object.live_period_));
  jo << ctie("expires_in", ToJson(object.expires_in_));
}
void to_json(JsonValueScope &jv, const td_api::messageVenue &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageVenue");
  if (object.venue_) {
    jo << ctie("venue", ToJson(object.venue_));
  }
}
void to_json(JsonValueScope &jv, const td_api::messageContact &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageContact");
  if (object.contact_) {
    jo << ctie("contact", ToJson(object.contact_));
  }
}
void to_json(JsonValueScope &jv, const td_api::messageGame &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageGame");
  if (object.game_) {
    jo << ctie("game", ToJson(object.game_));
  }
}
void to_json(JsonValueScope &jv, const td_api::messagePoll &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messagePoll");
  if (object.poll_) {
    jo << ctie("poll", ToJson(object.poll_));
  }
}
void to_json(JsonValueScope &jv, const td_api::messageInvoice &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageInvoice");
  jo << ctie("title", ToJson(object.title_));
  jo << ctie("description", ToJson(object.description_));
  if (object.photo_) {
    jo << ctie("photo", ToJson(object.photo_));
  }
  jo << ctie("currency", ToJson(object.currency_));
  jo << ctie("total_amount", ToJson(object.total_amount_));
  jo << ctie("start_parameter", ToJson(object.start_parameter_));
  jo << ctie("is_test", ToJson(object.is_test_));
  jo << ctie("need_shipping_address", ToJson(object.need_shipping_address_));
  jo << ctie("receipt_message_id", ToJson(object.receipt_message_id_));
}
void to_json(JsonValueScope &jv, const td_api::messageCall &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageCall");
  if (object.discard_reason_) {
    jo << ctie("discard_reason", ToJson(object.discard_reason_));
  }
  jo << ctie("duration", ToJson(object.duration_));
}
void to_json(JsonValueScope &jv, const td_api::messageBasicGroupChatCreate &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageBasicGroupChatCreate");
  jo << ctie("title", ToJson(object.title_));
  jo << ctie("member_user_ids", ToJson(object.member_user_ids_));
}
void to_json(JsonValueScope &jv, const td_api::messageSupergroupChatCreate &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageSupergroupChatCreate");
  jo << ctie("title", ToJson(object.title_));
}
void to_json(JsonValueScope &jv, const td_api::messageChatChangeTitle &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageChatChangeTitle");
  jo << ctie("title", ToJson(object.title_));
}
void to_json(JsonValueScope &jv, const td_api::messageChatChangePhoto &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageChatChangePhoto");
  if (object.photo_) {
    jo << ctie("photo", ToJson(object.photo_));
  }
}
void to_json(JsonValueScope &jv, const td_api::messageChatDeletePhoto &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageChatDeletePhoto");
}
void to_json(JsonValueScope &jv, const td_api::messageChatAddMembers &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageChatAddMembers");
  jo << ctie("member_user_ids", ToJson(object.member_user_ids_));
}
void to_json(JsonValueScope &jv, const td_api::messageChatJoinByLink &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageChatJoinByLink");
}
void to_json(JsonValueScope &jv, const td_api::messageChatDeleteMember &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageChatDeleteMember");
  jo << ctie("user_id", ToJson(object.user_id_));
}
void to_json(JsonValueScope &jv, const td_api::messageChatUpgradeTo &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageChatUpgradeTo");
  jo << ctie("supergroup_id", ToJson(object.supergroup_id_));
}
void to_json(JsonValueScope &jv, const td_api::messageChatUpgradeFrom &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageChatUpgradeFrom");
  jo << ctie("title", ToJson(object.title_));
  jo << ctie("basic_group_id", ToJson(object.basic_group_id_));
}
void to_json(JsonValueScope &jv, const td_api::messagePinMessage &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messagePinMessage");
  jo << ctie("message_id", ToJson(object.message_id_));
}
void to_json(JsonValueScope &jv, const td_api::messageScreenshotTaken &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageScreenshotTaken");
}
void to_json(JsonValueScope &jv, const td_api::messageChatSetTtl &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageChatSetTtl");
  jo << ctie("ttl", ToJson(object.ttl_));
}
void to_json(JsonValueScope &jv, const td_api::messageCustomServiceAction &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageCustomServiceAction");
  jo << ctie("text", ToJson(object.text_));
}
void to_json(JsonValueScope &jv, const td_api::messageGameScore &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageGameScore");
  jo << ctie("game_message_id", ToJson(object.game_message_id_));
  jo << ctie("game_id", ToJson(JsonInt64{object.game_id_}));
  jo << ctie("score", ToJson(object.score_));
}
void to_json(JsonValueScope &jv, const td_api::messagePaymentSuccessful &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messagePaymentSuccessful");
  jo << ctie("invoice_message_id", ToJson(object.invoice_message_id_));
  jo << ctie("currency", ToJson(object.currency_));
  jo << ctie("total_amount", ToJson(object.total_amount_));
}
void to_json(JsonValueScope &jv, const td_api::messagePaymentSuccessfulBot &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messagePaymentSuccessfulBot");
  jo << ctie("invoice_message_id", ToJson(object.invoice_message_id_));
  jo << ctie("currency", ToJson(object.currency_));
  jo << ctie("total_amount", ToJson(object.total_amount_));
  jo << ctie("invoice_payload", ToJson(base64_encode(object.invoice_payload_)));
  jo << ctie("shipping_option_id", ToJson(object.shipping_option_id_));
  if (object.order_info_) {
    jo << ctie("order_info", ToJson(object.order_info_));
  }
  jo << ctie("telegram_payment_charge_id", ToJson(object.telegram_payment_charge_id_));
  jo << ctie("provider_payment_charge_id", ToJson(object.provider_payment_charge_id_));
}
void to_json(JsonValueScope &jv, const td_api::messageContactRegistered &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageContactRegistered");
}
void to_json(JsonValueScope &jv, const td_api::messageWebsiteConnected &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageWebsiteConnected");
  jo << ctie("domain_name", ToJson(object.domain_name_));
}
void to_json(JsonValueScope &jv, const td_api::messagePassportDataSent &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messagePassportDataSent");
  jo << ctie("types", ToJson(object.types_));
}
void to_json(JsonValueScope &jv, const td_api::messagePassportDataReceived &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messagePassportDataReceived");
  jo << ctie("elements", ToJson(object.elements_));
  if (object.credentials_) {
    jo << ctie("credentials", ToJson(object.credentials_));
  }
}
void to_json(JsonValueScope &jv, const td_api::messageUnsupported &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageUnsupported");
}
void to_json(JsonValueScope &jv, const td_api::messageForwardInfo &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageForwardInfo");
  if (object.origin_) {
    jo << ctie("origin", ToJson(object.origin_));
  }
  jo << ctie("date", ToJson(object.date_));
  jo << ctie("from_chat_id", ToJson(object.from_chat_id_));
  jo << ctie("from_message_id", ToJson(object.from_message_id_));
}
void to_json(JsonValueScope &jv, const td_api::MessageForwardOrigin &object) {
  td_api::downcast_call(const_cast<td_api::MessageForwardOrigin &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::messageForwardOriginUser &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageForwardOriginUser");
  jo << ctie("sender_user_id", ToJson(object.sender_user_id_));
}
void to_json(JsonValueScope &jv, const td_api::messageForwardOriginHiddenUser &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageForwardOriginHiddenUser");
  jo << ctie("sender_name", ToJson(object.sender_name_));
}
void to_json(JsonValueScope &jv, const td_api::messageForwardOriginChannel &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageForwardOriginChannel");
  jo << ctie("chat_id", ToJson(object.chat_id_));
  jo << ctie("message_id", ToJson(object.message_id_));
  jo << ctie("author_signature", ToJson(object.author_signature_));
}
void to_json(JsonValueScope &jv, const td_api::messageLinkInfo &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageLinkInfo");
  jo << ctie("is_public", ToJson(object.is_public_));
  jo << ctie("chat_id", ToJson(object.chat_id_));
  if (object.message_) {
    jo << ctie("message", ToJson(object.message_));
  }
  jo << ctie("for_album", ToJson(object.for_album_));
}
void to_json(JsonValueScope &jv, const td_api::MessageSendingState &object) {
  td_api::downcast_call(const_cast<td_api::MessageSendingState &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::messageSendingStatePending &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageSendingStatePending");
}
void to_json(JsonValueScope &jv, const td_api::messageSendingStateFailed &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messageSendingStateFailed");
  jo << ctie("error_code", ToJson(object.error_code_));
  jo << ctie("error_message", ToJson(object.error_message_));
  jo << ctie("can_retry", ToJson(object.can_retry_));
  jo << ctie("retry_after", ToJson(object.retry_after_));
}
void to_json(JsonValueScope &jv, const td_api::messages &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "messages");
  jo << ctie("total_count", ToJson(object.total_count_));
  jo << ctie("messages", ToJson(object.messages_));
}
void to_json(JsonValueScope &jv, const td_api::minithumbnail &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "minithumbnail");
  jo << ctie("width", ToJson(object.width_));
  jo << ctie("height", ToJson(object.height_));
  jo << ctie("data", ToJson(base64_encode(object.data_)));
}
void to_json(JsonValueScope &jv, const td_api::networkStatistics &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "networkStatistics");
  jo << ctie("since_date", ToJson(object.since_date_));
  jo << ctie("entries", ToJson(object.entries_));
}
void to_json(JsonValueScope &jv, const td_api::NetworkStatisticsEntry &object) {
  td_api::downcast_call(const_cast<td_api::NetworkStatisticsEntry &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::networkStatisticsEntryFile &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "networkStatisticsEntryFile");
  if (object.file_type_) {
    jo << ctie("file_type", ToJson(object.file_type_));
  }
  if (object.network_type_) {
    jo << ctie("network_type", ToJson(object.network_type_));
  }
  jo << ctie("sent_bytes", ToJson(object.sent_bytes_));
  jo << ctie("received_bytes", ToJson(object.received_bytes_));
}
void to_json(JsonValueScope &jv, const td_api::networkStatisticsEntryCall &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "networkStatisticsEntryCall");
  if (object.network_type_) {
    jo << ctie("network_type", ToJson(object.network_type_));
  }
  jo << ctie("sent_bytes", ToJson(object.sent_bytes_));
  jo << ctie("received_bytes", ToJson(object.received_bytes_));
  jo << ctie("duration", ToJson(object.duration_));
}
void to_json(JsonValueScope &jv, const td_api::NetworkType &object) {
  td_api::downcast_call(const_cast<td_api::NetworkType &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::networkTypeNone &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "networkTypeNone");
}
void to_json(JsonValueScope &jv, const td_api::networkTypeMobile &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "networkTypeMobile");
}
void to_json(JsonValueScope &jv, const td_api::networkTypeMobileRoaming &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "networkTypeMobileRoaming");
}
void to_json(JsonValueScope &jv, const td_api::networkTypeWiFi &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "networkTypeWiFi");
}
void to_json(JsonValueScope &jv, const td_api::networkTypeOther &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "networkTypeOther");
}
void to_json(JsonValueScope &jv, const td_api::notification &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "notification");
  jo << ctie("id", ToJson(object.id_));
  jo << ctie("date", ToJson(object.date_));
  if (object.type_) {
    jo << ctie("type", ToJson(object.type_));
  }
}
void to_json(JsonValueScope &jv, const td_api::notificationGroup &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "notificationGroup");
  jo << ctie("id", ToJson(object.id_));
  if (object.type_) {
    jo << ctie("type", ToJson(object.type_));
  }
  jo << ctie("chat_id", ToJson(object.chat_id_));
  jo << ctie("total_count", ToJson(object.total_count_));
  jo << ctie("notifications", ToJson(object.notifications_));
}
void to_json(JsonValueScope &jv, const td_api::NotificationGroupType &object) {
  td_api::downcast_call(const_cast<td_api::NotificationGroupType &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::notificationGroupTypeMessages &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "notificationGroupTypeMessages");
}
void to_json(JsonValueScope &jv, const td_api::notificationGroupTypeMentions &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "notificationGroupTypeMentions");
}
void to_json(JsonValueScope &jv, const td_api::notificationGroupTypeSecretChat &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "notificationGroupTypeSecretChat");
}
void to_json(JsonValueScope &jv, const td_api::notificationGroupTypeCalls &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "notificationGroupTypeCalls");
}
void to_json(JsonValueScope &jv, const td_api::NotificationSettingsScope &object) {
  td_api::downcast_call(const_cast<td_api::NotificationSettingsScope &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::notificationSettingsScopePrivateChats &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "notificationSettingsScopePrivateChats");
}
void to_json(JsonValueScope &jv, const td_api::notificationSettingsScopeGroupChats &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "notificationSettingsScopeGroupChats");
}
void to_json(JsonValueScope &jv, const td_api::notificationSettingsScopeChannelChats &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "notificationSettingsScopeChannelChats");
}
void to_json(JsonValueScope &jv, const td_api::NotificationType &object) {
  td_api::downcast_call(const_cast<td_api::NotificationType &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::notificationTypeNewMessage &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "notificationTypeNewMessage");
  if (object.message_) {
    jo << ctie("message", ToJson(object.message_));
  }
}
void to_json(JsonValueScope &jv, const td_api::notificationTypeNewSecretChat &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "notificationTypeNewSecretChat");
}
void to_json(JsonValueScope &jv, const td_api::notificationTypeNewCall &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "notificationTypeNewCall");
  jo << ctie("call_id", ToJson(object.call_id_));
}
void to_json(JsonValueScope &jv, const td_api::notificationTypeNewPushMessage &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "notificationTypeNewPushMessage");
  jo << ctie("message_id", ToJson(object.message_id_));
  jo << ctie("sender_user_id", ToJson(object.sender_user_id_));
  if (object.content_) {
    jo << ctie("content", ToJson(object.content_));
  }
}
void to_json(JsonValueScope &jv, const td_api::ok &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "ok");
}
void to_json(JsonValueScope &jv, const td_api::OptionValue &object) {
  td_api::downcast_call(const_cast<td_api::OptionValue &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::optionValueBoolean &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "optionValueBoolean");
  jo << ctie("value", ToJson(object.value_));
}
void to_json(JsonValueScope &jv, const td_api::optionValueEmpty &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "optionValueEmpty");
}
void to_json(JsonValueScope &jv, const td_api::optionValueInteger &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "optionValueInteger");
  jo << ctie("value", ToJson(object.value_));
}
void to_json(JsonValueScope &jv, const td_api::optionValueString &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "optionValueString");
  jo << ctie("value", ToJson(object.value_));
}
void to_json(JsonValueScope &jv, const td_api::orderInfo &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "orderInfo");
  jo << ctie("name", ToJson(object.name_));
  jo << ctie("phone_number", ToJson(object.phone_number_));
  jo << ctie("email_address", ToJson(object.email_address_));
  if (object.shipping_address_) {
    jo << ctie("shipping_address", ToJson(object.shipping_address_));
  }
}
void to_json(JsonValueScope &jv, const td_api::PageBlock &object) {
  td_api::downcast_call(const_cast<td_api::PageBlock &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::pageBlockTitle &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockTitle");
  if (object.title_) {
    jo << ctie("title", ToJson(object.title_));
  }
}
void to_json(JsonValueScope &jv, const td_api::pageBlockSubtitle &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockSubtitle");
  if (object.subtitle_) {
    jo << ctie("subtitle", ToJson(object.subtitle_));
  }
}
void to_json(JsonValueScope &jv, const td_api::pageBlockAuthorDate &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockAuthorDate");
  if (object.author_) {
    jo << ctie("author", ToJson(object.author_));
  }
  jo << ctie("publish_date", ToJson(object.publish_date_));
}
void to_json(JsonValueScope &jv, const td_api::pageBlockHeader &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockHeader");
  if (object.header_) {
    jo << ctie("header", ToJson(object.header_));
  }
}
void to_json(JsonValueScope &jv, const td_api::pageBlockSubheader &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockSubheader");
  if (object.subheader_) {
    jo << ctie("subheader", ToJson(object.subheader_));
  }
}
void to_json(JsonValueScope &jv, const td_api::pageBlockKicker &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockKicker");
  if (object.kicker_) {
    jo << ctie("kicker", ToJson(object.kicker_));
  }
}
void to_json(JsonValueScope &jv, const td_api::pageBlockParagraph &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockParagraph");
  if (object.text_) {
    jo << ctie("text", ToJson(object.text_));
  }
}
void to_json(JsonValueScope &jv, const td_api::pageBlockPreformatted &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockPreformatted");
  if (object.text_) {
    jo << ctie("text", ToJson(object.text_));
  }
  jo << ctie("language", ToJson(object.language_));
}
void to_json(JsonValueScope &jv, const td_api::pageBlockFooter &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockFooter");
  if (object.footer_) {
    jo << ctie("footer", ToJson(object.footer_));
  }
}
void to_json(JsonValueScope &jv, const td_api::pageBlockDivider &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockDivider");
}
void to_json(JsonValueScope &jv, const td_api::pageBlockAnchor &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockAnchor");
  jo << ctie("name", ToJson(object.name_));
}
void to_json(JsonValueScope &jv, const td_api::pageBlockList &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockList");
  jo << ctie("items", ToJson(object.items_));
}
void to_json(JsonValueScope &jv, const td_api::pageBlockBlockQuote &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockBlockQuote");
  if (object.text_) {
    jo << ctie("text", ToJson(object.text_));
  }
  if (object.credit_) {
    jo << ctie("credit", ToJson(object.credit_));
  }
}
void to_json(JsonValueScope &jv, const td_api::pageBlockPullQuote &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockPullQuote");
  if (object.text_) {
    jo << ctie("text", ToJson(object.text_));
  }
  if (object.credit_) {
    jo << ctie("credit", ToJson(object.credit_));
  }
}
void to_json(JsonValueScope &jv, const td_api::pageBlockAnimation &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockAnimation");
  if (object.animation_) {
    jo << ctie("animation", ToJson(object.animation_));
  }
  if (object.caption_) {
    jo << ctie("caption", ToJson(object.caption_));
  }
  jo << ctie("need_autoplay", ToJson(object.need_autoplay_));
}
void to_json(JsonValueScope &jv, const td_api::pageBlockAudio &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockAudio");
  if (object.audio_) {
    jo << ctie("audio", ToJson(object.audio_));
  }
  if (object.caption_) {
    jo << ctie("caption", ToJson(object.caption_));
  }
}
void to_json(JsonValueScope &jv, const td_api::pageBlockPhoto &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockPhoto");
  if (object.photo_) {
    jo << ctie("photo", ToJson(object.photo_));
  }
  if (object.caption_) {
    jo << ctie("caption", ToJson(object.caption_));
  }
  jo << ctie("url", ToJson(object.url_));
}
void to_json(JsonValueScope &jv, const td_api::pageBlockVideo &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockVideo");
  if (object.video_) {
    jo << ctie("video", ToJson(object.video_));
  }
  if (object.caption_) {
    jo << ctie("caption", ToJson(object.caption_));
  }
  jo << ctie("need_autoplay", ToJson(object.need_autoplay_));
  jo << ctie("is_looped", ToJson(object.is_looped_));
}
void to_json(JsonValueScope &jv, const td_api::pageBlockCover &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockCover");
  if (object.cover_) {
    jo << ctie("cover", ToJson(object.cover_));
  }
}
void to_json(JsonValueScope &jv, const td_api::pageBlockEmbedded &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockEmbedded");
  jo << ctie("url", ToJson(object.url_));
  jo << ctie("html", ToJson(object.html_));
  if (object.poster_photo_) {
    jo << ctie("poster_photo", ToJson(object.poster_photo_));
  }
  jo << ctie("width", ToJson(object.width_));
  jo << ctie("height", ToJson(object.height_));
  if (object.caption_) {
    jo << ctie("caption", ToJson(object.caption_));
  }
  jo << ctie("is_full_width", ToJson(object.is_full_width_));
  jo << ctie("allow_scrolling", ToJson(object.allow_scrolling_));
}
void to_json(JsonValueScope &jv, const td_api::pageBlockEmbeddedPost &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockEmbeddedPost");
  jo << ctie("url", ToJson(object.url_));
  jo << ctie("author", ToJson(object.author_));
  if (object.author_photo_) {
    jo << ctie("author_photo", ToJson(object.author_photo_));
  }
  jo << ctie("date", ToJson(object.date_));
  jo << ctie("page_blocks", ToJson(object.page_blocks_));
  if (object.caption_) {
    jo << ctie("caption", ToJson(object.caption_));
  }
}
void to_json(JsonValueScope &jv, const td_api::pageBlockCollage &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockCollage");
  jo << ctie("page_blocks", ToJson(object.page_blocks_));
  if (object.caption_) {
    jo << ctie("caption", ToJson(object.caption_));
  }
}
void to_json(JsonValueScope &jv, const td_api::pageBlockSlideshow &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockSlideshow");
  jo << ctie("page_blocks", ToJson(object.page_blocks_));
  if (object.caption_) {
    jo << ctie("caption", ToJson(object.caption_));
  }
}
void to_json(JsonValueScope &jv, const td_api::pageBlockChatLink &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockChatLink");
  jo << ctie("title", ToJson(object.title_));
  if (object.photo_) {
    jo << ctie("photo", ToJson(object.photo_));
  }
  jo << ctie("username", ToJson(object.username_));
}
void to_json(JsonValueScope &jv, const td_api::pageBlockTable &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockTable");
  if (object.caption_) {
    jo << ctie("caption", ToJson(object.caption_));
  }
  jo << ctie("cells", ToJson(object.cells_));
  jo << ctie("is_bordered", ToJson(object.is_bordered_));
  jo << ctie("is_striped", ToJson(object.is_striped_));
}
void to_json(JsonValueScope &jv, const td_api::pageBlockDetails &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockDetails");
  if (object.header_) {
    jo << ctie("header", ToJson(object.header_));
  }
  jo << ctie("page_blocks", ToJson(object.page_blocks_));
  jo << ctie("is_open", ToJson(object.is_open_));
}
void to_json(JsonValueScope &jv, const td_api::pageBlockRelatedArticles &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockRelatedArticles");
  if (object.header_) {
    jo << ctie("header", ToJson(object.header_));
  }
  jo << ctie("articles", ToJson(object.articles_));
}
void to_json(JsonValueScope &jv, const td_api::pageBlockMap &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockMap");
  if (object.location_) {
    jo << ctie("location", ToJson(object.location_));
  }
  jo << ctie("zoom", ToJson(object.zoom_));
  jo << ctie("width", ToJson(object.width_));
  jo << ctie("height", ToJson(object.height_));
  if (object.caption_) {
    jo << ctie("caption", ToJson(object.caption_));
  }
}
void to_json(JsonValueScope &jv, const td_api::pageBlockCaption &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockCaption");
  if (object.text_) {
    jo << ctie("text", ToJson(object.text_));
  }
  if (object.credit_) {
    jo << ctie("credit", ToJson(object.credit_));
  }
}
void to_json(JsonValueScope &jv, const td_api::PageBlockHorizontalAlignment &object) {
  td_api::downcast_call(const_cast<td_api::PageBlockHorizontalAlignment &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::pageBlockHorizontalAlignmentLeft &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockHorizontalAlignmentLeft");
}
void to_json(JsonValueScope &jv, const td_api::pageBlockHorizontalAlignmentCenter &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockHorizontalAlignmentCenter");
}
void to_json(JsonValueScope &jv, const td_api::pageBlockHorizontalAlignmentRight &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockHorizontalAlignmentRight");
}
void to_json(JsonValueScope &jv, const td_api::pageBlockListItem &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockListItem");
  jo << ctie("label", ToJson(object.label_));
  jo << ctie("page_blocks", ToJson(object.page_blocks_));
}
void to_json(JsonValueScope &jv, const td_api::pageBlockRelatedArticle &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockRelatedArticle");
  jo << ctie("url", ToJson(object.url_));
  jo << ctie("title", ToJson(object.title_));
  jo << ctie("description", ToJson(object.description_));
  if (object.photo_) {
    jo << ctie("photo", ToJson(object.photo_));
  }
  jo << ctie("author", ToJson(object.author_));
  jo << ctie("publish_date", ToJson(object.publish_date_));
}
void to_json(JsonValueScope &jv, const td_api::pageBlockTableCell &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockTableCell");
  if (object.text_) {
    jo << ctie("text", ToJson(object.text_));
  }
  jo << ctie("is_header", ToJson(object.is_header_));
  jo << ctie("colspan", ToJson(object.colspan_));
  jo << ctie("rowspan", ToJson(object.rowspan_));
  if (object.align_) {
    jo << ctie("align", ToJson(object.align_));
  }
  if (object.valign_) {
    jo << ctie("valign", ToJson(object.valign_));
  }
}
void to_json(JsonValueScope &jv, const td_api::PageBlockVerticalAlignment &object) {
  td_api::downcast_call(const_cast<td_api::PageBlockVerticalAlignment &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::pageBlockVerticalAlignmentTop &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockVerticalAlignmentTop");
}
void to_json(JsonValueScope &jv, const td_api::pageBlockVerticalAlignmentMiddle &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockVerticalAlignmentMiddle");
}
void to_json(JsonValueScope &jv, const td_api::pageBlockVerticalAlignmentBottom &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pageBlockVerticalAlignmentBottom");
}
void to_json(JsonValueScope &jv, const td_api::passportAuthorizationForm &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportAuthorizationForm");
  jo << ctie("id", ToJson(object.id_));
  jo << ctie("required_elements", ToJson(object.required_elements_));
  jo << ctie("privacy_policy_url", ToJson(object.privacy_policy_url_));
}
void to_json(JsonValueScope &jv, const td_api::PassportElement &object) {
  td_api::downcast_call(const_cast<td_api::PassportElement &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::passportElementPersonalDetails &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementPersonalDetails");
  if (object.personal_details_) {
    jo << ctie("personal_details", ToJson(object.personal_details_));
  }
}
void to_json(JsonValueScope &jv, const td_api::passportElementPassport &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementPassport");
  if (object.passport_) {
    jo << ctie("passport", ToJson(object.passport_));
  }
}
void to_json(JsonValueScope &jv, const td_api::passportElementDriverLicense &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementDriverLicense");
  if (object.driver_license_) {
    jo << ctie("driver_license", ToJson(object.driver_license_));
  }
}
void to_json(JsonValueScope &jv, const td_api::passportElementIdentityCard &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementIdentityCard");
  if (object.identity_card_) {
    jo << ctie("identity_card", ToJson(object.identity_card_));
  }
}
void to_json(JsonValueScope &jv, const td_api::passportElementInternalPassport &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementInternalPassport");
  if (object.internal_passport_) {
    jo << ctie("internal_passport", ToJson(object.internal_passport_));
  }
}
void to_json(JsonValueScope &jv, const td_api::passportElementAddress &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementAddress");
  if (object.address_) {
    jo << ctie("address", ToJson(object.address_));
  }
}
void to_json(JsonValueScope &jv, const td_api::passportElementUtilityBill &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementUtilityBill");
  if (object.utility_bill_) {
    jo << ctie("utility_bill", ToJson(object.utility_bill_));
  }
}
void to_json(JsonValueScope &jv, const td_api::passportElementBankStatement &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementBankStatement");
  if (object.bank_statement_) {
    jo << ctie("bank_statement", ToJson(object.bank_statement_));
  }
}
void to_json(JsonValueScope &jv, const td_api::passportElementRentalAgreement &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementRentalAgreement");
  if (object.rental_agreement_) {
    jo << ctie("rental_agreement", ToJson(object.rental_agreement_));
  }
}
void to_json(JsonValueScope &jv, const td_api::passportElementPassportRegistration &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementPassportRegistration");
  if (object.passport_registration_) {
    jo << ctie("passport_registration", ToJson(object.passport_registration_));
  }
}
void to_json(JsonValueScope &jv, const td_api::passportElementTemporaryRegistration &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementTemporaryRegistration");
  if (object.temporary_registration_) {
    jo << ctie("temporary_registration", ToJson(object.temporary_registration_));
  }
}
void to_json(JsonValueScope &jv, const td_api::passportElementPhoneNumber &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementPhoneNumber");
  jo << ctie("phone_number", ToJson(object.phone_number_));
}
void to_json(JsonValueScope &jv, const td_api::passportElementEmailAddress &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementEmailAddress");
  jo << ctie("email_address", ToJson(object.email_address_));
}
void to_json(JsonValueScope &jv, const td_api::passportElementError &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementError");
  if (object.type_) {
    jo << ctie("type", ToJson(object.type_));
  }
  jo << ctie("message", ToJson(object.message_));
  if (object.source_) {
    jo << ctie("source", ToJson(object.source_));
  }
}
void to_json(JsonValueScope &jv, const td_api::PassportElementErrorSource &object) {
  td_api::downcast_call(const_cast<td_api::PassportElementErrorSource &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::passportElementErrorSourceUnspecified &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementErrorSourceUnspecified");
}
void to_json(JsonValueScope &jv, const td_api::passportElementErrorSourceDataField &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementErrorSourceDataField");
  jo << ctie("field_name", ToJson(object.field_name_));
}
void to_json(JsonValueScope &jv, const td_api::passportElementErrorSourceFrontSide &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementErrorSourceFrontSide");
}
void to_json(JsonValueScope &jv, const td_api::passportElementErrorSourceReverseSide &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementErrorSourceReverseSide");
}
void to_json(JsonValueScope &jv, const td_api::passportElementErrorSourceSelfie &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementErrorSourceSelfie");
}
void to_json(JsonValueScope &jv, const td_api::passportElementErrorSourceTranslationFile &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementErrorSourceTranslationFile");
  jo << ctie("file_index", ToJson(object.file_index_));
}
void to_json(JsonValueScope &jv, const td_api::passportElementErrorSourceTranslationFiles &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementErrorSourceTranslationFiles");
}
void to_json(JsonValueScope &jv, const td_api::passportElementErrorSourceFile &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementErrorSourceFile");
  jo << ctie("file_index", ToJson(object.file_index_));
}
void to_json(JsonValueScope &jv, const td_api::passportElementErrorSourceFiles &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementErrorSourceFiles");
}
void to_json(JsonValueScope &jv, const td_api::PassportElementType &object) {
  td_api::downcast_call(const_cast<td_api::PassportElementType &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::passportElementTypePersonalDetails &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementTypePersonalDetails");
}
void to_json(JsonValueScope &jv, const td_api::passportElementTypePassport &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementTypePassport");
}
void to_json(JsonValueScope &jv, const td_api::passportElementTypeDriverLicense &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementTypeDriverLicense");
}
void to_json(JsonValueScope &jv, const td_api::passportElementTypeIdentityCard &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementTypeIdentityCard");
}
void to_json(JsonValueScope &jv, const td_api::passportElementTypeInternalPassport &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementTypeInternalPassport");
}
void to_json(JsonValueScope &jv, const td_api::passportElementTypeAddress &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementTypeAddress");
}
void to_json(JsonValueScope &jv, const td_api::passportElementTypeUtilityBill &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementTypeUtilityBill");
}
void to_json(JsonValueScope &jv, const td_api::passportElementTypeBankStatement &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementTypeBankStatement");
}
void to_json(JsonValueScope &jv, const td_api::passportElementTypeRentalAgreement &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementTypeRentalAgreement");
}
void to_json(JsonValueScope &jv, const td_api::passportElementTypePassportRegistration &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementTypePassportRegistration");
}
void to_json(JsonValueScope &jv, const td_api::passportElementTypeTemporaryRegistration &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementTypeTemporaryRegistration");
}
void to_json(JsonValueScope &jv, const td_api::passportElementTypePhoneNumber &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementTypePhoneNumber");
}
void to_json(JsonValueScope &jv, const td_api::passportElementTypeEmailAddress &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementTypeEmailAddress");
}
void to_json(JsonValueScope &jv, const td_api::passportElements &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElements");
  jo << ctie("elements", ToJson(object.elements_));
}
void to_json(JsonValueScope &jv, const td_api::passportElementsWithErrors &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportElementsWithErrors");
  jo << ctie("elements", ToJson(object.elements_));
  jo << ctie("errors", ToJson(object.errors_));
}
void to_json(JsonValueScope &jv, const td_api::passportRequiredElement &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportRequiredElement");
  jo << ctie("suitable_elements", ToJson(object.suitable_elements_));
}
void to_json(JsonValueScope &jv, const td_api::passportSuitableElement &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passportSuitableElement");
  if (object.type_) {
    jo << ctie("type", ToJson(object.type_));
  }
  jo << ctie("is_selfie_required", ToJson(object.is_selfie_required_));
  jo << ctie("is_translation_required", ToJson(object.is_translation_required_));
  jo << ctie("is_native_name_required", ToJson(object.is_native_name_required_));
}
void to_json(JsonValueScope &jv, const td_api::passwordState &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "passwordState");
  jo << ctie("has_password", ToJson(object.has_password_));
  jo << ctie("password_hint", ToJson(object.password_hint_));
  jo << ctie("has_recovery_email_address", ToJson(object.has_recovery_email_address_));
  jo << ctie("has_passport_data", ToJson(object.has_passport_data_));
  if (object.recovery_email_address_code_info_) {
    jo << ctie("recovery_email_address_code_info", ToJson(object.recovery_email_address_code_info_));
  }
}
void to_json(JsonValueScope &jv, const td_api::paymentForm &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "paymentForm");
  if (object.invoice_) {
    jo << ctie("invoice", ToJson(object.invoice_));
  }
  jo << ctie("url", ToJson(object.url_));
  if (object.payments_provider_) {
    jo << ctie("payments_provider", ToJson(object.payments_provider_));
  }
  if (object.saved_order_info_) {
    jo << ctie("saved_order_info", ToJson(object.saved_order_info_));
  }
  if (object.saved_credentials_) {
    jo << ctie("saved_credentials", ToJson(object.saved_credentials_));
  }
  jo << ctie("can_save_credentials", ToJson(object.can_save_credentials_));
  jo << ctie("need_password", ToJson(object.need_password_));
}
void to_json(JsonValueScope &jv, const td_api::paymentReceipt &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "paymentReceipt");
  jo << ctie("date", ToJson(object.date_));
  jo << ctie("payments_provider_user_id", ToJson(object.payments_provider_user_id_));
  if (object.invoice_) {
    jo << ctie("invoice", ToJson(object.invoice_));
  }
  if (object.order_info_) {
    jo << ctie("order_info", ToJson(object.order_info_));
  }
  if (object.shipping_option_) {
    jo << ctie("shipping_option", ToJson(object.shipping_option_));
  }
  jo << ctie("credentials_title", ToJson(object.credentials_title_));
}
void to_json(JsonValueScope &jv, const td_api::paymentResult &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "paymentResult");
  jo << ctie("success", ToJson(object.success_));
  jo << ctie("verification_url", ToJson(object.verification_url_));
}
void to_json(JsonValueScope &jv, const td_api::paymentsProviderStripe &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "paymentsProviderStripe");
  jo << ctie("publishable_key", ToJson(object.publishable_key_));
  jo << ctie("need_country", ToJson(object.need_country_));
  jo << ctie("need_postal_code", ToJson(object.need_postal_code_));
  jo << ctie("need_cardholder_name", ToJson(object.need_cardholder_name_));
}
void to_json(JsonValueScope &jv, const td_api::personalDetails &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "personalDetails");
  jo << ctie("first_name", ToJson(object.first_name_));
  jo << ctie("middle_name", ToJson(object.middle_name_));
  jo << ctie("last_name", ToJson(object.last_name_));
  jo << ctie("native_first_name", ToJson(object.native_first_name_));
  jo << ctie("native_middle_name", ToJson(object.native_middle_name_));
  jo << ctie("native_last_name", ToJson(object.native_last_name_));
  if (object.birthdate_) {
    jo << ctie("birthdate", ToJson(object.birthdate_));
  }
  jo << ctie("gender", ToJson(object.gender_));
  jo << ctie("country_code", ToJson(object.country_code_));
  jo << ctie("residence_country_code", ToJson(object.residence_country_code_));
}
void to_json(JsonValueScope &jv, const td_api::personalDocument &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "personalDocument");
  jo << ctie("files", ToJson(object.files_));
  jo << ctie("translation", ToJson(object.translation_));
}
void to_json(JsonValueScope &jv, const td_api::photo &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "photo");
  jo << ctie("has_stickers", ToJson(object.has_stickers_));
  if (object.minithumbnail_) {
    jo << ctie("minithumbnail", ToJson(object.minithumbnail_));
  }
  jo << ctie("sizes", ToJson(object.sizes_));
}
void to_json(JsonValueScope &jv, const td_api::photoSize &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "photoSize");
  jo << ctie("type", ToJson(object.type_));
  if (object.photo_) {
    jo << ctie("photo", ToJson(object.photo_));
  }
  jo << ctie("width", ToJson(object.width_));
  jo << ctie("height", ToJson(object.height_));
}
void to_json(JsonValueScope &jv, const td_api::poll &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "poll");
  jo << ctie("id", ToJson(JsonInt64{object.id_}));
  jo << ctie("question", ToJson(object.question_));
  jo << ctie("options", ToJson(object.options_));
  jo << ctie("total_voter_count", ToJson(object.total_voter_count_));
  jo << ctie("is_closed", ToJson(object.is_closed_));
}
void to_json(JsonValueScope &jv, const td_api::pollOption &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pollOption");
  jo << ctie("text", ToJson(object.text_));
  jo << ctie("voter_count", ToJson(object.voter_count_));
  jo << ctie("vote_percentage", ToJson(object.vote_percentage_));
  jo << ctie("is_chosen", ToJson(object.is_chosen_));
  jo << ctie("is_being_chosen", ToJson(object.is_being_chosen_));
}
void to_json(JsonValueScope &jv, const td_api::profilePhoto &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "profilePhoto");
  jo << ctie("id", ToJson(JsonInt64{object.id_}));
  if (object.small_) {
    jo << ctie("small", ToJson(object.small_));
  }
  if (object.big_) {
    jo << ctie("big", ToJson(object.big_));
  }
}
void to_json(JsonValueScope &jv, const td_api::proxies &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "proxies");
  jo << ctie("proxies", ToJson(object.proxies_));
}
void to_json(JsonValueScope &jv, const td_api::proxy &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "proxy");
  jo << ctie("id", ToJson(object.id_));
  jo << ctie("server", ToJson(object.server_));
  jo << ctie("port", ToJson(object.port_));
  jo << ctie("last_used_date", ToJson(object.last_used_date_));
  jo << ctie("is_enabled", ToJson(object.is_enabled_));
  if (object.type_) {
    jo << ctie("type", ToJson(object.type_));
  }
}
void to_json(JsonValueScope &jv, const td_api::ProxyType &object) {
  td_api::downcast_call(const_cast<td_api::ProxyType &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::proxyTypeSocks5 &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "proxyTypeSocks5");
  jo << ctie("username", ToJson(object.username_));
  jo << ctie("password", ToJson(object.password_));
}
void to_json(JsonValueScope &jv, const td_api::proxyTypeHttp &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "proxyTypeHttp");
  jo << ctie("username", ToJson(object.username_));
  jo << ctie("password", ToJson(object.password_));
  jo << ctie("http_only", ToJson(object.http_only_));
}
void to_json(JsonValueScope &jv, const td_api::proxyTypeMtproto &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "proxyTypeMtproto");
  jo << ctie("secret", ToJson(object.secret_));
}
void to_json(JsonValueScope &jv, const td_api::publicMessageLink &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "publicMessageLink");
  jo << ctie("link", ToJson(object.link_));
  jo << ctie("html", ToJson(object.html_));
}
void to_json(JsonValueScope &jv, const td_api::PushMessageContent &object) {
  td_api::downcast_call(const_cast<td_api::PushMessageContent &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::pushMessageContentHidden &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pushMessageContentHidden");
  jo << ctie("is_pinned", ToJson(object.is_pinned_));
}
void to_json(JsonValueScope &jv, const td_api::pushMessageContentAnimation &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pushMessageContentAnimation");
  if (object.animation_) {
    jo << ctie("animation", ToJson(object.animation_));
  }
  jo << ctie("caption", ToJson(object.caption_));
  jo << ctie("is_pinned", ToJson(object.is_pinned_));
}
void to_json(JsonValueScope &jv, const td_api::pushMessageContentAudio &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pushMessageContentAudio");
  if (object.audio_) {
    jo << ctie("audio", ToJson(object.audio_));
  }
  jo << ctie("is_pinned", ToJson(object.is_pinned_));
}
void to_json(JsonValueScope &jv, const td_api::pushMessageContentContact &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pushMessageContentContact");
  jo << ctie("name", ToJson(object.name_));
  jo << ctie("is_pinned", ToJson(object.is_pinned_));
}
void to_json(JsonValueScope &jv, const td_api::pushMessageContentContactRegistered &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pushMessageContentContactRegistered");
}
void to_json(JsonValueScope &jv, const td_api::pushMessageContentDocument &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pushMessageContentDocument");
  if (object.document_) {
    jo << ctie("document", ToJson(object.document_));
  }
  jo << ctie("is_pinned", ToJson(object.is_pinned_));
}
void to_json(JsonValueScope &jv, const td_api::pushMessageContentGame &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pushMessageContentGame");
  jo << ctie("title", ToJson(object.title_));
  jo << ctie("is_pinned", ToJson(object.is_pinned_));
}
void to_json(JsonValueScope &jv, const td_api::pushMessageContentGameScore &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pushMessageContentGameScore");
  jo << ctie("title", ToJson(object.title_));
  jo << ctie("score", ToJson(object.score_));
  jo << ctie("is_pinned", ToJson(object.is_pinned_));
}
void to_json(JsonValueScope &jv, const td_api::pushMessageContentInvoice &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pushMessageContentInvoice");
  jo << ctie("price", ToJson(object.price_));
  jo << ctie("is_pinned", ToJson(object.is_pinned_));
}
void to_json(JsonValueScope &jv, const td_api::pushMessageContentLocation &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pushMessageContentLocation");
  jo << ctie("is_live", ToJson(object.is_live_));
  jo << ctie("is_pinned", ToJson(object.is_pinned_));
}
void to_json(JsonValueScope &jv, const td_api::pushMessageContentPhoto &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pushMessageContentPhoto");
  if (object.photo_) {
    jo << ctie("photo", ToJson(object.photo_));
  }
  jo << ctie("caption", ToJson(object.caption_));
  jo << ctie("is_secret", ToJson(object.is_secret_));
  jo << ctie("is_pinned", ToJson(object.is_pinned_));
}
void to_json(JsonValueScope &jv, const td_api::pushMessageContentPoll &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pushMessageContentPoll");
  jo << ctie("question", ToJson(object.question_));
  jo << ctie("is_pinned", ToJson(object.is_pinned_));
}
void to_json(JsonValueScope &jv, const td_api::pushMessageContentScreenshotTaken &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pushMessageContentScreenshotTaken");
}
void to_json(JsonValueScope &jv, const td_api::pushMessageContentSticker &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pushMessageContentSticker");
  if (object.sticker_) {
    jo << ctie("sticker", ToJson(object.sticker_));
  }
  jo << ctie("emoji", ToJson(object.emoji_));
  jo << ctie("is_pinned", ToJson(object.is_pinned_));
}
void to_json(JsonValueScope &jv, const td_api::pushMessageContentText &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pushMessageContentText");
  jo << ctie("text", ToJson(object.text_));
  jo << ctie("is_pinned", ToJson(object.is_pinned_));
}
void to_json(JsonValueScope &jv, const td_api::pushMessageContentVideo &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pushMessageContentVideo");
  if (object.video_) {
    jo << ctie("video", ToJson(object.video_));
  }
  jo << ctie("caption", ToJson(object.caption_));
  jo << ctie("is_secret", ToJson(object.is_secret_));
  jo << ctie("is_pinned", ToJson(object.is_pinned_));
}
void to_json(JsonValueScope &jv, const td_api::pushMessageContentVideoNote &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pushMessageContentVideoNote");
  if (object.video_note_) {
    jo << ctie("video_note", ToJson(object.video_note_));
  }
  jo << ctie("is_pinned", ToJson(object.is_pinned_));
}
void to_json(JsonValueScope &jv, const td_api::pushMessageContentVoiceNote &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pushMessageContentVoiceNote");
  if (object.voice_note_) {
    jo << ctie("voice_note", ToJson(object.voice_note_));
  }
  jo << ctie("is_pinned", ToJson(object.is_pinned_));
}
void to_json(JsonValueScope &jv, const td_api::pushMessageContentBasicGroupChatCreate &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pushMessageContentBasicGroupChatCreate");
}
void to_json(JsonValueScope &jv, const td_api::pushMessageContentChatAddMembers &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pushMessageContentChatAddMembers");
  jo << ctie("member_name", ToJson(object.member_name_));
  jo << ctie("is_current_user", ToJson(object.is_current_user_));
  jo << ctie("is_returned", ToJson(object.is_returned_));
}
void to_json(JsonValueScope &jv, const td_api::pushMessageContentChatChangePhoto &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pushMessageContentChatChangePhoto");
}
void to_json(JsonValueScope &jv, const td_api::pushMessageContentChatChangeTitle &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pushMessageContentChatChangeTitle");
  jo << ctie("title", ToJson(object.title_));
}
void to_json(JsonValueScope &jv, const td_api::pushMessageContentChatDeleteMember &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pushMessageContentChatDeleteMember");
  jo << ctie("member_name", ToJson(object.member_name_));
  jo << ctie("is_current_user", ToJson(object.is_current_user_));
  jo << ctie("is_left", ToJson(object.is_left_));
}
void to_json(JsonValueScope &jv, const td_api::pushMessageContentChatJoinByLink &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pushMessageContentChatJoinByLink");
}
void to_json(JsonValueScope &jv, const td_api::pushMessageContentMessageForwards &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pushMessageContentMessageForwards");
  jo << ctie("total_count", ToJson(object.total_count_));
}
void to_json(JsonValueScope &jv, const td_api::pushMessageContentMediaAlbum &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pushMessageContentMediaAlbum");
  jo << ctie("total_count", ToJson(object.total_count_));
  jo << ctie("has_photos", ToJson(object.has_photos_));
  jo << ctie("has_videos", ToJson(object.has_videos_));
}
void to_json(JsonValueScope &jv, const td_api::pushReceiverId &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "pushReceiverId");
  jo << ctie("id", ToJson(JsonInt64{object.id_}));
}
void to_json(JsonValueScope &jv, const td_api::recoveryEmailAddress &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "recoveryEmailAddress");
  jo << ctie("recovery_email_address", ToJson(object.recovery_email_address_));
}
void to_json(JsonValueScope &jv, const td_api::remoteFile &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "remoteFile");
  jo << ctie("id", ToJson(object.id_));
  jo << ctie("is_uploading_active", ToJson(object.is_uploading_active_));
  jo << ctie("is_uploading_completed", ToJson(object.is_uploading_completed_));
  jo << ctie("uploaded_size", ToJson(object.uploaded_size_));
}
void to_json(JsonValueScope &jv, const td_api::ReplyMarkup &object) {
  td_api::downcast_call(const_cast<td_api::ReplyMarkup &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::replyMarkupRemoveKeyboard &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "replyMarkupRemoveKeyboard");
  jo << ctie("is_personal", ToJson(object.is_personal_));
}
void to_json(JsonValueScope &jv, const td_api::replyMarkupForceReply &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "replyMarkupForceReply");
  jo << ctie("is_personal", ToJson(object.is_personal_));
}
void to_json(JsonValueScope &jv, const td_api::replyMarkupShowKeyboard &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "replyMarkupShowKeyboard");
  jo << ctie("rows", ToJson(object.rows_));
  jo << ctie("resize_keyboard", ToJson(object.resize_keyboard_));
  jo << ctie("one_time", ToJson(object.one_time_));
  jo << ctie("is_personal", ToJson(object.is_personal_));
}
void to_json(JsonValueScope &jv, const td_api::replyMarkupInlineKeyboard &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "replyMarkupInlineKeyboard");
  jo << ctie("rows", ToJson(object.rows_));
}
void to_json(JsonValueScope &jv, const td_api::RichText &object) {
  td_api::downcast_call(const_cast<td_api::RichText &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::richTextPlain &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "richTextPlain");
  jo << ctie("text", ToJson(object.text_));
}
void to_json(JsonValueScope &jv, const td_api::richTextBold &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "richTextBold");
  if (object.text_) {
    jo << ctie("text", ToJson(object.text_));
  }
}
void to_json(JsonValueScope &jv, const td_api::richTextItalic &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "richTextItalic");
  if (object.text_) {
    jo << ctie("text", ToJson(object.text_));
  }
}
void to_json(JsonValueScope &jv, const td_api::richTextUnderline &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "richTextUnderline");
  if (object.text_) {
    jo << ctie("text", ToJson(object.text_));
  }
}
void to_json(JsonValueScope &jv, const td_api::richTextStrikethrough &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "richTextStrikethrough");
  if (object.text_) {
    jo << ctie("text", ToJson(object.text_));
  }
}
void to_json(JsonValueScope &jv, const td_api::richTextFixed &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "richTextFixed");
  if (object.text_) {
    jo << ctie("text", ToJson(object.text_));
  }
}
void to_json(JsonValueScope &jv, const td_api::richTextUrl &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "richTextUrl");
  if (object.text_) {
    jo << ctie("text", ToJson(object.text_));
  }
  jo << ctie("url", ToJson(object.url_));
}
void to_json(JsonValueScope &jv, const td_api::richTextEmailAddress &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "richTextEmailAddress");
  if (object.text_) {
    jo << ctie("text", ToJson(object.text_));
  }
  jo << ctie("email_address", ToJson(object.email_address_));
}
void to_json(JsonValueScope &jv, const td_api::richTextSubscript &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "richTextSubscript");
  if (object.text_) {
    jo << ctie("text", ToJson(object.text_));
  }
}
void to_json(JsonValueScope &jv, const td_api::richTextSuperscript &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "richTextSuperscript");
  if (object.text_) {
    jo << ctie("text", ToJson(object.text_));
  }
}
void to_json(JsonValueScope &jv, const td_api::richTextMarked &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "richTextMarked");
  if (object.text_) {
    jo << ctie("text", ToJson(object.text_));
  }
}
void to_json(JsonValueScope &jv, const td_api::richTextPhoneNumber &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "richTextPhoneNumber");
  if (object.text_) {
    jo << ctie("text", ToJson(object.text_));
  }
  jo << ctie("phone_number", ToJson(object.phone_number_));
}
void to_json(JsonValueScope &jv, const td_api::richTextIcon &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "richTextIcon");
  if (object.document_) {
    jo << ctie("document", ToJson(object.document_));
  }
  jo << ctie("width", ToJson(object.width_));
  jo << ctie("height", ToJson(object.height_));
}
void to_json(JsonValueScope &jv, const td_api::richTextAnchor &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "richTextAnchor");
  if (object.text_) {
    jo << ctie("text", ToJson(object.text_));
  }
  jo << ctie("name", ToJson(object.name_));
}
void to_json(JsonValueScope &jv, const td_api::richTexts &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "richTexts");
  jo << ctie("texts", ToJson(object.texts_));
}
void to_json(JsonValueScope &jv, const td_api::savedCredentials &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "savedCredentials");
  jo << ctie("id", ToJson(object.id_));
  jo << ctie("title", ToJson(object.title_));
}
void to_json(JsonValueScope &jv, const td_api::scopeNotificationSettings &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "scopeNotificationSettings");
  jo << ctie("mute_for", ToJson(object.mute_for_));
  jo << ctie("sound", ToJson(object.sound_));
  jo << ctie("show_preview", ToJson(object.show_preview_));
  jo << ctie("disable_pinned_message_notifications", ToJson(object.disable_pinned_message_notifications_));
  jo << ctie("disable_mention_notifications", ToJson(object.disable_mention_notifications_));
}
void to_json(JsonValueScope &jv, const td_api::seconds &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "seconds");
  jo << ctie("seconds", ToJson(object.seconds_));
}
void to_json(JsonValueScope &jv, const td_api::secretChat &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "secretChat");
  jo << ctie("id", ToJson(object.id_));
  jo << ctie("user_id", ToJson(object.user_id_));
  if (object.state_) {
    jo << ctie("state", ToJson(object.state_));
  }
  jo << ctie("is_outbound", ToJson(object.is_outbound_));
  jo << ctie("ttl", ToJson(object.ttl_));
  jo << ctie("key_hash", ToJson(base64_encode(object.key_hash_)));
  jo << ctie("layer", ToJson(object.layer_));
}
void to_json(JsonValueScope &jv, const td_api::SecretChatState &object) {
  td_api::downcast_call(const_cast<td_api::SecretChatState &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::secretChatStatePending &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "secretChatStatePending");
}
void to_json(JsonValueScope &jv, const td_api::secretChatStateReady &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "secretChatStateReady");
}
void to_json(JsonValueScope &jv, const td_api::secretChatStateClosed &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "secretChatStateClosed");
}
void to_json(JsonValueScope &jv, const td_api::session &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "session");
  jo << ctie("id", ToJson(JsonInt64{object.id_}));
  jo << ctie("is_current", ToJson(object.is_current_));
  jo << ctie("is_password_pending", ToJson(object.is_password_pending_));
  jo << ctie("api_id", ToJson(object.api_id_));
  jo << ctie("application_name", ToJson(object.application_name_));
  jo << ctie("application_version", ToJson(object.application_version_));
  jo << ctie("is_official_application", ToJson(object.is_official_application_));
  jo << ctie("device_model", ToJson(object.device_model_));
  jo << ctie("platform", ToJson(object.platform_));
  jo << ctie("system_version", ToJson(object.system_version_));
  jo << ctie("log_in_date", ToJson(object.log_in_date_));
  jo << ctie("last_active_date", ToJson(object.last_active_date_));
  jo << ctie("ip", ToJson(object.ip_));
  jo << ctie("country", ToJson(object.country_));
  jo << ctie("region", ToJson(object.region_));
}
void to_json(JsonValueScope &jv, const td_api::sessions &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "sessions");
  jo << ctie("sessions", ToJson(object.sessions_));
}
void to_json(JsonValueScope &jv, const td_api::shippingOption &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "shippingOption");
  jo << ctie("id", ToJson(object.id_));
  jo << ctie("title", ToJson(object.title_));
  jo << ctie("price_parts", ToJson(object.price_parts_));
}
void to_json(JsonValueScope &jv, const td_api::sticker &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "sticker");
  jo << ctie("set_id", ToJson(JsonInt64{object.set_id_}));
  jo << ctie("width", ToJson(object.width_));
  jo << ctie("height", ToJson(object.height_));
  jo << ctie("emoji", ToJson(object.emoji_));
  jo << ctie("is_animated", ToJson(object.is_animated_));
  jo << ctie("is_mask", ToJson(object.is_mask_));
  if (object.mask_position_) {
    jo << ctie("mask_position", ToJson(object.mask_position_));
  }
  if (object.thumbnail_) {
    jo << ctie("thumbnail", ToJson(object.thumbnail_));
  }
  if (object.sticker_) {
    jo << ctie("sticker", ToJson(object.sticker_));
  }
}
void to_json(JsonValueScope &jv, const td_api::stickerSet &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "stickerSet");
  jo << ctie("id", ToJson(JsonInt64{object.id_}));
  jo << ctie("title", ToJson(object.title_));
  jo << ctie("name", ToJson(object.name_));
  if (object.thumbnail_) {
    jo << ctie("thumbnail", ToJson(object.thumbnail_));
  }
  jo << ctie("is_installed", ToJson(object.is_installed_));
  jo << ctie("is_archived", ToJson(object.is_archived_));
  jo << ctie("is_official", ToJson(object.is_official_));
  jo << ctie("is_animated", ToJson(object.is_animated_));
  jo << ctie("is_masks", ToJson(object.is_masks_));
  jo << ctie("is_viewed", ToJson(object.is_viewed_));
  jo << ctie("stickers", ToJson(object.stickers_));
  jo << ctie("emojis", ToJson(object.emojis_));
}
void to_json(JsonValueScope &jv, const td_api::stickerSetInfo &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "stickerSetInfo");
  jo << ctie("id", ToJson(JsonInt64{object.id_}));
  jo << ctie("title", ToJson(object.title_));
  jo << ctie("name", ToJson(object.name_));
  if (object.thumbnail_) {
    jo << ctie("thumbnail", ToJson(object.thumbnail_));
  }
  jo << ctie("is_installed", ToJson(object.is_installed_));
  jo << ctie("is_archived", ToJson(object.is_archived_));
  jo << ctie("is_official", ToJson(object.is_official_));
  jo << ctie("is_animated", ToJson(object.is_animated_));
  jo << ctie("is_masks", ToJson(object.is_masks_));
  jo << ctie("is_viewed", ToJson(object.is_viewed_));
  jo << ctie("size", ToJson(object.size_));
  jo << ctie("covers", ToJson(object.covers_));
}
void to_json(JsonValueScope &jv, const td_api::stickerSets &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "stickerSets");
  jo << ctie("total_count", ToJson(object.total_count_));
  jo << ctie("sets", ToJson(object.sets_));
}
void to_json(JsonValueScope &jv, const td_api::stickers &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "stickers");
  jo << ctie("stickers", ToJson(object.stickers_));
}
void to_json(JsonValueScope &jv, const td_api::storageStatistics &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "storageStatistics");
  jo << ctie("size", ToJson(object.size_));
  jo << ctie("count", ToJson(object.count_));
  jo << ctie("by_chat", ToJson(object.by_chat_));
}
void to_json(JsonValueScope &jv, const td_api::storageStatisticsByChat &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "storageStatisticsByChat");
  jo << ctie("chat_id", ToJson(object.chat_id_));
  jo << ctie("size", ToJson(object.size_));
  jo << ctie("count", ToJson(object.count_));
  jo << ctie("by_file_type", ToJson(object.by_file_type_));
}
void to_json(JsonValueScope &jv, const td_api::storageStatisticsByFileType &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "storageStatisticsByFileType");
  if (object.file_type_) {
    jo << ctie("file_type", ToJson(object.file_type_));
  }
  jo << ctie("size", ToJson(object.size_));
  jo << ctie("count", ToJson(object.count_));
}
void to_json(JsonValueScope &jv, const td_api::storageStatisticsFast &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "storageStatisticsFast");
  jo << ctie("files_size", ToJson(object.files_size_));
  jo << ctie("file_count", ToJson(object.file_count_));
  jo << ctie("database_size", ToJson(object.database_size_));
  jo << ctie("language_pack_database_size", ToJson(object.language_pack_database_size_));
  jo << ctie("log_size", ToJson(object.log_size_));
}
void to_json(JsonValueScope &jv, const td_api::supergroup &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "supergroup");
  jo << ctie("id", ToJson(object.id_));
  jo << ctie("username", ToJson(object.username_));
  jo << ctie("date", ToJson(object.date_));
  if (object.status_) {
    jo << ctie("status", ToJson(object.status_));
  }
  jo << ctie("member_count", ToJson(object.member_count_));
  jo << ctie("sign_messages", ToJson(object.sign_messages_));
  jo << ctie("is_channel", ToJson(object.is_channel_));
  jo << ctie("is_verified", ToJson(object.is_verified_));
  jo << ctie("restriction_reason", ToJson(object.restriction_reason_));
  jo << ctie("is_scam", ToJson(object.is_scam_));
}
void to_json(JsonValueScope &jv, const td_api::supergroupFullInfo &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "supergroupFullInfo");
  jo << ctie("description", ToJson(object.description_));
  jo << ctie("member_count", ToJson(object.member_count_));
  jo << ctie("administrator_count", ToJson(object.administrator_count_));
  jo << ctie("restricted_count", ToJson(object.restricted_count_));
  jo << ctie("banned_count", ToJson(object.banned_count_));
  jo << ctie("can_get_members", ToJson(object.can_get_members_));
  jo << ctie("can_set_username", ToJson(object.can_set_username_));
  jo << ctie("can_set_sticker_set", ToJson(object.can_set_sticker_set_));
  jo << ctie("can_view_statistics", ToJson(object.can_view_statistics_));
  jo << ctie("is_all_history_available", ToJson(object.is_all_history_available_));
  jo << ctie("sticker_set_id", ToJson(JsonInt64{object.sticker_set_id_}));
  jo << ctie("invite_link", ToJson(object.invite_link_));
  jo << ctie("upgraded_from_basic_group_id", ToJson(object.upgraded_from_basic_group_id_));
  jo << ctie("upgraded_from_max_message_id", ToJson(object.upgraded_from_max_message_id_));
}
void to_json(JsonValueScope &jv, const td_api::tMeUrl &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "tMeUrl");
  jo << ctie("url", ToJson(object.url_));
  if (object.type_) {
    jo << ctie("type", ToJson(object.type_));
  }
}
void to_json(JsonValueScope &jv, const td_api::TMeUrlType &object) {
  td_api::downcast_call(const_cast<td_api::TMeUrlType &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::tMeUrlTypeUser &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "tMeUrlTypeUser");
  jo << ctie("user_id", ToJson(object.user_id_));
}
void to_json(JsonValueScope &jv, const td_api::tMeUrlTypeSupergroup &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "tMeUrlTypeSupergroup");
  jo << ctie("supergroup_id", ToJson(object.supergroup_id_));
}
void to_json(JsonValueScope &jv, const td_api::tMeUrlTypeChatInvite &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "tMeUrlTypeChatInvite");
  if (object.info_) {
    jo << ctie("info", ToJson(object.info_));
  }
}
void to_json(JsonValueScope &jv, const td_api::tMeUrlTypeStickerSet &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "tMeUrlTypeStickerSet");
  jo << ctie("sticker_set_id", ToJson(JsonInt64{object.sticker_set_id_}));
}
void to_json(JsonValueScope &jv, const td_api::tMeUrls &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "tMeUrls");
  jo << ctie("urls", ToJson(object.urls_));
}
void to_json(JsonValueScope &jv, const td_api::temporaryPasswordState &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "temporaryPasswordState");
  jo << ctie("has_password", ToJson(object.has_password_));
  jo << ctie("valid_for", ToJson(object.valid_for_));
}
void to_json(JsonValueScope &jv, const td_api::termsOfService &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "termsOfService");
  if (object.text_) {
    jo << ctie("text", ToJson(object.text_));
  }
  jo << ctie("min_user_age", ToJson(object.min_user_age_));
  jo << ctie("show_popup", ToJson(object.show_popup_));
}
void to_json(JsonValueScope &jv, const td_api::testBytes &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "testBytes");
  jo << ctie("value", ToJson(base64_encode(object.value_)));
}
void to_json(JsonValueScope &jv, const td_api::testInt &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "testInt");
  jo << ctie("value", ToJson(object.value_));
}
void to_json(JsonValueScope &jv, const td_api::testString &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "testString");
  jo << ctie("value", ToJson(object.value_));
}
void to_json(JsonValueScope &jv, const td_api::testVectorInt &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "testVectorInt");
  jo << ctie("value", ToJson(object.value_));
}
void to_json(JsonValueScope &jv, const td_api::testVectorIntObject &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "testVectorIntObject");
  jo << ctie("value", ToJson(object.value_));
}
void to_json(JsonValueScope &jv, const td_api::testVectorString &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "testVectorString");
  jo << ctie("value", ToJson(object.value_));
}
void to_json(JsonValueScope &jv, const td_api::testVectorStringObject &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "testVectorStringObject");
  jo << ctie("value", ToJson(object.value_));
}
void to_json(JsonValueScope &jv, const td_api::text &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "text");
  jo << ctie("text", ToJson(object.text_));
}
void to_json(JsonValueScope &jv, const td_api::textEntities &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "textEntities");
  jo << ctie("entities", ToJson(object.entities_));
}
void to_json(JsonValueScope &jv, const td_api::textEntity &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "textEntity");
  jo << ctie("offset", ToJson(object.offset_));
  jo << ctie("length", ToJson(object.length_));
  if (object.type_) {
    jo << ctie("type", ToJson(object.type_));
  }
}
void to_json(JsonValueScope &jv, const td_api::TextEntityType &object) {
  td_api::downcast_call(const_cast<td_api::TextEntityType &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::textEntityTypeMention &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "textEntityTypeMention");
}
void to_json(JsonValueScope &jv, const td_api::textEntityTypeHashtag &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "textEntityTypeHashtag");
}
void to_json(JsonValueScope &jv, const td_api::textEntityTypeCashtag &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "textEntityTypeCashtag");
}
void to_json(JsonValueScope &jv, const td_api::textEntityTypeBotCommand &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "textEntityTypeBotCommand");
}
void to_json(JsonValueScope &jv, const td_api::textEntityTypeUrl &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "textEntityTypeUrl");
}
void to_json(JsonValueScope &jv, const td_api::textEntityTypeEmailAddress &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "textEntityTypeEmailAddress");
}
void to_json(JsonValueScope &jv, const td_api::textEntityTypeBold &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "textEntityTypeBold");
}
void to_json(JsonValueScope &jv, const td_api::textEntityTypeItalic &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "textEntityTypeItalic");
}
void to_json(JsonValueScope &jv, const td_api::textEntityTypeCode &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "textEntityTypeCode");
}
void to_json(JsonValueScope &jv, const td_api::textEntityTypePre &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "textEntityTypePre");
}
void to_json(JsonValueScope &jv, const td_api::textEntityTypePreCode &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "textEntityTypePreCode");
  jo << ctie("language", ToJson(object.language_));
}
void to_json(JsonValueScope &jv, const td_api::textEntityTypeTextUrl &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "textEntityTypeTextUrl");
  jo << ctie("url", ToJson(object.url_));
}
void to_json(JsonValueScope &jv, const td_api::textEntityTypeMentionName &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "textEntityTypeMentionName");
  jo << ctie("user_id", ToJson(object.user_id_));
}
void to_json(JsonValueScope &jv, const td_api::textEntityTypePhoneNumber &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "textEntityTypePhoneNumber");
}
void to_json(JsonValueScope &jv, const td_api::Update &object) {
  td_api::downcast_call(const_cast<td_api::Update &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::updateAuthorizationState &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateAuthorizationState");
  if (object.authorization_state_) {
    jo << ctie("authorization_state", ToJson(object.authorization_state_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateNewMessage &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateNewMessage");
  if (object.message_) {
    jo << ctie("message", ToJson(object.message_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateMessageSendAcknowledged &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateMessageSendAcknowledged");
  jo << ctie("chat_id", ToJson(object.chat_id_));
  jo << ctie("message_id", ToJson(object.message_id_));
}
void to_json(JsonValueScope &jv, const td_api::updateMessageSendSucceeded &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateMessageSendSucceeded");
  if (object.message_) {
    jo << ctie("message", ToJson(object.message_));
  }
  jo << ctie("old_message_id", ToJson(object.old_message_id_));
}
void to_json(JsonValueScope &jv, const td_api::updateMessageSendFailed &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateMessageSendFailed");
  if (object.message_) {
    jo << ctie("message", ToJson(object.message_));
  }
  jo << ctie("old_message_id", ToJson(object.old_message_id_));
  jo << ctie("error_code", ToJson(object.error_code_));
  jo << ctie("error_message", ToJson(object.error_message_));
}
void to_json(JsonValueScope &jv, const td_api::updateMessageContent &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateMessageContent");
  jo << ctie("chat_id", ToJson(object.chat_id_));
  jo << ctie("message_id", ToJson(object.message_id_));
  if (object.new_content_) {
    jo << ctie("new_content", ToJson(object.new_content_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateMessageEdited &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateMessageEdited");
  jo << ctie("chat_id", ToJson(object.chat_id_));
  jo << ctie("message_id", ToJson(object.message_id_));
  jo << ctie("edit_date", ToJson(object.edit_date_));
  if (object.reply_markup_) {
    jo << ctie("reply_markup", ToJson(object.reply_markup_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateMessageViews &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateMessageViews");
  jo << ctie("chat_id", ToJson(object.chat_id_));
  jo << ctie("message_id", ToJson(object.message_id_));
  jo << ctie("views", ToJson(object.views_));
}
void to_json(JsonValueScope &jv, const td_api::updateMessageContentOpened &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateMessageContentOpened");
  jo << ctie("chat_id", ToJson(object.chat_id_));
  jo << ctie("message_id", ToJson(object.message_id_));
}
void to_json(JsonValueScope &jv, const td_api::updateMessageMentionRead &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateMessageMentionRead");
  jo << ctie("chat_id", ToJson(object.chat_id_));
  jo << ctie("message_id", ToJson(object.message_id_));
  jo << ctie("unread_mention_count", ToJson(object.unread_mention_count_));
}
void to_json(JsonValueScope &jv, const td_api::updateNewChat &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateNewChat");
  if (object.chat_) {
    jo << ctie("chat", ToJson(object.chat_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateChatTitle &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateChatTitle");
  jo << ctie("chat_id", ToJson(object.chat_id_));
  jo << ctie("title", ToJson(object.title_));
}
void to_json(JsonValueScope &jv, const td_api::updateChatPhoto &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateChatPhoto");
  jo << ctie("chat_id", ToJson(object.chat_id_));
  if (object.photo_) {
    jo << ctie("photo", ToJson(object.photo_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateChatPermissions &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateChatPermissions");
  jo << ctie("chat_id", ToJson(object.chat_id_));
  if (object.permissions_) {
    jo << ctie("permissions", ToJson(object.permissions_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateChatLastMessage &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateChatLastMessage");
  jo << ctie("chat_id", ToJson(object.chat_id_));
  if (object.last_message_) {
    jo << ctie("last_message", ToJson(object.last_message_));
  }
  jo << ctie("order", ToJson(JsonInt64{object.order_}));
}
void to_json(JsonValueScope &jv, const td_api::updateChatOrder &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateChatOrder");
  jo << ctie("chat_id", ToJson(object.chat_id_));
  jo << ctie("order", ToJson(JsonInt64{object.order_}));
}
void to_json(JsonValueScope &jv, const td_api::updateChatIsPinned &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateChatIsPinned");
  jo << ctie("chat_id", ToJson(object.chat_id_));
  jo << ctie("is_pinned", ToJson(object.is_pinned_));
  jo << ctie("order", ToJson(JsonInt64{object.order_}));
}
void to_json(JsonValueScope &jv, const td_api::updateChatIsMarkedAsUnread &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateChatIsMarkedAsUnread");
  jo << ctie("chat_id", ToJson(object.chat_id_));
  jo << ctie("is_marked_as_unread", ToJson(object.is_marked_as_unread_));
}
void to_json(JsonValueScope &jv, const td_api::updateChatIsSponsored &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateChatIsSponsored");
  jo << ctie("chat_id", ToJson(object.chat_id_));
  jo << ctie("is_sponsored", ToJson(object.is_sponsored_));
  jo << ctie("order", ToJson(JsonInt64{object.order_}));
}
void to_json(JsonValueScope &jv, const td_api::updateChatDefaultDisableNotification &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateChatDefaultDisableNotification");
  jo << ctie("chat_id", ToJson(object.chat_id_));
  jo << ctie("default_disable_notification", ToJson(object.default_disable_notification_));
}
void to_json(JsonValueScope &jv, const td_api::updateChatReadInbox &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateChatReadInbox");
  jo << ctie("chat_id", ToJson(object.chat_id_));
  jo << ctie("last_read_inbox_message_id", ToJson(object.last_read_inbox_message_id_));
  jo << ctie("unread_count", ToJson(object.unread_count_));
}
void to_json(JsonValueScope &jv, const td_api::updateChatReadOutbox &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateChatReadOutbox");
  jo << ctie("chat_id", ToJson(object.chat_id_));
  jo << ctie("last_read_outbox_message_id", ToJson(object.last_read_outbox_message_id_));
}
void to_json(JsonValueScope &jv, const td_api::updateChatUnreadMentionCount &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateChatUnreadMentionCount");
  jo << ctie("chat_id", ToJson(object.chat_id_));
  jo << ctie("unread_mention_count", ToJson(object.unread_mention_count_));
}
void to_json(JsonValueScope &jv, const td_api::updateChatNotificationSettings &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateChatNotificationSettings");
  jo << ctie("chat_id", ToJson(object.chat_id_));
  if (object.notification_settings_) {
    jo << ctie("notification_settings", ToJson(object.notification_settings_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateScopeNotificationSettings &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateScopeNotificationSettings");
  if (object.scope_) {
    jo << ctie("scope", ToJson(object.scope_));
  }
  if (object.notification_settings_) {
    jo << ctie("notification_settings", ToJson(object.notification_settings_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateChatPinnedMessage &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateChatPinnedMessage");
  jo << ctie("chat_id", ToJson(object.chat_id_));
  jo << ctie("pinned_message_id", ToJson(object.pinned_message_id_));
}
void to_json(JsonValueScope &jv, const td_api::updateChatReplyMarkup &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateChatReplyMarkup");
  jo << ctie("chat_id", ToJson(object.chat_id_));
  jo << ctie("reply_markup_message_id", ToJson(object.reply_markup_message_id_));
}
void to_json(JsonValueScope &jv, const td_api::updateChatDraftMessage &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateChatDraftMessage");
  jo << ctie("chat_id", ToJson(object.chat_id_));
  if (object.draft_message_) {
    jo << ctie("draft_message", ToJson(object.draft_message_));
  }
  jo << ctie("order", ToJson(JsonInt64{object.order_}));
}
void to_json(JsonValueScope &jv, const td_api::updateChatOnlineMemberCount &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateChatOnlineMemberCount");
  jo << ctie("chat_id", ToJson(object.chat_id_));
  jo << ctie("online_member_count", ToJson(object.online_member_count_));
}
void to_json(JsonValueScope &jv, const td_api::updateNotification &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateNotification");
  jo << ctie("notification_group_id", ToJson(object.notification_group_id_));
  if (object.notification_) {
    jo << ctie("notification", ToJson(object.notification_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateNotificationGroup &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateNotificationGroup");
  jo << ctie("notification_group_id", ToJson(object.notification_group_id_));
  if (object.type_) {
    jo << ctie("type", ToJson(object.type_));
  }
  jo << ctie("chat_id", ToJson(object.chat_id_));
  jo << ctie("notification_settings_chat_id", ToJson(object.notification_settings_chat_id_));
  jo << ctie("is_silent", ToJson(object.is_silent_));
  jo << ctie("total_count", ToJson(object.total_count_));
  jo << ctie("added_notifications", ToJson(object.added_notifications_));
  jo << ctie("removed_notification_ids", ToJson(object.removed_notification_ids_));
}
void to_json(JsonValueScope &jv, const td_api::updateActiveNotifications &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateActiveNotifications");
  jo << ctie("groups", ToJson(object.groups_));
}
void to_json(JsonValueScope &jv, const td_api::updateHavePendingNotifications &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateHavePendingNotifications");
  jo << ctie("have_delayed_notifications", ToJson(object.have_delayed_notifications_));
  jo << ctie("have_unreceived_notifications", ToJson(object.have_unreceived_notifications_));
}
void to_json(JsonValueScope &jv, const td_api::updateDeleteMessages &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateDeleteMessages");
  jo << ctie("chat_id", ToJson(object.chat_id_));
  jo << ctie("message_ids", ToJson(object.message_ids_));
  jo << ctie("is_permanent", ToJson(object.is_permanent_));
  jo << ctie("from_cache", ToJson(object.from_cache_));
}
void to_json(JsonValueScope &jv, const td_api::updateUserChatAction &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateUserChatAction");
  jo << ctie("chat_id", ToJson(object.chat_id_));
  jo << ctie("user_id", ToJson(object.user_id_));
  if (object.action_) {
    jo << ctie("action", ToJson(object.action_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateUserStatus &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateUserStatus");
  jo << ctie("user_id", ToJson(object.user_id_));
  if (object.status_) {
    jo << ctie("status", ToJson(object.status_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateUser &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateUser");
  if (object.user_) {
    jo << ctie("user", ToJson(object.user_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateBasicGroup &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateBasicGroup");
  if (object.basic_group_) {
    jo << ctie("basic_group", ToJson(object.basic_group_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateSupergroup &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateSupergroup");
  if (object.supergroup_) {
    jo << ctie("supergroup", ToJson(object.supergroup_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateSecretChat &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateSecretChat");
  if (object.secret_chat_) {
    jo << ctie("secret_chat", ToJson(object.secret_chat_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateUserFullInfo &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateUserFullInfo");
  jo << ctie("user_id", ToJson(object.user_id_));
  if (object.user_full_info_) {
    jo << ctie("user_full_info", ToJson(object.user_full_info_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateBasicGroupFullInfo &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateBasicGroupFullInfo");
  jo << ctie("basic_group_id", ToJson(object.basic_group_id_));
  if (object.basic_group_full_info_) {
    jo << ctie("basic_group_full_info", ToJson(object.basic_group_full_info_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateSupergroupFullInfo &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateSupergroupFullInfo");
  jo << ctie("supergroup_id", ToJson(object.supergroup_id_));
  if (object.supergroup_full_info_) {
    jo << ctie("supergroup_full_info", ToJson(object.supergroup_full_info_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateServiceNotification &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateServiceNotification");
  jo << ctie("type", ToJson(object.type_));
  if (object.content_) {
    jo << ctie("content", ToJson(object.content_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateFile &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateFile");
  if (object.file_) {
    jo << ctie("file", ToJson(object.file_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateFileGenerationStart &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateFileGenerationStart");
  jo << ctie("generation_id", ToJson(JsonInt64{object.generation_id_}));
  jo << ctie("original_path", ToJson(object.original_path_));
  jo << ctie("destination_path", ToJson(object.destination_path_));
  jo << ctie("conversion", ToJson(object.conversion_));
}
void to_json(JsonValueScope &jv, const td_api::updateFileGenerationStop &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateFileGenerationStop");
  jo << ctie("generation_id", ToJson(JsonInt64{object.generation_id_}));
}
void to_json(JsonValueScope &jv, const td_api::updateCall &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateCall");
  if (object.call_) {
    jo << ctie("call", ToJson(object.call_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateUserPrivacySettingRules &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateUserPrivacySettingRules");
  if (object.setting_) {
    jo << ctie("setting", ToJson(object.setting_));
  }
  if (object.rules_) {
    jo << ctie("rules", ToJson(object.rules_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateUnreadMessageCount &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateUnreadMessageCount");
  jo << ctie("unread_count", ToJson(object.unread_count_));
  jo << ctie("unread_unmuted_count", ToJson(object.unread_unmuted_count_));
}
void to_json(JsonValueScope &jv, const td_api::updateUnreadChatCount &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateUnreadChatCount");
  jo << ctie("unread_count", ToJson(object.unread_count_));
  jo << ctie("unread_unmuted_count", ToJson(object.unread_unmuted_count_));
  jo << ctie("marked_as_unread_count", ToJson(object.marked_as_unread_count_));
  jo << ctie("marked_as_unread_unmuted_count", ToJson(object.marked_as_unread_unmuted_count_));
}
void to_json(JsonValueScope &jv, const td_api::updateOption &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateOption");
  jo << ctie("name", ToJson(object.name_));
  if (object.value_) {
    jo << ctie("value", ToJson(object.value_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateInstalledStickerSets &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateInstalledStickerSets");
  jo << ctie("is_masks", ToJson(object.is_masks_));
  jo << ctie("sticker_set_ids", ToJson(JsonVectorInt64{object.sticker_set_ids_}));
}
void to_json(JsonValueScope &jv, const td_api::updateTrendingStickerSets &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateTrendingStickerSets");
  if (object.sticker_sets_) {
    jo << ctie("sticker_sets", ToJson(object.sticker_sets_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateRecentStickers &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateRecentStickers");
  jo << ctie("is_attached", ToJson(object.is_attached_));
  jo << ctie("sticker_ids", ToJson(object.sticker_ids_));
}
void to_json(JsonValueScope &jv, const td_api::updateFavoriteStickers &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateFavoriteStickers");
  jo << ctie("sticker_ids", ToJson(object.sticker_ids_));
}
void to_json(JsonValueScope &jv, const td_api::updateSavedAnimations &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateSavedAnimations");
  jo << ctie("animation_ids", ToJson(object.animation_ids_));
}
void to_json(JsonValueScope &jv, const td_api::updateSelectedBackground &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateSelectedBackground");
  jo << ctie("for_dark_theme", ToJson(object.for_dark_theme_));
  if (object.background_) {
    jo << ctie("background", ToJson(object.background_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateLanguagePackStrings &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateLanguagePackStrings");
  jo << ctie("localization_target", ToJson(object.localization_target_));
  jo << ctie("language_pack_id", ToJson(object.language_pack_id_));
  jo << ctie("strings", ToJson(object.strings_));
}
void to_json(JsonValueScope &jv, const td_api::updateConnectionState &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateConnectionState");
  if (object.state_) {
    jo << ctie("state", ToJson(object.state_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateTermsOfService &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateTermsOfService");
  jo << ctie("terms_of_service_id", ToJson(object.terms_of_service_id_));
  if (object.terms_of_service_) {
    jo << ctie("terms_of_service", ToJson(object.terms_of_service_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateNewInlineQuery &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateNewInlineQuery");
  jo << ctie("id", ToJson(JsonInt64{object.id_}));
  jo << ctie("sender_user_id", ToJson(object.sender_user_id_));
  if (object.user_location_) {
    jo << ctie("user_location", ToJson(object.user_location_));
  }
  jo << ctie("query", ToJson(object.query_));
  jo << ctie("offset", ToJson(object.offset_));
}
void to_json(JsonValueScope &jv, const td_api::updateNewChosenInlineResult &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateNewChosenInlineResult");
  jo << ctie("sender_user_id", ToJson(object.sender_user_id_));
  if (object.user_location_) {
    jo << ctie("user_location", ToJson(object.user_location_));
  }
  jo << ctie("query", ToJson(object.query_));
  jo << ctie("result_id", ToJson(object.result_id_));
  jo << ctie("inline_message_id", ToJson(object.inline_message_id_));
}
void to_json(JsonValueScope &jv, const td_api::updateNewCallbackQuery &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateNewCallbackQuery");
  jo << ctie("id", ToJson(JsonInt64{object.id_}));
  jo << ctie("sender_user_id", ToJson(object.sender_user_id_));
  jo << ctie("chat_id", ToJson(object.chat_id_));
  jo << ctie("message_id", ToJson(object.message_id_));
  jo << ctie("chat_instance", ToJson(JsonInt64{object.chat_instance_}));
  if (object.payload_) {
    jo << ctie("payload", ToJson(object.payload_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateNewInlineCallbackQuery &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateNewInlineCallbackQuery");
  jo << ctie("id", ToJson(JsonInt64{object.id_}));
  jo << ctie("sender_user_id", ToJson(object.sender_user_id_));
  jo << ctie("inline_message_id", ToJson(object.inline_message_id_));
  jo << ctie("chat_instance", ToJson(JsonInt64{object.chat_instance_}));
  if (object.payload_) {
    jo << ctie("payload", ToJson(object.payload_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateNewShippingQuery &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateNewShippingQuery");
  jo << ctie("id", ToJson(JsonInt64{object.id_}));
  jo << ctie("sender_user_id", ToJson(object.sender_user_id_));
  jo << ctie("invoice_payload", ToJson(object.invoice_payload_));
  if (object.shipping_address_) {
    jo << ctie("shipping_address", ToJson(object.shipping_address_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateNewPreCheckoutQuery &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateNewPreCheckoutQuery");
  jo << ctie("id", ToJson(JsonInt64{object.id_}));
  jo << ctie("sender_user_id", ToJson(object.sender_user_id_));
  jo << ctie("currency", ToJson(object.currency_));
  jo << ctie("total_amount", ToJson(object.total_amount_));
  jo << ctie("invoice_payload", ToJson(base64_encode(object.invoice_payload_)));
  jo << ctie("shipping_option_id", ToJson(object.shipping_option_id_));
  if (object.order_info_) {
    jo << ctie("order_info", ToJson(object.order_info_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updateNewCustomEvent &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateNewCustomEvent");
  jo << ctie("event", ToJson(object.event_));
}
void to_json(JsonValueScope &jv, const td_api::updateNewCustomQuery &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updateNewCustomQuery");
  jo << ctie("id", ToJson(JsonInt64{object.id_}));
  jo << ctie("data", ToJson(object.data_));
  jo << ctie("timeout", ToJson(object.timeout_));
}
void to_json(JsonValueScope &jv, const td_api::updatePoll &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updatePoll");
  if (object.poll_) {
    jo << ctie("poll", ToJson(object.poll_));
  }
}
void to_json(JsonValueScope &jv, const td_api::updates &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "updates");
  jo << ctie("updates", ToJson(object.updates_));
}
void to_json(JsonValueScope &jv, const td_api::user &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "user");
  jo << ctie("id", ToJson(object.id_));
  jo << ctie("first_name", ToJson(object.first_name_));
  jo << ctie("last_name", ToJson(object.last_name_));
  jo << ctie("username", ToJson(object.username_));
  jo << ctie("phone_number", ToJson(object.phone_number_));
  if (object.status_) {
    jo << ctie("status", ToJson(object.status_));
  }
  if (object.profile_photo_) {
    jo << ctie("profile_photo", ToJson(object.profile_photo_));
  }
  if (object.outgoing_link_) {
    jo << ctie("outgoing_link", ToJson(object.outgoing_link_));
  }
  if (object.incoming_link_) {
    jo << ctie("incoming_link", ToJson(object.incoming_link_));
  }
  jo << ctie("is_verified", ToJson(object.is_verified_));
  jo << ctie("is_support", ToJson(object.is_support_));
  jo << ctie("restriction_reason", ToJson(object.restriction_reason_));
  jo << ctie("is_scam", ToJson(object.is_scam_));
  jo << ctie("have_access", ToJson(object.have_access_));
  if (object.type_) {
    jo << ctie("type", ToJson(object.type_));
  }
  jo << ctie("language_code", ToJson(object.language_code_));
}
void to_json(JsonValueScope &jv, const td_api::userFullInfo &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "userFullInfo");
  jo << ctie("is_blocked", ToJson(object.is_blocked_));
  jo << ctie("can_be_called", ToJson(object.can_be_called_));
  jo << ctie("has_private_calls", ToJson(object.has_private_calls_));
  jo << ctie("bio", ToJson(object.bio_));
  jo << ctie("share_text", ToJson(object.share_text_));
  jo << ctie("group_in_common_count", ToJson(object.group_in_common_count_));
  if (object.bot_info_) {
    jo << ctie("bot_info", ToJson(object.bot_info_));
  }
}
void to_json(JsonValueScope &jv, const td_api::UserPrivacySetting &object) {
  td_api::downcast_call(const_cast<td_api::UserPrivacySetting &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::userPrivacySettingShowStatus &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "userPrivacySettingShowStatus");
}
void to_json(JsonValueScope &jv, const td_api::userPrivacySettingShowProfilePhoto &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "userPrivacySettingShowProfilePhoto");
}
void to_json(JsonValueScope &jv, const td_api::userPrivacySettingShowLinkInForwardedMessages &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "userPrivacySettingShowLinkInForwardedMessages");
}
void to_json(JsonValueScope &jv, const td_api::userPrivacySettingAllowChatInvites &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "userPrivacySettingAllowChatInvites");
}
void to_json(JsonValueScope &jv, const td_api::userPrivacySettingAllowCalls &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "userPrivacySettingAllowCalls");
}
void to_json(JsonValueScope &jv, const td_api::userPrivacySettingAllowPeerToPeerCalls &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "userPrivacySettingAllowPeerToPeerCalls");
}
void to_json(JsonValueScope &jv, const td_api::UserPrivacySettingRule &object) {
  td_api::downcast_call(const_cast<td_api::UserPrivacySettingRule &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::userPrivacySettingRuleAllowAll &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "userPrivacySettingRuleAllowAll");
}
void to_json(JsonValueScope &jv, const td_api::userPrivacySettingRuleAllowContacts &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "userPrivacySettingRuleAllowContacts");
}
void to_json(JsonValueScope &jv, const td_api::userPrivacySettingRuleAllowUsers &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "userPrivacySettingRuleAllowUsers");
  jo << ctie("user_ids", ToJson(object.user_ids_));
}
void to_json(JsonValueScope &jv, const td_api::userPrivacySettingRuleRestrictAll &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "userPrivacySettingRuleRestrictAll");
}
void to_json(JsonValueScope &jv, const td_api::userPrivacySettingRuleRestrictContacts &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "userPrivacySettingRuleRestrictContacts");
}
void to_json(JsonValueScope &jv, const td_api::userPrivacySettingRuleRestrictUsers &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "userPrivacySettingRuleRestrictUsers");
  jo << ctie("user_ids", ToJson(object.user_ids_));
}
void to_json(JsonValueScope &jv, const td_api::userPrivacySettingRules &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "userPrivacySettingRules");
  jo << ctie("rules", ToJson(object.rules_));
}
void to_json(JsonValueScope &jv, const td_api::userProfilePhoto &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "userProfilePhoto");
  jo << ctie("id", ToJson(JsonInt64{object.id_}));
  jo << ctie("added_date", ToJson(object.added_date_));
  jo << ctie("sizes", ToJson(object.sizes_));
}
void to_json(JsonValueScope &jv, const td_api::userProfilePhotos &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "userProfilePhotos");
  jo << ctie("total_count", ToJson(object.total_count_));
  jo << ctie("photos", ToJson(object.photos_));
}
void to_json(JsonValueScope &jv, const td_api::UserStatus &object) {
  td_api::downcast_call(const_cast<td_api::UserStatus &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::userStatusEmpty &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "userStatusEmpty");
}
void to_json(JsonValueScope &jv, const td_api::userStatusOnline &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "userStatusOnline");
  jo << ctie("expires", ToJson(object.expires_));
}
void to_json(JsonValueScope &jv, const td_api::userStatusOffline &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "userStatusOffline");
  jo << ctie("was_online", ToJson(object.was_online_));
}
void to_json(JsonValueScope &jv, const td_api::userStatusRecently &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "userStatusRecently");
}
void to_json(JsonValueScope &jv, const td_api::userStatusLastWeek &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "userStatusLastWeek");
}
void to_json(JsonValueScope &jv, const td_api::userStatusLastMonth &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "userStatusLastMonth");
}
void to_json(JsonValueScope &jv, const td_api::UserType &object) {
  td_api::downcast_call(const_cast<td_api::UserType &>(object), [&jv](const auto &object) { to_json(jv, object); });
}
void to_json(JsonValueScope &jv, const td_api::userTypeRegular &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "userTypeRegular");
}
void to_json(JsonValueScope &jv, const td_api::userTypeDeleted &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "userTypeDeleted");
}
void to_json(JsonValueScope &jv, const td_api::userTypeBot &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "userTypeBot");
  jo << ctie("can_join_groups", ToJson(object.can_join_groups_));
  jo << ctie("can_read_all_group_messages", ToJson(object.can_read_all_group_messages_));
  jo << ctie("is_inline", ToJson(object.is_inline_));
  jo << ctie("inline_query_placeholder", ToJson(object.inline_query_placeholder_));
  jo << ctie("need_location", ToJson(object.need_location_));
}
void to_json(JsonValueScope &jv, const td_api::userTypeUnknown &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "userTypeUnknown");
}
void to_json(JsonValueScope &jv, const td_api::users &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "users");
  jo << ctie("total_count", ToJson(object.total_count_));
  jo << ctie("user_ids", ToJson(object.user_ids_));
}
void to_json(JsonValueScope &jv, const td_api::validatedOrderInfo &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "validatedOrderInfo");
  jo << ctie("order_info_id", ToJson(object.order_info_id_));
  jo << ctie("shipping_options", ToJson(object.shipping_options_));
}
void to_json(JsonValueScope &jv, const td_api::venue &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "venue");
  if (object.location_) {
    jo << ctie("location", ToJson(object.location_));
  }
  jo << ctie("title", ToJson(object.title_));
  jo << ctie("address", ToJson(object.address_));
  jo << ctie("provider", ToJson(object.provider_));
  jo << ctie("id", ToJson(object.id_));
  jo << ctie("type", ToJson(object.type_));
}
void to_json(JsonValueScope &jv, const td_api::video &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "video");
  jo << ctie("duration", ToJson(object.duration_));
  jo << ctie("width", ToJson(object.width_));
  jo << ctie("height", ToJson(object.height_));
  jo << ctie("file_name", ToJson(object.file_name_));
  jo << ctie("mime_type", ToJson(object.mime_type_));
  jo << ctie("has_stickers", ToJson(object.has_stickers_));
  jo << ctie("supports_streaming", ToJson(object.supports_streaming_));
  if (object.minithumbnail_) {
    jo << ctie("minithumbnail", ToJson(object.minithumbnail_));
  }
  if (object.thumbnail_) {
    jo << ctie("thumbnail", ToJson(object.thumbnail_));
  }
  if (object.video_) {
    jo << ctie("video", ToJson(object.video_));
  }
}
void to_json(JsonValueScope &jv, const td_api::videoNote &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "videoNote");
  jo << ctie("duration", ToJson(object.duration_));
  jo << ctie("length", ToJson(object.length_));
  if (object.minithumbnail_) {
    jo << ctie("minithumbnail", ToJson(object.minithumbnail_));
  }
  if (object.thumbnail_) {
    jo << ctie("thumbnail", ToJson(object.thumbnail_));
  }
  if (object.video_) {
    jo << ctie("video", ToJson(object.video_));
  }
}
void to_json(JsonValueScope &jv, const td_api::voiceNote &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "voiceNote");
  jo << ctie("duration", ToJson(object.duration_));
  jo << ctie("waveform", ToJson(base64_encode(object.waveform_)));
  jo << ctie("mime_type", ToJson(object.mime_type_));
  if (object.voice_) {
    jo << ctie("voice", ToJson(object.voice_));
  }
}
void to_json(JsonValueScope &jv, const td_api::webPage &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "webPage");
  jo << ctie("url", ToJson(object.url_));
  jo << ctie("display_url", ToJson(object.display_url_));
  jo << ctie("type", ToJson(object.type_));
  jo << ctie("site_name", ToJson(object.site_name_));
  jo << ctie("title", ToJson(object.title_));
  jo << ctie("description", ToJson(object.description_));
  if (object.photo_) {
    jo << ctie("photo", ToJson(object.photo_));
  }
  jo << ctie("embed_url", ToJson(object.embed_url_));
  jo << ctie("embed_type", ToJson(object.embed_type_));
  jo << ctie("embed_width", ToJson(object.embed_width_));
  jo << ctie("embed_height", ToJson(object.embed_height_));
  jo << ctie("duration", ToJson(object.duration_));
  jo << ctie("author", ToJson(object.author_));
  if (object.animation_) {
    jo << ctie("animation", ToJson(object.animation_));
  }
  if (object.audio_) {
    jo << ctie("audio", ToJson(object.audio_));
  }
  if (object.document_) {
    jo << ctie("document", ToJson(object.document_));
  }
  if (object.sticker_) {
    jo << ctie("sticker", ToJson(object.sticker_));
  }
  if (object.video_) {
    jo << ctie("video", ToJson(object.video_));
  }
  if (object.video_note_) {
    jo << ctie("video_note", ToJson(object.video_note_));
  }
  if (object.voice_note_) {
    jo << ctie("voice_note", ToJson(object.voice_note_));
  }
  jo << ctie("instant_view_version", ToJson(object.instant_view_version_));
}
void to_json(JsonValueScope &jv, const td_api::webPageInstantView &object) {
  auto jo = jv.enter_object();
  jo << ctie("@type", "webPageInstantView");
  jo << ctie("page_blocks", ToJson(object.page_blocks_));
  jo << ctie("version", ToJson(object.version_));
  jo << ctie("url", ToJson(object.url_));
  jo << ctie("is_rtl", ToJson(object.is_rtl_));
  jo << ctie("is_full", ToJson(object.is_full_));
}
}  // namespace td_api
}  // namespace td
